#!/bin/bash
# These defines must precede any usage or weird things may happen.
%define _x11dir             /usr/X11R6
%define _x11bindir          %{_x11dir}/bin
%define _x11includedir      %{_x11dir}/include
%define _x11libdir          %{_x11dir}/lib
%define _x11mandir          %{_x11dir}/man
%define _x11fontdir         %{_x11libdir}/X11/fonts

Name: XFree86
Version: 4.2.1
#Release: 27
Release: 16.73.31.legacy

# Build for RHL 7.3 instead of 8.0 - this tweaks various defaults so we can
# share one X specfile and patchset between both releases
%define RHL_73_build		1
# If RHL_73_build is false above, set RHL_80_build to true
%define RHL_80_build		!%{RHL_73_build}

# Only build on architectures we shipped an OS for
#Exclusivearch: %{ix86} athlon

%ifarch s390 s390x
%define ParallelBuild           0
%else
%define ParallelBuild           1
%endif

%define VerboseBuild            1
# Builds X with debug symbol info.  This results in *FRECKIN* *HUGE* packages.
# Enable this if you want to debug the modular X server.  As of gdb 5.0, this
# requires patches to gdb to be completely useful.  I MEAN HUGE, ie 2-3 times
# the size!  Don't complain - you've been warned!  gdb for XFree86 is
# Available for download from ftp://people.redhat.com/mharris/gdb-xfree86
%define DebuggableBuild         0

%define Glide3version           20010520
%define ttmkfdir_ver		3.0.9

%ifarch %{ix86} alpha ia64
%define BuildTdfx               1
%define Glide3Require           1
%else
%define BuildTdfx               0
%define Glide3Require           0
%endif

%define WithNewSavageDriver         1
%define WithNewCyrixDriver          1
%define WithNewAlanCoxInputDrivers  1

# We build DRM modules in our kernel package, not XFree86.  Defining this to
# 1 will build but not yet package the DRM modules.
%define with_DRM                0

%ifarch %{ix86} athlon x86_64 ia64 alpha
%define with_DRI                1
%else
%define with_DRI                0
%endif

# Both RHL 7.3 and 8.0 include ttmkfdir internally
%define with_ttmkfdir           1

# xf86cfg is now disabled, as we're moving to our own GTK based config tool
# This only works on x86/alpha aparently, so we ifarch
%ifarch %{ix86} alpha
%define with_xf86cfg            %{RHL_73_build}
%else
%define with_xf86cfg            0
%endif

# Set this to 1 to have patch create backup files below when patching X
#%define with_bk             1

# FIXME We're using the new fontconfig based Xft1 1.2 lib now.
%define with_new_fontconfig_Xft		%{RHL_80_build}

# XFree86 3.3.6 is now OBSOLETE, so we want it upgraded to 4.x now, and all old
# 3.3.6 crap vanquished from existance.  Conditionalized for people rebuilding
# 4.2.0 on RHL 7.x who for some weirdo reason want to keep 3.3.6 compatibility
%define obsolete_xfree86_336		%{RHL_80_build}

# RPM 4.1-0.63 and higher in current rawhide, has the ability to abort builds
# during final file packaging, if any files and/or directories are present in
# $RPM_BUILD_ROOT that are not explicitly listed in %files section.  Developers
# can use this feature to ensure no important files go missing when updating
# packages, and also to ensure new software versions which install new files,
# do not end up having missing files due to a developer not checking for new
# files.
%define _unpackaged_files_terminate_build  0

%if %{RHL_73_build}
%define __xftfc-cache	xftcache
%else
%define __xftfc-cache	fc-cache
%endif
%define __fccache       umask 133;which %{__xftfc-cache} &> /dev/null && %{__xftfc-cache}

%define __mkfontdir	umask 133;%{_x11bindir}/mkfontdir

# Disable rpm from stripping XFree86's modules, or they explode
%define __spec_install_post /usr/lib/rpm/brp-compress

%define rhbsys  %([ -r /etc/beehive-root ] && echo 1 || echo 0)

######################################################################
######################################################################

Summary: The basic fonts, programs and docs for an X workstation.
License: XFree86
Group: User Interface/X
URL: http://www.xfree86.org
BuildRoot: %{_tmppath}/%{name}-%{version}-root

BuildRequires: freetype-devel >= 2.0.6-3, flex >= 2.5.4a, bison, zlib-devel
BuildRequires: ncurses-devel, pam-devel, expat-devel
BuildRequires: libpng-devel, utempter, libtool
BuildRequires: gcc-c++
Requires: utempter
# FIXME: xrdb needs /lib/cpp at runtime (should be changed to use /usr/bin/cpp)
Requires: /lib/cpp
Requires: %{_x11bindir}/xauth

# We need fontconfig for the new Xft1
%if %{with_new_fontconfig_Xft}
BuildRequires: fontconfig-devel
%endif

# Added when Glide3 was separated back out.
# This conditional buildrequires works when you use rpm manually.  However
# it breaks horribly when passed through the Red Hat build system which
# doesn't grok conditionals like this.  <shrug>
%if %{Glide3Require}
Requires: Glide3 >= %{Glide3version}
BuildRequires: Glide3-devel >= %{Glide3version}
%endif

Requires: XFree86-xfs = %{version}-%{release}, XFree86-libs = %{version}-%{release}
Requires: XFree86-base-fonts = %{version}-%{release}
Requires: pam-devel
# kernel-drm requirement is so DRI works properly.  The kernel RPM package
# should have a "Provides: kernel-drm = 4.2.0".  Future kernels that provide
# new kernel-drm, should list all supported DRM interfaces with multiple
# Provides: lines.  The 4.2.0 DRM is backward compatible with XFree86 4.1.0
# also.                                                 <mharris@redhat.com>
# WAS: %ifnarch ppc ppc64 s390 s390x sparc sparc64
# Changed to %if %{with_DRI}, which makes it automatic if BuildDRI is
# enabled for a given architecture.  Don't have to make changes in 2 places.
%if %{with_DRI}
# XFree86 4.2.0 and 4.2.1 are the same DRM-wise so there is no kernel-drm 4.2.1
Requires: kernel-drm = 4.2.0
%endif

Prereq: /bin/ln, %{_sbindir}/chkfontpath, %{_x11bindir}/mkfontdir

# Obsolete all old XFree86 3.3.x crap, and similar ancient stuff
Obsoletes: XFree86-ATI, XFree86-Alliance, XFree86-ChipsTechnologies
Obsoletes: XFree86-Cirrus, XFree86-Cyrix, XFree86-i740, XFree86-i810, XFree86-mga
Obsoletes: XFree86-NeoMagic, XFree86-NVidia, XFree86-Rage128, XFree86-Rendition
Obsoletes: XFree86-SiS, XFree86-3dfx, XFree86-Trident, XFree86-Tseng
Obsoletes: tdfx_dri, X11R6-contrib, XFree86-V4L
# The xtrap-clients package got obsoleted and merged into the main XFree86
# package for 4.3.0, and there's no good reason to have it separate, so I
# am obsoleting it in 4.2.1 erratum for RHL 7.3 and 8.0 also.
Obsoletes: XFree86-xtrap-clients

%if %{obsolete_xfree86_336}
Obsoletes: XFree86-3DLabs, XFree86-8514, XFree86-AGX, XFree86-FBDev
Obsoletes: XFree86-Mach32, XFree86-Mach64, XFree86-Mach8, XFree86-Mono
Obsoletes: XFree86-P9000, XFree86-S3, XFree86-S3V, XFree86-SVGA
Obsoletes: XFree86-VGA16, XFree86-W32, XFree86-compat-modules, XFree86-compat-libs
# This one is only on Alpha
Obsoletes: XFree86-TGA
%endif

# This Obsoletes was added for ulT1mo latin2 fonts, subsequently removed for
# 4.2.0, and now added back to force any prior packages to be removed upon
# upgrade, since do not supply these fonts any longer, so Provides is not needed.
Obsoletes: XFree86-ISO8859-2-Type1-fonts

Source:   XFree86-%{version}.tar.gz
Source3:  xserver.pamd
Source4:  xdm.pamd
Source5:  xfs.init
Source6:  xfs.config
Source7:  xdm.init

# Tim Roberts' Savage driver 1.1.27t (Apr 19, 2003) <mharris@redhat.com>
Source14: http://www.probo.com/timr/savage-1.1.27t.tgz
Source20: XftConfig.redhat
#Source21: ttmkfdir2.tar.bz2
Source21: ttmkfdir-%{ttmkfdir_ver}.tar.bz2
# Backport of Xft1 for fontconfig from XFree86 CVS 4.2.99.1
Source22: Xft1-2002-06-21.tar.bz2
Source23: mkxauth
Source24: mkxauth.1x
Source30: ftp://people.redhat.com/alan/XFree86/Cyrix/cyrix-0.3.tar.gz
Source31: ftp://people.redhat.com/alan/XFree86/Fujitsu/fpit-0.01.tar.gz
Source32: ftp://people.redhat.com/alan/XFree86/Palmax/palmax-0.02.tar.gz
Source33: ftp://people.redhat.com/alan/XFree86/UnionReality/ur98-0.01.tar.gz

# XFree86 stable branch patch
Patch0:   XFree86-4.2.1-xf-4_2-branch-20030405.patch
# Parallel make patch, designed specifically to hog all CPU's on all the
# build system boxes and make kernel builds take longer.  <evil grin>
Patch3:   XFree86-4.2.0-parallelmake-this-time-its-personal.patch

Patch7:   XFree86-4.2.0-xtermresources.patch
Patch12:  XFree86-4.0-broken-includes.patch
# Red Hat Custom default modelines patch (Mike A. Harris <mharris@redhat.com>)
Patch16:  XFree86-4.2.0-redhat-custom-modelines.patch

##### DRIVER PATCHES #################################################
# Patches 100-104: apm driver patches
Patch100: XFree86-4.2.0-apm-driver-update-cvs-20020617.patch
# Patches 105-109: ark driver patches
Patch105: XFree86-4.2.0-ark-driver-update-cvs-20020617.patch
# Patches 110-119: ati driver patches
# 110 is obsoleted by 111 (testing, new Dell fix for PCI spec violation)
Patch110: XFree86-4.2.0-ati-mach64-rage-XL.patch
Patch111: XFree86-4.2.0-ati-rage-xl-pci-spec-cleanup.patch
# Backport from CVS to fix old card support lost when FireGL 7800 patch got
# added.
Patch112: XFree86-4.2.0-ati-old-LX-card-fix.patch
Patch113: XFree86-4.2.0-ati-mach64-dsp-rounding-error.patch

# PATCHES 120-129 for ATI Rage 128
# Patch for R128 from Michal Daenzer
Patch120: XFree86-4.2.0-ati-r128-indirectBuffer.patch
# Rage 128 patch from Michal Daenzer for enable/disable of DMA with Xv
Patch121: XFree86-4.2.0-ati-r128-Xv-dma-fix.patch
Patch122: XFree86-4.2.0-ati-r128-vtswitch-fix-busmaster-enable.patch
Patch123: XFree86-4.2.1-ati-r128-dri-dga.patch
# Fix for bug #83303
Patch124: XFree86-4.2.1-ati-r128-missing-symbols.patch

# Patches 130-139: radeon driver patches 
# ATI Radeon Mobility M7 (LX) support - Mike A. Harris <mharris@redhat.com>
Patch130: XFree86-4.2.0-ati-radeon-mobility-FireGL-7800.patch
Patch132: XFree86-4.2.0-ati-radeon-misc-bugfixes.patch

# Bugfix for long time standing ATI Radeon VTswitch related problems
Patch133: XFree86-4.2.0-ati-radeon-vtswitch-fix-busmaster-enable.patch
Patch134: XFree86-4.2.0-ati-radeon-cp-colorexpansion-imagewrite-enhancement.patch
Patch135: XFree86-4.2.0-ati-radeon-missing-commas.patch
# Fix (hopefully) for FPE in radeon driver at 1400x1050 and 1600x1200 with
# certain cards, in certain refresh rates, during certain phases of the moon
Patch136: XFree86-4.2.0-ati-radeon-dda-removal.patch
Patch137: XFree86-4.2.1-ati-radeon-dri-dga.patch
Patch138: XFree86-4.2.1-ati-radeon-alan-legacy-vga.patch

# Patches 140-149: chips driver patches 
Patch140: XFree86-4.2.0-chips-driver-update-cvs-20020617.patch
Patch141: XFree86-4.2.99.1-chips-accel-fix.patch

# Patches 150-159: cirrus driver patches 
Patch150: XFree86-4.2.0-cirrus-driver-update-cvs-20020617.patch
Patch151: XFree86-4.2.0-cirrus-disable-DEBUG.patch

# Patches 160-169: cyrix driver patches
Patch160: XFree86-4.2.0-cyrix-new-driver-from-alan-cox.patch

# Patches 170-179: fbdev driver patches
# Patches 180-189: glint driver patches
# FIXME: Applied to 4.2.99.x CVS already, safe to remove when updating
Patch180: XFree86-4.2.0-glint.patch
# Patches 190-199: i128 driver patches
# Patches 200-209: i740 driver patches
Patch200: XFree86-4.2.0-i740-driver-update-cvs-20020617.patch
# Patches 210-219: Intel i810 / i830 patches
# Update to CVS and add 2D only i845 support
Patch210: XFree86-4.2.0-i810-driver-update-cvs-20020617.patch
Patch211: XFree86-4.2.0-i810-dont-use-empty-for-loops-for-delays.patch
Patch212: XFree86-4.2.0-i810-dont-force-XvMC-on-DRI-users.patch
# Fix for Dell C400 and some other broken BIOS's which limit the i830 to 1Mb
# of stolen memory.  (DOES NOT WORK, DISABLED)
Patch213: XFree86-4.2.0-i810-dell-c400-broken-bios-1Mb-limit-workaround.patch
# Fix for i810 VTswitch bug reported by Alan Cox (#66187)
Patch214: XFree86-4.2.0-i810-vtswitch-sync-fix.patch

# Patches 220-229: mga driver patches
Patch220: XFree86-4.2.0-G450.patch
Patch221: XFree86-4.2.0-mga-g550-cursor.patch
Patch222: XFree86-4.2.1-mga-xinerama-G450-issue.patch

# Patches 230-239: neomagic driver patches
Patch230: XFree86-4.2.0-neomagic-Xv-support.patch
# Patches 240-249: nv driver patches
# Patches 255-259: rendition driver patches
# Patches 260-269: s3 driver patches
# Patches 270-279: s3virge driver patches
# Patches 280-289: savage driver patches
# Patches 290-299: siliconmotion driver patches
Patch290: XFree86-4.2.0-siliconmotion-driver-update-cvs-20020617.patch

# Patches 300-309: sis driver patches
Patch300: XFree86-4.2.0-sis-cursor.patch
# Fixes backwards conditionals in SiS driver
Patch301: XFree86-4.2.0-sis-maxxfbmem-fixup.patch
# Fix up unresolved symbols reported by Alan Cox
Patch302: XFree86-4.2.0-sis-unresolved-symbols.patch

# Patches 310-319: tdfx driver patches
# Minor typo bugfix preventing 2048 video modes from working <mharris@redhat.com>
Patch310: XFree86-4.2.0-tdfx-should-be-2048-not-2046.patch
# Interlaced video mode support for Voodoo 3/4/5 <mharris@redhat.com>
# FIXME: (needs testing yet to make sure it works)
Patch311: XFree86-4.2.0-tdfx-enable-interlaced-modes.patch
# My attempt to fix VGA font corruption on VT switch <mharris@redhat.com>
# FIXME: (needs testing yet to make sure it works)
Patch312: XFree86-4.2.0-tdfx-fix-vtswitch-font-corruption.patch
# Disable DRI on 16Mb cards in high res (Mike A. Harris <mharris@redhat.com>)
# FIXME: (needs testing yet to make sure it works)
Patch313: XFree86-4.2.0-tdfx-disable-dri-on-16Mb-cards-in-hires.patch
# Fix compiler warnings in tdfx Mesa code
Patch319: XFree86-4.2.0-tdfx-fix-compiler-warnings.patch

# Patches 320-329: tga driver patches
# Patches 330-339: trident driver patches
Patch330: XFree86-4.2.0-trident-driver-update-cvs-20020617.patch
# Older patch, probably unneeded with CVS driver update above
Patch331: XFree86-4.2.0-trident-9397.patch

# Patches 340-349: tseng driver patches
# Patches 350-359: v4l driver patches
# Patches 360-369: vesa driver patches
# Patches 370-379: vga driver patches
# Patches 380-389: vmware driver patches

### Non-video driver patches #########################################
# Patches 400-419: xc/nls/{locale.dir,locale.alias,compose.dir} patches
Patch400: XFree86-4.2.0-locale-gb18030.patch
Patch401: XFree86-4.2.0-locale-tr_TR-bug55736.patch
Patch402: XFree86-4.0.2-xfree86.lst.patch

# Fix bad page size assumptions in DRI drivers <mharris@redhat.com>
Patch405: XFree86-4.1.99.2-pagesize-fixup.patch
# CUSTOM startup messages (Currently does nothing) Mike A. Harris <mharris@redhat.com>
Patch421: XFree86-4.0.3-rhl-startupmessages.patch
# Manpage fixup  Mike A. Harris <mharris@redhat.com>
Patch422: XFree86-4.0.3-xset-man-update.patch
Patch504: XFree86-4.0.99.3-Xwrapper.patch

# Patches: 800-819 - xkb keyboard symbol files
Patch800: XFree86-4.2.0-xkb-french-canadian.patch
Patch801: XFree86-4.2.0-xkb-ar.patch
# Icelandic keyboard symbol patch to fix bug (#60594)
Patch803: XFree86-4.2.0-xkb-is.patch
# Fixed deadkey doublequote in ISO8859-15
Patch804: XFree86-4.2.0-xkb-fix-deadkey-quotedbl-us_intl.patch

Patch1000: XFree86-4.0.1-drm.patch
Patch1001: XFree86-4.1-xinerama.patch
Patch1003: XFree86-4.0.99.901-redhat-xdm-pam.patch

# Xaw3d patch to xterm  H.J. Lu <hjl@gnu.org>
Patch1007: XFree86-4.0.2-xterm-Xaw3d.patch
# TEMPORARILY MOVED HERE for patch reorganization
Patch1009: XFree86-4.0.1-alpha-pcibus-lemming.patch
Patch1010: XFree86-4.0.1-pic.patch
# -frame option is ignored if -id option used <mharris@redhat.com>
Patch1018: XFree86-4.1.0-xwd-frame-option.patch
# load agpgart for DRM
Patch1021: XFree86-4.1.0-agpgart-load.patch
# Add support for Japanese 109 key USB keyboard
Patch1023: XFree86-4.1.0-keyboard-jp109usb.patch
Patch1025: XFree86-4.2.0-FIRSTINDEX-breaks-ttmkfdir.patch
# Fixes xman bug by using s/zsoelim/soelim/.  Also, a symlink added to groff package. mharris@redhat.com
Patch1028: XFree86-4.1.0-xman-soelim-fix.patch
# FIXME: REMOVE for 4.3.0 - fixed in CVS in another way - Fixes unaligned trap error on Alpha
Patch1029: XFree86-4.1.0-glFrustum-fixie.patch
# Fix for abnt2 keycodes (#55128)
# DISABLED: 4.2.0 has this already in a slightly different way.
Patch1033: XFree86-4.1.0-keycodes-abnt2.patch

# S390 patches (will be moved to arch specific section later)
#Patch3000: XFree86-4.1.0-s390x.patch
Patch3001: XFree86-4.0.1-nohardware.patch
Patch3002: XFree86-4.0.2-FreeType-s390x.patch
Patch3004: xdm-4.0-servonly.patch
Patch3005: XFree86-4.1.0-cpp-s390x.patch
Patch3007: XFree86-4.1.0-ppc-compiler-workaround.patch
# Sparc patches (might be needed/useful on PPC arch too)
Patch3100: XFree86-4.2.0-pci-domains-from-cvs.patch

# Chinese i18n support patches
# 4004 - gb18030 patches may need tweaking 
Patch4004: XFree86-4.2.0-gb18030-20020207.patch
Patch4005: XFree86-4.1.0-xtt.patch
Patch4006: XFree86-4.2.0-gb2312-gbk-enc-support.patch
Patch4009: XFree86-4.2.0-zh_CN-i18n.patch
# Xcin fixes, otaylor@redhat.com, llch@redhat.com
Patch4020: XFree86-4.2.0-zh_TW-xcinNEW.patch
Patch4021: XFree86-4.2.0-gb18030-enc.patch
Patch4022: XFree86-4.2.0-euro-support.patch

# New stuffs
Patch4100: XFree86-4.2.0-Wacom-USB-driver-a25-update.patch
# Patch to xfs to make it chdir("/"); prior to fork() for bug #57110
Patch4104: XFree86-4.2.0-xfs-chdir-to-root-dir.patch
# Fix syslog to log to LOG_DAEMON instead of LOG_LOCAL0 <mharris@redhat.com>
Patch4105: XFree86-4.2.0-xfs-syslog.patch
# Disable the ugly checkerboard pattern that X starts up with.  We're in the
# year 2002 now, and this pattern just has to go.  No really.  <mharris>
Patch4106: XFree86-4.2.0-die-ugly-pattern-die-die-die.patch
Patch4110: XFree86-4.2.0-nls-en_US-en_GB-ISO8859-15-support.patch
Patch4111: XFree86-4.2.0-sessreg-highuid.patch
Patch4112: XFree86-4.2.0-startx-hostname-fix.patch
Patch4113: XFree86-4.2.0-drm-device-dir-perms.patch
# Patch to correct the way xman defaults the man config filename, and
# also make it more easily configureable via Imakefile instead of in
# the xman code.   Mike A. Harris <mharris@redhat.com>
Patch4117: XFree86-4.2.0-xman-manconf.patch
Patch4118: XFree86-4.2.0-mkfontscale-xcvs-20020618.patch

Patch4201: XFree86-4.2.0-alpha-ia64-_LP64-fix.patch
#Patch6000:

Patch4300: XFree86-4.2.0-Xft1-Imake-config.patch
Patch4302: XFree86-4.2.0-hostname-stderr-fix.patch
# Document the NoMTRR option in the XF86Config manpage
Patch4303: XFree86-4.2.0-manpage-document-nomtrr-option.patch
Patch4304: XFree86-4.2.0-sysreq.patch
Patch4305: XFree86-4.2.0-libICE-remove-stupid-delay.patch

# X Resource extension - feature enhancement patch
Patch4306: XFree86-4.2.0-Xresource-extension.patch
# Workaround for bug #67914
Patch4307: XFree86-4.2.0-locale-alias-utf8-euro.patch
Patch4308: XFree86-4.2.0-sane-deadacc.patch
Patch4310: XFree86-4.2.0-minor-typo.patch
Patch4311: XFree86-4.2.0-elf-loader-empty-symbol-table.patch
# Xrender enhancement - color cursors from Keith
# (disabled by default, only present for testing/fun)
Patch4312: XFree86-4.2.0-keith-is-the-man.patch
Patch4313: XFree86-4.2.0-im-clientmessage-crash.patch
Patch4314: XFree86-4.2.0-libXrender-bugfix.patch

# Fixes a SEGV in lbxproxy
Patch4500: XFree86-4.2.1-lbxproxy-SEGV-fix.patch
Patch4501: XFree86-4.2.1-xshm-header-file-fix.patch
Patch4502: XFree86-4.2.1-vidmode-manpage-fixes.diff
Patch4503: XFree86-4.2.1-new-alan-cox-input-drivers.patch
Patch4504: XFree86-4.2.1-Xrender-crashfix.patch
Patch4505: XFree86-4.2.0-bad-mmap-check.patch
Patch4506: XFree86-4.2.1-timestamp-monotonicity.patch
Patch4507: XFree86-4.2.1-xkb-Xutf8LookupString-fails-in-UTF8-bug78804.patch
Patch4508: XFree86-4.2.1-lndir-relative-symlink-fix.patch
Patch4509: XFree86-4.2.1-netmouse.patch
Patch4510: XFree86-4.2.99.2-mkfontdir-perms.patch
Patch4511: XFree86-4.2.99.901-xauth-diskfull.patch
# XAA RENDER bugfix backport from 4.3.0 which fixes Xinerama+mga+render bugs
Patch4512: XFree86-4.2.1-xaa-render-mga-xinerama-issues.patch
Patch4513: XFree86-4.2.1-xterm-DECUDK-security-fix.patch
Patch4514: XFree86-4.2.1-xterm-can-2003-0063.patch
Patch4515: XFree86-4.2.1-makefile-fastbuild.patch
Patch4516: XFree86-4.2.1-xterm-session-management-resource.patch
# Fix for CVE advisory CAN-2003-0730
Patch4520: XFree86-4.2.1-libXfont-security-int-overflow-430-backport.patch
Patch4523: XFree86-4.2.1-xdm-pam-setcred-security.patch
Patch4524: XFree86-4.2.1-libXfont-security-CAN-2004-0083-CAN-2004-0084-CAN-2004-0106-v2-430-backport.patch
# Fix for CAN-2004-0687/8
Patch4525: XFree86-openbsd.xpm.sec.patch
# Fix for CVE advisory CAN-2004-0914
Patch4526: xorg-680-CAN-2004-0914.patch
Patch4527: xorg-x11-6.8.1-xpm-security-fixes-CAN-2004-0914-sec8-ammendment.patch
Patch4528: XFree86-4.1.0-xpm-security-fix-CAN-2005-0605.patch
Patch4529: XFree86-4.3.0-security-CAN-2005-2495.patch 

# 8000 series - ia64 patches
Patch8004: XFree86-4.2.0-ia64-gcc3.1.patch

Patch9000: XFree86-4.2.1-redhat-custom-startup.patch
Patch9001: XFree86-4.2.1-redhat-bug-report-address-update.patch
Patch9002: XFree86-4.2.1-redhat-lock-version.patch
Patch9003: XFree86-4.2.1-redhat-version-change-detection.patch

######################################################################
%package devel
Obsoletes: xpm-devel
Provides: xpm-devel
%if %{with_new_fontconfig_Xft}
Requires: fontconfig
%endif

Summary: X11R6 static libraries, headers and programming man pages.
Group: Development/Libraries
Requires: XFree86-libs = %{version}
Obsoletes: Mesa-devel
Provides: Mesa-devel

######################################################################
%package xfs
Summary: A font server for the X Window System.
Group: System Environment/Daemons
Prereq: fileutils sed
Prereq: shadow-utils
# chkconfig is needed for %post %postun
Prereq: /sbin/chkconfig, %{_x11bindir}/mkfontdir, /usr/bin/ttmkfdir
Requires: XFree86-libs = %{version}
######################################################################
%package twm
Summary: A simple window manager
Group: User Interface/X
Requires: XFree86, XFree86-libs = %{version}
Provides: windowmanager
# The twm.1 manpage was moved from the XFree86 package to the twm package
# to fix bug #70025 on July 29 2002 - Mike A. Harris
Conflicts: XFree86 <= 4.2.0-57.1
######################################################################
%package xdm
Summary: X Display Manager
Requires: XFree86 = %{version}, /etc/pam.d/system-auth
# xinitrc requirement on 3.13 for user login shell enhancement to Xsession
Requires: xinitrc >= 3.13
Group: User Interface/X
######################################################################
%package libs
Summary: Shared libraries needed by the X Window System version 11 release 6.4
Group: System Environment/Libraries
Obsoletes: xpm
Provides: xpm
# The files (XErrorDB, XKeysymDB, rgb.txt) moved from XFree86 to XFree86-libs
# subpackage in 4.2.1-10 while duplicating an enhancement request made to
# XFree86 4.1.0-43 for AS 2.1 - bugzilla bug (#79488)
# Changed conflict from 4.2.1-10 to just 4.2.1 for 7.3
Conflicts: XFree86 < 4.2.1
Prereq: /sbin/ldconfig grep textutils
%if %{RHL_73_build}
# This is required by the glut package in RHL 7.3
Obsoletes: Mesa
Provides: Mesa
%endif

%description libs
XFree86-libs contains the shared libraries required for running X
applications.
######################################################################
%package base-fonts
Summary: The collection of XFree86 core base fonts
Group: User Interface/X
Prereq: /usr/sbin/chkfontpath, %{_x11bindir}/mkfontdir
# Required so upgrades work, since base fonts moved here from main pkg
Conflicts: XFree86 <= 4.2.0-3.1

%description base-fonts
XFree86-base-fonts provides the base fonts required by XFree86
for proper operation.
######################################################################
%package truetype-fonts
Summary: XFree86 Luxi TrueType fonts by Bigelow and Holmes
Group: User Interface/X
Prereq: /usr/sbin/chkfontpath, %{_x11bindir}/mkfontdir, /usr/bin/ttmkfdir

%description truetype-fonts
A collection of truetype fonts which are part of the XFree86 core
distribution, including the Luxi fonts donated by Bigelow and Holmes.
######################################################################
%package font-utils
Summary: Font utilities required for installing fonts
Group: User Interface/X
# mkfontdir and other utilities were moved here so this conflict is needed
Conflicts: XFree86 < 4.2.0-5.2
# freetype package ttmkfdir conflict
Conflicts: freetype < 2.0.6-3

%description font-utils
XFree86-font-utils provides mkfontdir, and ttmkfdir utilities which are
required when installing font packages.
######################################################################
%package 75dpi-fonts
Summary: A set of 75dpi resolution fonts for the X Window System.
Group: User Interface/X
Prereq: /usr/sbin/chkfontpath, %{_x11bindir}/mkfontdir
######################################################################
%package 100dpi-fonts
Summary: A set of 100dpi resolution fonts for the X Window System.
Group: User Interface/X
Prereq: /usr/sbin/chkfontpath, %{_x11bindir}/mkfontdir
######################################################################
%package ISO8859-2-75dpi-fonts
Summary: A set of 75dpi Central European language fonts for X.
Group: User Interface/X
Prereq: /usr/sbin/chkfontpath, %{_x11bindir}/mkfontdir
######################################################################
%package ISO8859-2-100dpi-fonts
Summary: A set of 100dpi Central European language fonts for X.
Group: User Interface/X
Prereq: /usr/sbin/chkfontpath, %{_x11bindir}/mkfontdir
######################################################################
%package ISO8859-9-75dpi-fonts
Summary: ISO8859-9-75dpi-fonts
Group: User Interface/X
Prereq: /usr/sbin/chkfontpath, %{_x11bindir}/mkfontdir
######################################################################
%package ISO8859-9-100dpi-fonts
Summary: ISO8859-9-100dpi-fonts
Group: User Interface/X
Prereq: /usr/sbin/chkfontpath, %{_x11bindir}/mkfontdir
######################################################################
%package ISO8859-15-75dpi-fonts
Summary: ISO8859-15-75dpi-fonts
Group: User Interface/X
Prereq: /usr/sbin/chkfontpath, %{_x11bindir}/mkfontdir
######################################################################
%package ISO8859-15-100dpi-fonts
Summary: ISO8859-15-100dpi-fonts
Group: User Interface/X
Prereq: /usr/sbin/chkfontpath, %{_x11bindir}/mkfontdir
######################################################################
%package cyrillic-fonts
Summary: Cyrillic fonts for X.
Group: User Interface/X
Prereq: /usr/sbin/chkfontpath, %{_x11bindir}/mkfontdir
######################################################################
%ifnarch s390 s390x
%package doc
Summary: Documentation on various X11 programming interfaces.
Group: Documentation
%endif
######################################################################
%package Xnest
Summary: A nested XFree86 server.
Group: User Interface/X
Requires: XFree86 = %{version}
######################################################################
%package Xvfb
Summary: A virtual framebuffer X Windows System server for XFree86.
Group: User Interface/X
Requires: XFree86 = %{version}
######################################################################
%package tools
Summary: Various tools for XFree86
Group: User Interface/X
Obsoletes: X11R6-contrib
Requires: XFree86
######################################################################
%if %{RHL_80_build}
%package xauth
Summary: X authority file utility
Group: User Interface/X
Conflicts: XFree86 < 4.2.0-50.11
Obsoletes: mkxauth
Provides: mkxauth

%description xauth
The xauth program is used to edit and display the authorization information
used in connecting to the X server.
%endif
######################################################################
%if %{RHL_80_build}
%package Mesa-libGL
Summary: A 3D graphics library which uses an OpenGL-like API
Group: System Environment/Libraries
# FIXME: Removed dep as I'm not sure it is required.  Only got put here
# due to Mesa previously req'ing XFree86
#Requires: XFree86
Obsoletes: Mesa
Provides: Mesa
# Conflict is due to this package being split out from XFree86-libs
Conflicts: XFree86-libs < 4.2.0-50.5

%description Mesa-libGL
The Mesa 3D graphics library is a powerful and generic toolset for
creating hardware assisted computer graphics. To the extent that Mesa
utilizes the OpenGL command syntax or state machine, it is being used
with authorization from Silicon Graphics, Inc. However, the author
(Brian Paul) makes no claim that Mesa is in any way a compatible
replacement for OpenGL or associated with Silicon Graphics, Inc. Those
who want a licensed implementation of OpenGL should contact a licensed
vendor. Mesa is very similar to OpenGL and you might find Mesa to be a
valid alternative to OpenGL.
######################################################################
%package Mesa-libGLU
Summary: Commonly used GL utility library
Group: System Environment/Libraries
#Requires: XFree86
# Conflict is due to this package being split out from XFree86-libs
Conflicts: XFree86-libs < 4.2.0-50.5

%description Mesa-libGLU
libGLU is a utility library used by a lot of OpenGL applications
%endif
######################################################################
%if %{with_xf86cfg}
%package xf86cfg
Summary: XFree86 configuration program
Group: User Interface/X
Obsoletes: XFree86-XF86Setup
Requires: XFree86 = %{version}
# Removed dep on Xconfigurator and changed to the actual Cards file instead
Requires: %{_x11libdir}/X11/Cards
%endif
########## DESCRIPTIONS ##############################################
%description
XFree86 is an open source implementation of the X Window System.  It
provides the basic low level functionality which full fledged
graphical user interfaces (GUIs) such as GNOME and KDE are designed
upon.

######################################################################
%description Xvfb
Xvfb (X Virtual Frame Buffer) is an X server that is able to run on
machines with no display hardware and no physical input devices.
Xvfb simulates a dumb framebuffer using virtual memory.  Xvfb does
not open any devices, but behaves otherwise as an X display.  Xvfb
is normally used for testing servers.

######################################################################
%description Xnest
Xnest is an X server, which has been implemented as an ordinary
X application.  It runs in a window just like other X applications,
but it is an X server itself in which you can run other software.  It
is a very useful tool for developers who wish to test their
applications without running them on their real X server.

######################################################################

%description ISO8859-2-75dpi-fonts
Contains a set of 75dpi fonts for Central European languages.

######################################################################

%description ISO8859-2-100dpi-fonts
Contains a set of 100dpi fonts for Central European languages.

######################################################################

%description ISO8859-9-75dpi-fonts
Contains a set of 75dpi fonts for the Turkish language.

######################################################################

%description ISO8859-9-100dpi-fonts
Contains a set of 100dpi fonts for the Turkish language.

######################################################################

%description ISO8859-15-75dpi-fonts
Contains a set of 75dpi fonts in the ISO8859-15 encoding which
provide Euro support.

######################################################################

%description ISO8859-15-100dpi-fonts
Contains a set of 100dpi fonts in the ISO8859-15 encoding which
provide Euro support.

######################################################################

%description 75dpi-fonts
XFree86-75dpi-fonts contains the 75 dpi fonts used on most X Window
Systems. If you're going to use the X Window System, you should
install this package, unless you have a monitor which can support 100
dpi resolution.  In that case, you may prefer the 100dpi fonts
available in the XFree86-100dpi-fonts package.

%description 100dpi-fonts
The XFree86-100dpi-fonts package contains a set of 100 dpi fonts used
on most Linux systems. If you're going to use the X Window System and
you have a high resolution monitor capable of 100 dpi, you should
install XFree86-100dpi-fonts.

######################################################################
%description cyrillic-fonts
Contains a set of Cyrillic fonts.

%ifnarch s390 s390x
%description doc
XFree86-doc provides a great deal of documentation, in PostScript
format, on the various X APIs, libraries, and other interfaces.  If
you need low level X documentation, you will find it here.  Topics
include the X protocol, the ICCCM window manager standard, ICE
session management, the font server API, etc.
%endif

######################################################################
%description xdm
X Display Manager.

%description xfs
XFree86-xfs contains the font server for XFree86.  Xfs can also serve
fonts to remote X servers. The remote system will be able to use all
fonts installed on the font server, even if they are not installed on
the remote computer.

%description devel
XFree86-devel includes the libraries, header files and documentation
needed for developing applications for the X window system.

######################################################################
%description twm
A simple and lightweight window manager

######################################################################
%description tools
Various tools for X, including listres, xbiff, xedit, xeyes, xcalc, xload
and xman, among others.

This package contains all applications that used to be in X11R6-contrib
in older releases.

######################################################################
# Replaced ifnarch with with_xf86cfg
#%ifnarch ia64 s390 s390x
%if %{with_xf86cfg}
%description xf86cfg
Configuration tool for XFree86
%endif


##########  PREP  ###################################################
%prep
# Beehive doesn't grok BuildRequires tags that fall inside a %ifarch block
# so we can't conditionally include Glide3-devel per architecture.  Instead
# we leave out the BuildRequires and test for the package existing here with
# a prep time check.  We bomb out if Glide3-devel is not installed.

#%if %{Glide3Require}
#%define Glide3BuildRequires %([ "$(rpm -q --queryformat '%{version}' Glide3-devel)" -ge %{Glide3version} ] && echo 1 || echo 0)
#echo -n "Testing for Glide3-devel >= %{version} build requirement ... "
#if [ "$(rpm -q --queryformat '%%{version}' Glide3-devel)" -ge "%{Glide3version}" ];then
#    echo "Glide3-devel found."
#else
#    echo -e "not found.\n\n"
#    cat <<-EOF
#Glide3 and Glide3-devel version %{Glide3version} or higher are required
#to build XFree86 on x86, alpha and ia64.  Please install these packages
#first prior to building XFree86.  This dependancy check would normally
#be a BuildRequires line in the XFree86 spec file, however build
#requirements that only pertain to certain architectures, and not all
#screw up some software, so this check was implemented instead.
#EOF
#    %exit
#fi
#%endif

%if %{with_ttmkfdir}
%setup -q -c -a 21
%else
%setup -q -c
%endif

%if %{with_new_fontconfig_Xft}
#mv xc/lib/Xft xc/lib/Xft.stock-4.2.0
bzcat %{SOURCE22} | tar xf -
#mv xc/lib/Xft1 xc/lib/Xft
%endif

%if %{WithNewSavageDriver}
{
   echo "Updating SAVAGE driver with %{SOURCE14}"
   pushd xc/programs/Xserver/hw/xfree86/drivers/savage
   tar zxvf %{SOURCE14}
   popd
}
%endif
%if %{WithNewCyrixDriver}
{
   echo "Updating Cyrix driver with %{SOURCE30}"
   pushd xc/programs/Xserver/hw/xfree86/drivers
   tar zxvf %{SOURCE30}
   popd
}
%endif
%if %{WithNewAlanCoxInputDrivers}
   echo "Adding Alan Cox's new input drivers"
   pushd xc/programs/Xserver/hw/xfree86/input
   tar zxvf %{SOURCE31}
   tar zxvf %{SOURCE32}
   tar zxvf %{SOURCE33}
   popd
%endif

##########  PATCH  ##################################################
# This patch *MUST* be first
%patch0 -p0 %{?with_bk:-b .xf-4_2-branch}

# FIXME The parallel make patch might patch stuff that is fixed in a different
# way now, but that doesn't conflict with the patch.  Disabled to be safe.
%if %{ParallelBuild}
%patch3 -p0 %{?with_bk:-b .parallelmake}
%endif

%patch7 -p0 %{?with_bk:-b .xtermresources}
%patch12 -p1 %{?with_bk:-b .patch-broken}
%patch16 -p0 %{?with_bk:-b .redhat-custom-modelines}

# 30-39 Internationalization patches

%patch100 -p0 %{?with_bk:-b .apm-driver-update-cvs-20020617}

%patch105 -p0 %{?with_bk:-b .ark-driver-update-cvs-20020617}

#%patch110 -p0 %{?with_bk:-b .ati-mach64-rage-XL}
%patch111 -p0 %{?with_bk:-b .ati-rage-xl-pci-spec-cleanup}
#%patch112 -p0 %{?with_bk:-b .}
%patch113 -p0 %{?with_bk:-b .ati-mach64-dsp-rounding-error}

# Patch for R128 from Michal Daenzer
%patch120 -p0 %{?with_bk:-b .ati-r128-indirectBuffer}
%patch121 -p0 %{?with_bk:-b .ati-r128-Xv-dma-fix}
%patch122 -p0 %{?with_bk:-b .ati-r128-vtswitch-fix-busmaster-enable}
%patch123 -p0 %{?with_bk:-b .ati-r128-dri-dga}
%patch124 -p0 %{?with_bk:-b .ati-r128-missing-symbols}

%patch130 -p0 %{?with_bk:-b .ati-radeon-mobility-FireGL-7800}
%patch132 -p0 %{?with_bk:-b .ati-radeon-update-from-ati}
%patch133 -p0 %{?with_bk:-b .ati-radeon-vtswitch-fix-busmaster-enable}
# Temporarily disabled due to crash report...
#%patch134 -p0 %{?with_bk:-b .ati-radeon-cp-colorexpansion-imagewrite-enhancement}
#%exit
%patch135 -p0 %{?with_bk:-b .ati-radeon-missing-commas}
%patch136 -p0 %{?with_bk:-b .ati-radeon-dda-removal}
%patch137 -p0 %{?with_bk:-b .ati-radeon-dri-dga}
%patch138 -p0 %{?with_bk:-b .ati-radeon-alan-legacy-vga}

%patch140 -p0 %{?with_bk:-b .chips-driver-update-cvs-20020617}
%patch141 -p0 %{?with_bk:-b .chips-accel-fix}

%patch150 -p0 %{?with_bk:-b .cirrus-driver-update-cvs-20020617}
%patch151 -p0 %{?with_bk:-b .cirrus-disable-DEBUG}
# Cyrix
#%patch160 -p0 %{?with_bk:-b .cyrix-new-driver-from-alan-cox}

# Glint
%patch180 -p0 %{?with_bk:-b .glint-bugfix}

# Intel i740
%patch200 -p0 %{?with_bk:-b .i740-driver-update-cvs-20020617}
# Intel i810/i830
%patch210 -p0 %{?with_bk:-b .i810-driver-update-cvs-20020617}
%patch211 -p0 %{?with_bk:-b .i810-dont-use-empty-for-loops-for-delays}
# Disabled, as it is included in i810-driver-update-cvs-20020617
#%patch212 -p0 %{?with_bk:-b .i810-dont-force-XvMC-on-DRI-users}

# Broken, disabled (actually, requires some new kernel support aparently)
#%patch213 -p0 %{?with_bk:-b .i810-dell-c400-broken-bios-1Mb-limit-workaround}
%patch214 -p0 %{?with_bk:-b .i810-vtswitch-sync-fix}

# mga - Matrox
%patch220 -p0 %{?with_bk:-b .mga-g450-bugfix}
%patch221 -p0 %{?with_bk:-b .mga-g550-cursor}
#%patch222 -p0 %{?with_bk:-b .mga-xinerama-G450-issue}

# Neomagic
%patch230 -p0 %{?with_bk:-b .neomagic-Xv-support}

%patch290 -p0 %{?with_bk:-b .siliconmotion-driver-update-cvs-20020617}

# SiS patches
%patch300 -p0 %{?with_bk:-b .sis-cursor}
%patch301 -p0 %{?with_bk:-b .sis-maxxfbmem-fixup}

# tdfx driver patches
%patch310 -p0 %{?with_bk:-b .tdfx-should-be-2048-not-2046}
%patch313 -p0 %{?with_bk:-b .tdfx-disable-dri-on-16Mb-cards-in-hires}

# Trident
%patch330 -p0 %{?with_bk:-b .trident-driver-update-cvs-20020617}

#####################
%patch402 -p0 %{?with_bk:-b .patch-xfree86.lst}
%patch400 -p0 %{?with_bk:-b .locale-alias-gb18030}
%patch401 -p0 %{?with_bk:-b .locale-locale-tr_TR-bug55736}

%patch405 -p0 %{?with_bk:-b .pagesize-fixup}

%patch422 -p0 %{?with_bk:-b .xset-man-update}

# Patches 800 - 819 xkb keyboard symbol patches
%patch800 -p0 %{?with_bk:-b .xkb-french-canadian}
%patch801 -p1 %{?with_bk:-b .xkb-arabic-support}
%patch803 -p0 %{?with_bk:-b .xkb-is}
%patch804 -p0 %{?with_bk:-b .xkb-fix-deadkey-quotedbl-us_intl}

# MISC new patches go here until I finish the patch reorganization, this
# stuff is likely to move around a lot over the next while (Jun 8, 2001)
# Update: Ok, so it has stayed messy for longer than anticipated.  Not a
# horrible tragedy really.  I haven't lost sleep over it yet or anything.
# Hopefully will reorganize for 4.3.0.  ;o)  (Apr 15, 2002)
%patch1000 -p1 %{?with_bk:-b .patch-drm}
%patch1001 -p1 %{?with_bk:-b .xinerama}
%patch1003 -p0 %{?with_bk:-b .redhat-xdm-pam}

%ifarch alpha
%patch1009 -p0 %{?with_bk:-b .lemming}
%endif

%ifarch ia64
%patch1010 -p1 %{?with_bk:-b .patch-pic}
%endif

%patch1018 -p0 %{?with_bk:-b .xwd-frame-option}
%patch1021 -p1 %{?with_bk:-b .agpgart-load}
# Add support for Japanese 109 key USB keyboard
%patch1023 -p0 %{?with_bk:-b .keyboard-jp109usb}
%patch1025 -p0 %{?with_bk:-b .FIRSTINDEX-breaks-ttmkfdir}
%patch1028 -p0 %{?with_bk:-b .xman-soelim-fix}
%patch1029 -p0 %{?with_bk:-b .glFrustum-fixie}

# FIXME: Disabled because 4.2.0 seems to fix this similarly already.  Remove
# once confirmed.
#%patch1033 -p0 %{?with_bk:-b .keycodes-abnt2}

# S/390, S/390x patches
%ifarch s390 s390x
#%patch3000 -p1 %{?with_bk:-b .patch-s390}
%patch3001 -p1 %{?with_bk:-b .s390-nohardware}
%patch3002 -p1 %{?with_bk:-b .s390-freetype}
%patch3005 -p1 %{?with_bk:-b .s390-cpp}
%endif

# PCI domains backport from CVS.  Only applying to non-mainstream archs that
# require it to work correctly on some hardware.
%ifarch sparc sparc64 ppc ppc64
%patch3100 -p0 %{?with_bk:-b .pci-domains-from-cvs}
%endif

%patch3004 -p1 %{?with_bk:-b .xdm-servonly}

# Chinese i18n - GB18030 locale support patches
%patch4004 -p0 %{?with_bk:-b .gb18030-support}
%patch4005 -p0 %{?with_bk:-b .gb18030-xtt-support}
%patch4006 -p0 %{?with_bk:-b .gb2312-gbk-enc-support}
%patch4009 -p1 %{?with_bk:-b .zh_CN-i18n}
%patch4020 -p0 %{?with_bk:-b .zh_TW-xcin}
%patch4021 -p0 %{?with_bk:-b .gb18030-enc}
%patch4022 -p0 %{?with_bk:-b .euro-support}

%patch4100 -p0 %{?with_bk:-b .Wacom-USB-driver-a25-update}
# FIXME:  Awaiting feedback on this
%patch4104 -p0 %{?with_bk:-b .xfs-chdir-to-root-dir}
%patch4105 -p0 %{?with_bk:-b .xfs-syslog}
# The ancient X startup stipple pattern is no more..
%patch4106 -p0 %{?with_bk:-b .die-ugly-pattern-die-die-die}

%patch4110 -p0 %{?with_bk:-b .nls-en_US-en_GB-ISO8859-15-support}
%patch4111 -p0 %{?with_bk:-b .sessreg-highuid}
%patch4112 -p0 %{?with_bk:-b .startx-hostname-fix}
%patch4113 -p0 %{?with_bk:-b .drm-device-dir-perms}
%patch4117 -p0 %{?with_bk:-b .xman-manconf}
%patch4118 -p0 %{?with_bk:-b .mkfontscale-xcvs-20020618}

%ifarch alpha ia64 ppc64 s390x x86_64
%patch4201 -p0 %{?with_bk:-b .alpha-ia64-_LP64-fix}
%endif

#%patch4300 -p0 %{?with_bk:-b .Xft1-Imake-config}
%patch4302 -p0 %{?with_bk:-b .hostname-stderr}
%patch4303 -p0 %{?with_bk:-b .manpage-document-nomtrr-option}
%patch4304 -p0 %{?with_bk:-b .sysreq}
%patch4305 -p0 %{?with_bk:-b .libICE-remove-stupid-delay}
%patch4306 -p0 %{?with_bk:-b .Xresource-extension}
%patch4307 -p0 %{?with_bk:-b .locale-alias-utf8-euro}
%patch4308 -p0 %{?with_bk:-b .sane-deadacc}
%patch4310 -p0 %{?with_bk:-b .minor-typo}
%patch4311 -p0 %{?with_bk:-b .elf-loader-empty-symbol-table}
%patch4313 -p0 %{?with_bk:-b .im-clientmessage-crash}
%patch4314 -p0 %{?with_bk:-b .libXrender-bugfix}

%patch4500 -p0 %{?with_bk:-b .lbxproxy-SEGV-fix}
%patch4501 -p0 %{?with_bk:-b .xshm-header-file-fix}
%patch4502 -p0 %{?with_bk:-b .vidmode-manpage-fixes}
%if %{WithNewAlanCoxInputDrivers}
%patch4503 -p0 %{?with_bk:-b .new-alan-cox-input-drivers}
%endif
%patch4504 -p0 %{?with_bk:-b .Xrender-crashfix}
%patch4505 -p0 %{?with_bk:-b .bad-mmap-check}
%patch4506 -p0 %{?with_bk:-b .timestamp-monotonicity}
%patch4507 -p0 %{?with_bk:-b .xkb-Xutf8LookupString-fails-in-UTF8-bug78804}
%patch4508 -p0 %{?with_bk:-b .lndir-relative-symlink-fix}
%patch4509 -p0 %{?with_bk:-b .netmouse}
%patch4510 -p0 %{?with_bk:-b .mkfontdir-perms}
%patch4511 -p0 %{?with_bk:-b .xauth-diskfull}
%patch4512 -p0 %{?with_bk:-b .xaa-render-mga-xinerama-issues}
%patch4513 -p0 %{?with_bk:-b .xterm-DECUDK-security-fix}
%patch4514 -p0 %{?with_bk:-b .xterm-can-2003-0063}
%patch4515 -p0 %{?with_bk:-b .makefile-fastbuild}
%patch4516 -p0 %{?with_bk:-b .xterm-session-management-resource}
%patch4520 -p0 -b .libXfont-security-int-overflow-430-backport
%patch4523 -p0 -b .xdm-pam-setcred-security
%patch4524 -p0 -b .libXfont-security-CAN-2004-0083-CAN-2004-0084-CAN-2004-0106-v2-430-backport
%patch4525 -p0 -b .xpmsec
%patch4526 -p0 -b .can0914
%patch4527 -p0 -b .can0914fix
%patch4528 -p0 -b .xpm-security-fix-CAN-2005-0605
%patch4529 -p0 -b .security-CAN-2005-2495.patch

%ifarch ia64
%patch8004 -p0 %{?with_bk:-b .ia64-gcc3.1}
%endif

%patch9000 -p0 -b .redhat-custom-startup
%patch9001 -p0 -b .redhat-bug-report-address-update
%patch9002 -p0 -b .redhat-lock-version
%patch9003 -p0 -b .redhat-version-change-detection

######################################################################
#####  CREATE host.def  ##############################################

# Make sure '-g' is not being passed by RPM via RPM_OPT_FLAGS
RPM_OPT_FLAGS=${RPM_OPT_FLAGS//-g/}

pwd
%if %{rhbsys}
%define rhbuild Red Hat Linux release
%else
%define rhbuild Custom Build
%endif

cat > xc/config/cf/host.def << EOF
#define XFree86CustomVersion "%rhbuild: %{version}-%{release}"
/* Experimental custom messages */
#define XFree86RedHatCustom YES

#define BuilderString "Build Host: %(hostname)\n"
#define LinuxDistribution	LinuxRedHat
    
%if %{DebuggableBuild}
#define BuildDebug		YES
/* #define XFree86Devel		YES */
/* #define DoLoadableServer	NO */
%endif

/* #define HasGcc3      YES (for XFree86 4.3.0) */
#define BootstrapCFlags         $RPM_OPT_FLAGS -pipe
#define DefaultGcc2i386Opt      $RPM_OPT_FLAGS -pipe
#define DefaultGcc2AxpOpt       $RPM_OPT_FLAGS -pipe -Wa,-m21164a
#define DefaultGcc2PpcOpt       $RPM_OPT_FLAGS -pipe
/* FIXME: M-fPIC added temporarily until proper solution can be made.  */
#define DefaultGcc2x86_64Opt    $RPM_OPT_FLAGS -pipe -fPIC

%if %{ParallelBuild}
#define ParallelMakeFlags	-j1
%endif

%if %{with_new_fontconfig_Xft}
/* Fontconfig support */
#define UseFontconfig       YES
#define HasFontconfig       YES
%endif

/* We want includes in /usr/include/GL, so we move them there later on */
#define LinkGLToUsrInclude	NO

/* The OpenGL ABI on Linux standard states libGL and libGLU must be present in
 * /usr/lib either directly, or as symlinks.
 */
#define LinkGLToUsrLib		YES
#define BuildGLwLibrary		YES

#define ForceNormalLib		YES

/* Disable joystick support because it is totally broken in XFree86 4.x, at
   least up to and including 4.1.0.  Use native OS joystick support instead. */
#define JoystickSupport		NO

%ifarch s390 s390x
#define HasAgpGart              NO
%else
#define HasAgpGart              YES
%endif

#define HasPam			YES
#define HasPamMisc		YES
#define HasZlib			YES
/* Use Freetype 2, but we have our own - so don't build it */
#define HasFreetype2		YES
#define Freetype2LibDir		%{_libdir}

#define HasLinuxInput		YES
#define HasMMXSupport		YES
#define Has3DNowSupport		YES
/* Katmai/SSE support enabled experimentally */
#define HasKatmaiSupport	YES

#define XtermWithI18N		YES

%ifarch %{ix86} alpha ia64
#define HasGlide3		YES
#define Glide3LibName		glide3
#define Glide3IncDir		/usr/include/glide3
%endif

#define BuildFonts              YES
#define BuildSpeedoFonts        YES
#define BuildCyrillicFonts      YES
/* #define BuildISO8859_1Fonts     YES */
#define BuildISO8859_2Fonts	YES
#define BuildISO8859_3Fonts	NO
#define BuildISO8859_4Fonts	NO
#define BuildISO8859_5Fonts	BuildCyrillicFonts
/* #define BuildISO8859_6Fonts	NO  */
#define BuildISO8859_7Fonts	YES 
/* #define BuildISO8859_8Fonts	NO  */
#define BuildISO8859_9Fonts	YES
#define BuildISO8859_10Fonts	NO
#define BuildISO8859_11Fonts	NO
#define BuildISO8859_12Fonts	NO
#define BuildISO8859_13Fonts	NO
#define BuildISO8859_14Fonts	NO
#define BuildISO8859_15Fonts	YES

/**************************************************************************/
/* BOTH XIE and PEX were deprecated in XFree86 4.1.0 and are now obsolete */
/* in XFree86 4.2.0, and can probably be removed as it defaults them      */
/* FIXME: Confirm these are safe to remove in default config of X and remove */
#define BuildPhigs      NO
#define BuildPexExt     NO
#define BuildPexLib     NO
#define BuildXIE        NO
#define BuildXIElib     NO
/**************************************************************************/

#define BuildXF86MiscExt        YES
#define BuildHtmlManPages       NO

%if %{with_DRI}
#define BuildXF86DRI                YES
%else
#define BuildXF86DRI                NO
%endif

%ifarch s390 s390x
#define BuildServer                 YES
#define XVirtualFramebufferServer   YES
#define XnestServer                 YES
%endif

/* Kernel DRM modules */
%if %{with_DRM}
#define BuildXF86DRM            YES
%else
#define BuildXF86DRM            NO
%endif

#define BuildXinerama           YES
#define BuildXineramaLibrary    YES

#define BuildXF86DGA            YES


#define UseXserverWrapper       YES
#define UseUtempter             YES
#define UseInternalMalloc       NO
#define UseMatroxHal            NO

#define UseConfDirForXkb           NO
#define UseConfDirForAppDefaults   NO

#undef  DefaultUserPath
#define DefaultUserPath		/usr/local/bin:/bin:/usr/bin
#undef  DefaultSystemPath
#define DefaultSystemPath	/usr/local/sbin:/sbin:/usr/sbin:/bin:/usr/bin

#define AdmDir              /var/log
#define LbxproxyDir         /etc/X11/lbxproxy
#define ProxyManagerDir     /etc/X11/proxymngr
#define ServerConfigDir     /etc/X11/xserver
#define XdmDir              /etc/X11/xdm
#define XConfigDir          /etc/X11
#define XinitDir            /etc/X11/xinit

%ifarch alpha
#define XF86CardDrivers mga nv tga s3virge sis rendition \
			neomagic i740 tdfx cirrus tseng trident chips apm \
			fbdev ati vga v4l glint
%endif

%ifarch ia64
/* Original hardware driver list we've shipped in the past
 * #define XF86CardDrivers mga nv s3virge sis rendition i740 \
 *			tdfx v4l fbdev glint ati vga 
 */

/* Hardware driver list we've pruned */
#define XF86CardDrivers mga nv tdfx v4l fbdev glint ati vga 
%endif

%ifarch ppc ppc64
#define XF86CardDrivers mga glint s3virge sis savage \
                        ati trident chips fbdev \
                        DevelDrivers vga \
                        XF86OSCardDrivers XF86ExtraCardDrivers
%endif

#define DriverManDir    \$(MANSOURCEPATH)4
#define DriverManSuffix 4x /* use just one tab or cpp will die */
#define MiscManDir      \$(MANSOURCEPATH)7
#define MiscManSuffix   7x /* use just one tab or cpp will die */
EOF


##########  BUILD  ##################################################

%build
[ "$RPM_BUILD_ROOT" != "/" ] && rm -rf $RPM_BUILD_ROOT
# Remove unnecessary stuff...  DO NOT MOVE THIS
find . -name CVS -type d | xargs rm -rf
#find . -name .cvsignore -type f |xargs rm -f

%if %{ParallelBuild}
numprocs=$(( $(egrep -c ^cpu[0-9]+ /proc/stat || :) * 2 ))
[ "$numprocs" = "0" ] && numprocs=1
echo "PARALLEL MAKE ENABLED: numprocs=$numprocs"
%else
numprocs=1
%endif

%if %{DebuggableBuild}
makeg World -C xc WORLDOPTS= FAST=1
%else
make World -C xc WORLDOPTS= FAST=1
%endif

%if %{with_ttmkfdir}
{
	pushd ttmkfdir-%{ttmkfdir_ver}
	make OPTFLAGS="$RPM_OPT_FLAGS"
	%makeinstall DESTDIR=$RPM_BUILD_ROOT
	popd
}
%endif


##########  INSTALL  #################################################
%install
# Enable set -x if VerboseBuild is enabled
%{!?VerboseBuild:set -x}

mkdir -p $RPM_BUILD_ROOT{/usr/{include,lib},/etc/{pam.d,security/console.apps}}
install -c -m 644 %{SOURCE3} $RPM_BUILD_ROOT/etc/pam.d/xserver
install -c -m 644 %{SOURCE4} $RPM_BUILD_ROOT/etc/pam.d/xdm
touch $RPM_BUILD_ROOT/etc/security/console.apps/xserver

make -C xc DESTDIR=$RPM_BUILD_ROOT install install.man

# Put GL includes in /usr/include/GL instead of the default location
{
   mkdir -p $RPM_BUILD_ROOT/usr/include/GL
   mv $RPM_BUILD_ROOT%{_x11dir}/include/GL/* $RPM_BUILD_ROOT/usr/include/GL/
   rmdir $RPM_BUILD_ROOT%{_x11dir}/include/GL
}

# Explicitly create X authdir
mkdir -m 700 -p $RPM_BUILD_ROOT/var/lib/xdm/authdir

# We install our own config file for the xfs package
mkdir -p $RPM_BUILD_ROOT/etc/X11/fs
install -c -m 644 %{SOURCE6} $RPM_BUILD_ROOT/etc/X11/fs/config

mkdir -p $RPM_BUILD_ROOT/etc/rc.d/init.d
install -c -m 755 %{SOURCE5} $RPM_BUILD_ROOT/etc/rc.d/init.d/xfs

# FIXME: Can Imake do this?  Fix up symlinks
{
   mkdir -p $RPM_BUILD_ROOT/usr/{bin,include,lib}
   ln -sf ../X11R6/include/X11 $RPM_BUILD_ROOT/usr/include/X11
   ln -sf ../X11R6/include/DPS $RPM_BUILD_ROOT/usr/include/DPS

# This can probably go away in next major release
%ifnarch s390 s390x
   ln -snf ../../../../etc/X11/XF86Config \
      $RPM_BUILD_ROOT%{_x11libdir}/X11/XF86Config
%endif
}

# Backward compatibility symlink
ln -sf ../..%{_x11libdir}/X11/xkb $RPM_BUILD_ROOT/etc/X11

# symlink shared libs
{
    pushd $RPM_BUILD_ROOT%{_x11libdir} &> /dev/null
    for lib in *.so.*; do ln -sf $lib ${lib%.so*}.so ; done
    popd &> /dev/null
}

%if %{with_new_fontconfig_Xft}
# Build and install Xft1 fontconfig lib
# This MUST COME AFTER the "symlink shared libs" section above
{
    pushd xc/lib/Xft1
    xmkmf -a
    make
    make DESTDIR=$RPM_BUILD_ROOT install
    # Remove static lib, development .so, old 1.1 lib, and headers
    rm -f $RPM_BUILD_ROOT%{_x11libdir}/libXft.{so,a,so.1.1}
    rm -f $RPM_BUILD_ROOT%{_x11includedir}/X11/Xft/*
    # Fix symbolic link to point to 1.2 lib, instead of 1.1 lib
#    ln -sf libXft.so.1.2 $RPM_BUILD_ROOT%{_x11libdir}/libXft.so.1
    popd
}
%endif

# Auxilliary font related file processing
{
    FONTDIR=$RPM_BUILD_ROOT%{_x11fontdir}
    # Strip out all fonts.dir files from font directories as they should
    # not be included in the packaging but should be generated at install
    # time instead.
#    rm -f $(find $FONTDIR -name 'fonts.dir') || :
    # "touch" all fonts.dir, fonts.alias, etc files we've got flagged as %ghost
    # but which are not present in the RPM_BUILD_ROOT when RPM looks for files
    touch $FONTDIR/TTF/fonts.alias
    for subdir in 100dpi 75dpi CID local misc Speedo Type1 TTF cyrillic ; do
        rm -f $FONTDIR/$subdir/{encodings,fonts}.dir
        touch $FONTDIR/$subdir/{encodings,fonts}.dir
		chmod 0644 $FONTDIR/$subdir/{encodings,fonts}.dir
    # FIXME: fonts.alias files should be created also possibly
    #    touch $FONTDIR/$subdir/fonts.alias
    done
}

# Make sure all manpage dirs exist and are owned by XFree86-libs
mkdir -m 755 -p $RPM_BUILD_ROOT%{_x11mandir}/man{1,2,3,4,5,6,7,8} || :

# for ghost config file
touch $RPM_BUILD_ROOT/etc/X11/XF86Config
touch $RPM_BUILD_ROOT/etc/X11/XF86Config-4
#chmod 644 $RPM_BUILD_ROOT/etc/X11/{XF86Config,XF86Config-4}

rm -f $RPM_BUILD_ROOT/etc/X11/XftConfig

%if %{with_new_fontconfig_Xft}
cat <<-EOF > $RPM_BUILD_ROOT/etc/X11/XftConfig.README-OBSOLETE
# IMPORTANT NOTICE about XftConfig:
#
# The XftConfig config file has been deprecated and obsoleted by
# /etc/fonts/fonts.conf, which is the new font configuration file for Xft2, and
# is provided by "fontconfig".  A backward compatible Xft1 library is also
# provided which has been converted to use fontconfig also and provide users
# with a single way of configuring client side fonts, while retaining binary
# compatibility. For information on configuring fonts using fontconfig,
# please consult the fontconfig documentation.
EOF
%else
cp %{SOURCE20} $RPM_BUILD_ROOT/etc/X11/XftConfig
%endif


# Fix permissions on locale/common/*.so libs
chmod 755 $RPM_BUILD_ROOT%{_x11libdir}/X11/locale/common/*.so.*

# Add symlinks to libGLU.so and libGLU.so.1 into %{_libdir}
{
    rm -f $RPM_BUILD_ROOT%{_libdir}/libGL.so*
    ln -s ../..%{_x11libdir}/libGL.so.1.2 $RPM_BUILD_ROOT%{_libdir}/libGL.so
    ln -s ../..%{_x11libdir}/libGL.so.1.2 $RPM_BUILD_ROOT%{_libdir}/libGL.so.1
    ln -s ../..%{_x11libdir}/libGLU.so.1.3 $RPM_BUILD_ROOT%{_libdir}/libGLU.so
    ln -s ../..%{_x11libdir}/libGLU.so.1.3 $RPM_BUILD_ROOT%{_libdir}/libGLU.so.1
}

%if %{RHL_80_build}
# Install mkxauth
{
    install -m 755 %{SOURCE23} $RPM_BUILD_ROOT%{_x11bindir}/
    install -m 644 %{SOURCE24} $RPM_BUILD_ROOT%{_x11mandir}/man1/
}
%endif

######################################################################
# DELETE UNWANTED FILES SECTION
#
# error: Installed (but unpackaged) file(s) found:
rm -f $RPM_BUILD_ROOT/etc/X11/rstart/commands/x11r6/@List
rm -f $RPM_BUILD_ROOT/etc/X11/rstart/commands/x11r6/LoadMonitor
rm -f $RPM_BUILD_ROOT/etc/X11/rstart/commands/x11r6/Terminal
rm -f $RPM_BUILD_ROOT/etc/X11/xdm/GiveConsole
rm -f $RPM_BUILD_ROOT/etc/X11/xdm/TakeConsole
rm -f $RPM_BUILD_ROOT/etc/X11/xdm/Xaccess
rm -f $RPM_BUILD_ROOT/etc/X11/xdm/Xsession
rm -f $RPM_BUILD_ROOT/etc/X11/xdm/Xsetup_0
rm -f $RPM_BUILD_ROOT/etc/X11/xdm/libXdmGreet.so.1.0
rm -f $RPM_BUILD_ROOT/etc/X11/xdm/xdm-config
rm -f $RPM_BUILD_ROOT/etc/X11/xinit/xinitrc
rm -f $RPM_BUILD_ROOT/%{_x11bindir}/ccmakedep
%if ! %{with_xf86cfg}
  rm -f $RPM_BUILD_ROOT/%{_x11bindir}/xf86cfg
  rm -f $RPM_BUILD_ROOT/%{_x11mandir}/man1/xf86cfg.1x*
%endif
%if %{with_new_fontconfig_Xft}
  rm -f $RPM_BUILD_ROOT/%{_x11bindir}/xftcache
  rm -f $RPM_BUILD_ROOT/%{_x11mandir}/man1/xftcache.1x*
%endif
rm -f $RPM_BUILD_ROOT/%{_x11bindir}/xmh
rm -f $RPM_BUILD_ROOT/%{_x11libdir}/X11/Cards
rm -f $RPM_BUILD_ROOT/%{_x11libdir}/X11/XF86Config.98
rm -f $RPM_BUILD_ROOT/%{_x11libdir}/X11/XF86Config.eg
rm -f $RPM_BUILD_ROOT/%{_x11mandir}/man1/xmh.1x*
# Other files we're not shipping
rm -f $RPM_BUILD_ROOT%{_x11libdir}/modules/drivers/vmware_drv.o
rm -f $RPM_BUILD_ROOT%{_x11mandir}/man4/vmware.4x*
# FIXME: Fix this by patching Imake configs and submit upstream (hack fix bug #49990)
%ifnarch %{ix86} alpha
  rm -f $RPM_BUILD_ROOT%{_x11libdir}/libxrx.*
%endif
# Delete hardcopy XIE and PEX documentation since both are obsolete now
rm -rf $RPM_BUILD_DIR/%{name}-%{version}/xc/doc/hardcopy/XIE
rm -rf $RPM_BUILD_DIR/%{name}-%{version}/xc/doc/hardcopy/PEX5

######################################################################
# STRIP SECTION
# strip the crap that's safe to strip
%if ! %{DebuggableBuild}
{
    set +x
    # Strip ELF binary executables of debug symbols and .comment section
    for file in $(find $RPM_BUILD_ROOT -type f -perm +0111 -exec file {} \; | \
                    grep -v ' shared object,' | \
                    sed -n -e 's/^\(.*\):[  ]*ELF.*, not stripped/\1/p')
    do
        strip --strip-debug -R .comment $file || :
    done
    # Strip shared libraries of .comment section, and all unneeded symbols
    strip --strip-unneeded -R .comment $RPM_BUILD_ROOT%{_x11libdir}/*.so.* || :
    strip --strip-unneeded -R .comment $RPM_BUILD_ROOT%{_libdir}/*.so.* || :
# Enable this only after testing and verifying it works properly
    strip --strip-unneeded -R .comment $RPM_BUILD_ROOT%{_x11libdir}/X11/locale/common/*.so.* || :
}
%endif


###  DO NOT PUT ANYTHING PAST THIS POINT #############################

######################################################################
#########  SCRIPT SECTION  ###########################################
######################################################################

%triggerpostun -- XFree86
{
%ifarch s390 s390x
  for dir in lbxproxy proxymngr rstart ; do
%else
  for dir in lbxproxy proxymngr rstart xserver ; do
%endif
    if [ -d %{_x11libdir}/X11/$dir ] ; then
      mv -f %{_x11libdir}/X11/$dir /etc/X11/ 2>/dev/null || :
    fi
    # no need to keep this symlink around any longer - pgb 06/28/00
    # these are needed for 3.x servers - notting 07/24/00
    [ ! -L %{_x11libdir}/X11/$dir ] && \
      ln -snf ../../../../etc/X11/$dir %{_x11libdir}/X11/$dir || :
  done
} &> /dev/null || :

%pre
{
  # Remove xie and pex5 from the config files, as they are
  # no longer provided nor supported as of XFree86 4.2.0
  {
    CONFFILE=/etc/X11/XF86Config-4
    if [ -e $CONFFILE ] ; then
      SAVECONF=$CONFFILE.rpmsave
      cp -p $CONFFILE $SAVECONF
      grep -iv 'Load[[:space:]]*"\(pex5\|xie\)"' $SAVECONF > $CONFFILE
    fi
  }
  # Do this for upgrades or installs
  XKB_DIR=/usr/X11R6/lib/X11/xkb/compiled
  if [ ! -L $XKB_DIR -a -d $XKB_DIR ]; then
    mkdir -p /var/lib/xkb
    mv -f $XKB_DIR /var/lib/xkb/
    ln -sf ../../../../../var/lib/xkb $XKB_DIR
  fi
} &> /dev/null || :

%post
{
%ifarch s390 s390x
  for dir in lbxproxy proxymngr rstart ; do
%else
  for dir in lbxproxy proxymngr rstart xserver ; do
%endif
    [ ! -L /usr/X11R6/lib/X11/$dir -a ! -d /usr/X11R6/lib/X11/$dir ] && \
      ln -snf ../../../../etc/X11/$dir /usr/X11R6/lib/X11/$dir || :
  done
} &> /dev/null || :

%pre xdm
{
  # The dir /etc/X11/xdm/authdir moved to /var/lib/xdm/authdir and was replaced
  # by a symlink.  Upgrades from Red Hat Linux 6.x and earlier to any new
  # release with XFree86-4.0.x fail without the following. (fixes bug #32574)
  if [ ! -L /etc/X11/xdm/authdir -a -d /etc/X11/xdm/authdir ]; then
    mkdir -p /var/lib/xdm && \
    mv -f /etc/X11/xdm/authdir /var/lib/xdm/  && \
       ln -sf ../../../var/lib/xdm/authdir /etc/X11/xdm/authdir || :
  fi
} &> /dev/null || :
         
%post libs
{
  grep "^/usr/X11R6/lib$" /etc/ld.so.conf &> /dev/null
  [ $? -ne 0 ] && echo "/usr/X11R6/lib" >> /etc/ld.so.conf

  /sbin/ldconfig
}

%postun libs
{
  if [ "$1" = "0" ]; then
    grep -v "^/usr/X11R6/lib$" /etc/ld.so.conf > /etc/ld.so.conf.new
    # preserve permissions
    cat /etc/ld.so.conf.new > /etc/ld.so.conf
    rm -f /etc/ld.so.conf.new
  fi
  /sbin/ldconfig
}

#######################################################################
%if %{RHL_80_build}
%post Mesa-libGL
{
  grep "^/usr/X11R6/lib$" /etc/ld.so.conf &> /dev/null
  [ $? -ne 0 ] && echo "/usr/X11R6/lib" >> /etc/ld.so.conf
  /sbin/ldconfig
}

%postun Mesa-libGL
{
  /sbin/ldconfig
}

%post Mesa-libGLU
{
  grep "^/usr/X11R6/lib$" /etc/ld.so.conf &> /dev/null
  [ $? -ne 0 ] && echo "/usr/X11R6/lib" >> /etc/ld.so.conf
  /sbin/ldconfig
}

%postun Mesa-libGLU
{
  /sbin/ldconfig
}
%endif
#######################################################################

%verifyscript libs
{
  echo -n "Looking for /usr/X11R6/lib in /etc/ld.so.conf... "
  if ! grep "^/usr/X11R6/lib$" /etc/ld.so.conf > /dev/null; then
    echo "missing"
    echo "/usr/X11R6/lib missing from /etc/ld.so.conf" >&2
  else
    echo "found"
  fi
}

##### xfs scripts ####################################################
%pre xfs
{
  # Conditionalized to work on RHL 7.1 and 7.2 which do not have /sbin/nologin
  LOGINSHELL=$([ -e /sbin/nologin ] && echo /sbin/nologin || echo /bin/false)
  /usr/sbin/useradd -c "X Font Server" -r -s $LOGINSHELL -u 43 -d /etc/X11/fs xfs

} &> /dev/null || :

%post xfs
{
  /sbin/chkconfig --add xfs
# FIXME: What an unmaintainable mess.  ;o) There almost has to be a cleaner
# way of doing this.  If not, it needs to be figured out and documented to
# avoid confusion.
  use_unix=
  for config in /etc/X11/XF86Config /etc/X11/XF86Config-4 ; do
    if [ -f $config ] && grep -q "unix/:" $config &> /dev/null; then
      use_unix=1
    fi
    if [ -f $config ] && grep -q "unix/:-1" $config &> /dev/null; then
      rm -f $config.new $config.rpmsave
      sed "s#unix/:-1#unix/:7100#g" $config > $config.new
      cp -f $config $config.rpmsave
      cat $config.new > $config
      rm -f $config.new
    fi
    if [ -f $config ] && grep -q "unix/:" $config &> /dev/null && \
      grep -q "%{_x11fontdir}/TrueType" $config &> /dev/null ; then \
      sed "s|FontPath[ ]*\"%{_x11fontdir}/TrueType\"|#FontPath \"%{_x11fontdir}/TrueType\"|g" $config > $config.new
      cat $config.new > $config
      rm -f $config.new
    fi
  done
  if [ -n "$use_unix" ] && ! grep -q "no-listen" /etc/X11/fs/config &> /dev/null;then
    echo -e "# don't listen on tcp by default\nno-listen = tcp\n" >> /etc/X11/fs/config
  fi
}

%preun xfs
{
  if [ "$1" = "0" ]; then
    /sbin/chkconfig --del xfs || :
    /usr/sbin/userdel xfs 2>/dev/null || :
    /usr/sbin/groupdel xfs 2>/dev/null || :
    service xfs stop &> /dev/null || :
  fi
}

%postun xfs
{
  if [ "$1" -ge "1" ]; then
    service xfs condrestart &> /dev/null || :
  fi
}

%post base-fonts
{
# FIXME: Make it only run mkfontdir in dirs that have fonts in them.
# Build fonts.dir files for all font dirs in this package.
# (exclude the local and CID dirs as they do not have fonts currently)
  for fontdir in 100dpi 75dpi misc Speedo Type1 ;do
    %__mkfontdir %{_x11fontdir}/$fontdir || :
  done
  /usr/sbin/chkfontpath -qa %{_x11fontdir}/75dpi:unscaled || :
  /usr/sbin/chkfontpath -qa %{_x11fontdir}/100dpi:unscaled || :
  /usr/sbin/chkfontpath -qa %{_x11fontdir}/misc:unscaled || :
  /usr/sbin/chkfontpath -qa %{_x11fontdir}/Speedo || :
  /usr/sbin/chkfontpath -qa %{_x11fontdir}/Type1 || :
# Only run fc-cache in the Type1 dir, gzipped pcf's take forever
  %__fccache %{_x11fontdir}/Type1 || :
} &> /dev/null || :

%postun base-fonts
# Rebuild fonts.dir when uninstalling package. (exclude the local, CID dirs)
{
  if [ "$1" = "0" ]; then
    for fontdir in 100dpi 75dpi misc Speedo Type1 ;do
      %__mkfontdir %{_x11fontdir}/$fontdir || :
    done
# Only run fc-cache in the Type1 dir, gzipped pcf's take forever
    %__fccache %{_x11fontdir}/Type1 || :
  fi
} &> /dev/null || :

%post truetype-fonts
{
  FONTDIR=%{_x11fontdir}/TTF
  ttmkfdir -d $FONTDIR -o $FONTDIR/fonts.scale
  %__mkfontdir $FONTDIR
  %__fccache $FONTDIR
  /usr/sbin/chkfontpath -q -a $FONTDIR
} &> /dev/null || :
 
%postun truetype-fonts
{
  FONTDIR=%{_x11fontdir}/TTF
  if [ "$1" = "0" ]; then
    ttmkfdir -d $FONTDIR -o $FONTDIR/fonts.scale
    %__mkfontdir $FONTDIR
    %__fccache $FONTDIR
  fi
} &> /dev/null || :

%post 75dpi-fonts
{
    %__mkfontdir %{_x11fontdir}/75dpi
#    %__fccache %{_x11fontdir}/75dpi
    /usr/sbin/chkfontpath -q -a %{_x11fontdir}/75dpi:unscaled
} &> /dev/null || :

%post 100dpi-fonts
{
    %__mkfontdir %{_x11fontdir}/100dpi
#    %__fccache %{_x11fontdir}/100dpi
    /usr/sbin/chkfontpath -q -a %{_x11fontdir}/100dpi:unscaled
} &> /dev/null || :

%post ISO8859-2-75dpi-fonts
{
    %__mkfontdir %{_x11fontdir}/75dpi
#    %__fccache %{_x11fontdir}/75dpi
    /usr/sbin/chkfontpath -q -a %{_x11fontdir}/75dpi:unscaled
} &> /dev/null || :

%post ISO8859-2-100dpi-fonts
{
    %__mkfontdir %{_x11fontdir}/100dpi
#    %__fccache %{_x11fontdir}/100dpi
    /usr/sbin/chkfontpath -q -a %{_x11fontdir}/100dpi:unscaled
} &> /dev/null || :

%post ISO8859-9-75dpi-fonts
{
    %__mkfontdir %{_x11fontdir}/75dpi
#    %__fccache %{_x11fontdir}/75dpi
    /usr/sbin/chkfontpath -q -a %{_x11fontdir}/75dpi:unscaled
} &> /dev/null || :

%post ISO8859-9-100dpi-fonts
{
    %__mkfontdir %{_x11fontdir}/100dpi
#    %__fccache %{_x11fontdir}/100dpi
    /usr/sbin/chkfontpath -q -a %{_x11fontdir}/100dpi:unscaled
} &> /dev/null || :

%post ISO8859-15-75dpi-fonts
{
    %__mkfontdir %{_x11fontdir}/75dpi
#    %__fccache %{_x11fontdir}/75dpi
    /usr/sbin/chkfontpath -q -a %{_x11fontdir}/75dpi:unscaled
} &> /dev/null || :
    
%post ISO8859-15-100dpi-fonts
{
    %__mkfontdir %{_x11fontdir}/100dpi
#    %__fccache %{_x11fontdir}/100dpi
    /usr/sbin/chkfontpath -q -a %{_x11fontdir}/100dpi:unscaled
} &> /dev/null || :

%post cyrillic-fonts
{
    %__mkfontdir %{_x11fontdir}/cyrillic
#    %__fccache %{_x11fontdir}/cyrillic
    /usr/sbin/chkfontpath -q -a %{_x11fontdir}/cyrillic:unscaled
} &> /dev/null || :

%postun 75dpi-fonts
{
  if [ "$1" = "0" ]; then
    %__mkfontdir %{_x11fontdir}/75dpi
#    %__fccache %{_x11fontdir}/75dpi
  fi
} &> /dev/null || :

%postun 100dpi-fonts
{
  if [ "$1" = "0" ]; then
    %__mkfontdir %{_x11fontdir}/100dpi
#    %__fccache %{_x11fontdir}/100dpi
  fi
} &> /dev/null || :

%postun ISO8859-2-75dpi-fonts
{
  if [ "$1" = "0" ]; then
    %__mkfontdir %{_x11fontdir}/75dpi
#    %__fccache %{_x11fontdir}/75dpi
  fi
}

%postun ISO8859-2-100dpi-fonts
{
  if [ "$1" = "0" ]; then
    %__mkfontdir %{_x11fontdir}/100dpi
#    %__fccache %{_x11fontdir}/100dpi
  fi
} &> /dev/null || :

%postun ISO8859-9-75dpi-fonts
{
  if [ "$1" = "0" ]; then
    %__mkfontdir %{_x11fontdir}/75dpi
#    %__fccache %{_x11fontdir}/75dpi
  fi
} &> /dev/null || :

%postun ISO8859-9-100dpi-fonts
{
  if [ "$1" = "0" ]; then
    %__mkfontdir %{_x11fontdir}/100dpi
#    %__fccache %{_x11fontdir}/100dpi
  fi
} &> /dev/null || :

%postun ISO8859-15-75dpi-fonts
{
  if [ "$1" = "0" ]; then
    %__mkfontdir %{_x11fontdir}/75dpi
#    %__fccache %{_x11fontdir}/75dpi
  fi
} &> /dev/null || :

%postun ISO8859-15-100dpi-fonts
{
  if [ "$1" = "0" ]; then
    %__mkfontdir %{_x11fontdir}/100dpi
#    %__fccache %{_x11fontdir}/100dpi
  fi
} &> /dev/null || :

%postun cyrillic-fonts
{
  if [ "$1" = "0" ]; then
    %__mkfontdir %{_x11fontdir}/cyrillic
#    %__fccache %{_x11fontdir}/cyrillic
  fi
} &> /dev/null || :


########## FILES SECTION #############################################
#
# IMPORTANT NOTE:  All fonts.dir, fonts.scale files are created during package
# installation time, and as such need to be flagged as ghost files, also their
# content is variable while installed as new fonts can be installed in the same
# directories potentially at any time, so they need to be flagged with %verify
# also.  They should not be flagged with %config however as they are not
# considered to be user editable, and should not be preserved.  Any case of a
# user wanting to edit these files by hand for ANY REASON, indicates a bug
# in the mkfontdir/ttmkfdir tools which should be fixed instead.
#
# encodings.dir files also should be flagged with %ghost and %verify, since
# the same applies to them, the only difference is that it may not actually
# exist unless the user creates it for some reason.  These files are deprecated
# and will be removed in a future upstream release entirely.
#
# fonts.alias should be flagged with %verify as it is modifyable.  For directories
# in which we supply a fonts.alias file, it should be flagged %config(noreplace)
# and for dirs which we do not supply one it should be flagged as both %ghost
# and %config(noreplace) so that the files are actually owned by the package,
# just not supplied by default, and they are preserved across upgrades.

%files
%defattr(-,root,root)
%dir /etc/X11/lbxproxy
%config /etc/X11/lbxproxy/AtomControl
%dir /etc/X11/proxymngr
%config /etc/X11/proxymngr/pmconfig
# rstart crapola
%dir /etc/X11/rstart
%dir /etc/X11/rstart/commands
/etc/X11/rstart/commands/@List
/etc/X11/rstart/commands/ListContexts
/etc/X11/rstart/commands/ListGenericCommands
/etc/X11/rstart/commands/x
/etc/X11/rstart/commands/x11
%dir /etc/X11/rstart/commands/x11r6
%dir /etc/X11/rstart/contexts
/etc/X11/rstart/contexts/@List
/etc/X11/rstart/contexts/default
/etc/X11/rstart/contexts/x
/etc/X11/rstart/contexts/x11
%dir /etc/X11/rstart/contexts/x11r6
%config /etc/X11/rstart/config
/etc/X11/rstart/rstartd.real

%ifnarch s390 s390x
%dir /etc/X11/xinit
# %config /etc/X11/xinit/xinitrc We have a separate xinitrc package
%dir /etc/X11/xserver
%config /etc/X11/xserver/*
%ghost %config(missingok,noreplace) %verify(not md5 size mtime) /etc/X11/XF86Config
%endif
%ghost %config(missingok,noreplace) %verify(not md5 size mtime) /etc/X11/XF86Config-4
%dir /etc/X11/xsm
%config /etc/X11/xsm/system.xsm
# Changed back to 'noreplace' to fix bug #53103
%if %{with_new_fontconfig_Xft}
# XftConfig is no longer present or used
/etc/X11/XftConfig.README-OBSOLETE
%else
%config(noreplace) /etc/X11/XftConfig
%endif

%dir %{_x11libdir}/X11/etc
%ghost %{_x11libdir}/X11/lbxproxy
%ghost %{_x11libdir}/X11/proxymngr
%ghost %{_x11libdir}/X11/rstart
%ifnarch s390 s390x
%ghost %{_x11libdir}/X11/xserver
%endif
%dir %{_x11libdir}/X11/xkb
%config %{_x11libdir}/X11/app-defaults/*
%dir /var/lib/xkb
%config %attr(0644,root,root) /etc/pam.d/xserver
%config(missingok) /etc/security/console.apps/xserver
/var/lib/xkb/README
# SuperProbe is obsolete %{_x11bindir}/SuperProbe
%ifnarch s390 s390x
%{_x11bindir}/X
%attr(4711,root,root) %{_x11bindir}/XFree86
%endif
%{_x11bindir}/Xmark
%{_x11bindir}/Xprt
%ifnarch s390 s390x ppc ppc64
%{_x11bindir}/pcitweak
%{_x11bindir}/scanpci
%endif
%{_x11bindir}/appres
%{_x11bindir}/atobm
%{_x11bindir}/bdftopcf
%{_x11bindir}/bdftruncate.pl
%{_x11bindir}/bitmap
%{_x11bindir}/bmtoa
%{_x11bindir}/cleanlinks
%{_x11bindir}/dga
%{_x11bindir}/dpsexec
%{_x11bindir}/dpsinfo
%{_x11bindir}/editres
%{_x11bindir}/iceauth
%{_x11bindir}/lbxproxy
%{_x11bindir}/lndir
%{_x11bindir}/luit
%{_x11bindir}/makepsres
%{_x11bindir}/makestrs
%{_x11bindir}/mergelib
%{_x11bindir}/mkcfm
%{_x11bindir}/mkdirhier
%{_x11bindir}/proxymngr
%{_x11bindir}/resize
%{_x11bindir}/revpath
%{_x11bindir}/rstart
%{_x11bindir}/rstartd
%{_x11bindir}/sessreg
%{_x11bindir}/setxkbmap
%{_x11bindir}/showrgb
%{_x11bindir}/smproxy
%ifnarch s390 s390x
%{_x11bindir}/startx
%endif
%{_x11bindir}/texteroids
%{_x11bindir}/uxterm
%if %{RHL_73_build}
%{_x11bindir}/xauth
%endif
%{_x11bindir}/xcmsdb
%{_x11bindir}/xconsole
%{_x11bindir}/xcutsel
%{_x11bindir}/xdpyinfo
%ifnarch s390 s390x
%{_x11bindir}/xf86config
%endif
%{_x11bindir}/xfindproxy
%if ! %{with_new_fontconfig_Xft}
%{_x11bindir}/xftcache
%endif
%{_x11bindir}/xfwp
%{_x11bindir}/xgamma
%{_x11bindir}/xhost
%ifnarch s390 s390x
%{_x11bindir}/xinit
%endif
%{_x11bindir}/xkbbell
%{_x11bindir}/xkbcomp
%{_x11bindir}/xkbevd
%{_x11bindir}/xkbprint
%{_x11bindir}/xkbvleds
%{_x11bindir}/xkbwatch
%{_x11bindir}/xlsatoms
%{_x11bindir}/xlsclients
%{_x11bindir}/xlsfonts
# xmh is obsolete %{_x11bindir}/xmh
%{_x11bindir}/xmodmap
%{_x11bindir}/xon
%{_x11bindir}/xprop
%{_x11bindir}/xrandr
%{_x11bindir}/xrdb
%{_x11bindir}/xrefresh
%{_x11bindir}/xset
%{_x11bindir}/xsetmode
%{_x11bindir}/xsetpointer
%{_x11bindir}/xsetroot
%{_x11bindir}/xsm
%{_x11bindir}/xstdcmap
%{_x11bindir}/xterm
%{_x11bindir}/xtrapchar
%{_x11bindir}/xtrapin
%{_x11bindir}/xtrapinfo
%{_x11bindir}/xtrapout
%{_x11bindir}/xtrapproto
%{_x11bindir}/xtrapreset
%{_x11bindir}/xtrapstats
%{_x11bindir}/xvidtune
%{_x11bindir}/xwd
%{_x11bindir}/xwud
%ifnarch s390 s390x
%dir %{_x11libdir}/X11/doc
%{_x11libdir}/X11/doc/*
%endif

# XFree86 server modules #################################################
%ifnarch s390 s390x
%dir %{_x11libdir}/modules
%{_x11libdir}/modules/*.a
%endif
%ifarch %{ix86} alpha
%{_x11libdir}/modules/*.uc
%endif
%ifnarch s390 s390x
%dir %{_x11libdir}/modules/codeconv
%{_x11libdir}/modules/codeconv/*
%dir %{_x11libdir}/modules/extensions
%{_x11libdir}/modules/extensions/*
%dir %{_x11libdir}/modules/fonts
%{_x11libdir}/modules/fonts/*
%dir %{_x11libdir}/modules/input
%{_x11libdir}/modules/input/*
%dir %{_x11libdir}/modules/linux
%{_x11libdir}/modules/linux/*
%endif
%if %{with_DRI}
%dir %{_x11libdir}/modules/dri
%{_x11libdir}/modules/dri/*
%endif
%ifnarch s390 s390x
%dir %{_x11libdir}/modules/drivers
%{_x11libdir}/modules/drivers/*
%endif

# Provided by the Xconfigurator package in RHL 7.x, and in the hwdata
# currently in rawhide.
#%{_x11libdir}/X11/Cards
# This should probably be moved to Xconfigurator also
%ifnarch s390 s390x
%{_x11libdir}/X11/Options
%{_x11libdir}/X11/XF86Config
# Junk config file for PC98
#%{_x11libdir}/X11/XF86Config.98
#%{_x11libdir}/X11/XF86Config.eg
%endif
%if ! %{with_new_fontconfig_Xft}
%{_x11libdir}/X11/XftConfig
%endif

%dir %{_x11libdir}/X11/app-defaults
%ifnarch s390 s390x
%{_x11libdir}/X11/etc/*
%{_x11libdir}/X11/xinit
%endif
%{_x11libdir}/X11/xkb/*
/etc/X11/xkb
%dir %{_x11libdir}/X11/x11perfcomp
%{_x11libdir}/X11/x11perfcomp/*
%{_x11libdir}/X11/xsm
%ifnarch s390 s390x
# SuperProbe is obsolete %{_x11mandir}/man1/SuperProbe.1*
%{_x11mandir}/man1/XFree86.1*
%endif
%{_x11mandir}/man1/Xserver.1*
%{_x11mandir}/man1/Xmark.1*
%{_x11mandir}/man1/appres.1*
%{_x11mandir}/man1/atobm.1*
%{_x11mandir}/man1/bdftopcf.1*
%{_x11mandir}/man1/bitmap.1*
%{_x11mandir}/man1/bmtoa.1*
%{_x11mandir}/man1/dga.1*
%{_x11mandir}/man1/dpsexec.1*
%{_x11mandir}/man1/dpsinfo.1*
%{_x11mandir}/man1/editres.1*
%{_x11mandir}/man1/iceauth.1*
%{_x11mandir}/man1/lbxproxy.1*
%ifarch %{ix86} alpha
%{_x11mandir}/man1/libxrx.1*
%endif
%{_x11mandir}/man1/lndir.1*
%{_x11mandir}/man1/luit.1*
%{_x11mandir}/man1/makedepend.1*
%{_x11mandir}/man1/makepsres.1*
%{_x11mandir}/man1/makestrs.1*
%{_x11mandir}/man1/mkcfm.1*
%{_x11mandir}/man1/mkdirhier.1*
%{_x11mandir}/man1/oclock.1*
%ifnarch s390 s390x ppc ppc64
%{_x11mandir}/man1/pcitweak.1*
%{_x11mandir}/man1/scanpci.1*
%endif
%{_x11mandir}/man1/proxymngr.1*
%{_x11mandir}/man1/resize.1*
%{_x11mandir}/man1/revpath.1*
%{_x11mandir}/man1/rstart.1*
%{_x11mandir}/man1/rstartd.1*
%{_x11mandir}/man1/sessreg.1*
%{_x11mandir}/man1/setxkbmap.1*
%{_x11mandir}/man1/showrgb.1*
%{_x11mandir}/man1/smproxy.1*
%ifnarch s390 s390x
%{_x11mandir}/man1/startx.1*
%endif
%{_x11mandir}/man1/texteroids.1*
%if %{RHL_73_build}
%{_x11mandir}/man1/xauth.1*
%endif
%{_x11mandir}/man1/xcmsdb.1*
%{_x11mandir}/man1/xconsole.1*
%{_x11mandir}/man1/xcutsel.1*
%{_x11mandir}/man1/xdpyinfo.1*
%ifnarch s390 s390x
%{_x11mandir}/man1/xf86config.1*
%endif
%{_x11mandir}/man1/xfindproxy.1*
%if ! %{with_new_fontconfig_Xft}
%{_x11mandir}/man1/xftcache.1*
%endif
%{_x11mandir}/man1/xfwp.1*
%{_x11mandir}/man1/xgamma.1*
%{_x11mandir}/man1/xhost.1*
%ifnarch s390 s390x
%{_x11mandir}/man1/xinit.1*
%endif
%{_x11mandir}/man1/xkbcomp.1*
%{_x11mandir}/man1/xkbevd.1*
%{_x11mandir}/man1/xkbprint.1*
%{_x11mandir}/man1/xkill.1*
%{_x11mandir}/man1/xlogo.1*
%{_x11mandir}/man1/xlsatoms.1*
%{_x11mandir}/man1/xlsclients.1*
%{_x11mandir}/man1/xlsfonts.1*
# xmh is obsolete %{_x11mandir}/man1/xmh.1*
%{_x11mandir}/man1/xmodmap.1*
%{_x11mandir}/man1/xon.1*
%{_x11mandir}/man1/xprop.1*
%{_x11mandir}/man1/xrandr.1*
%{_x11mandir}/man1/xrdb.1*
%{_x11mandir}/man1/xrefresh.1*
%{_x11mandir}/man1/xset.1*
%{_x11mandir}/man1/xsetmode.1*
%{_x11mandir}/man1/xsetpointer.1*
%{_x11mandir}/man1/xsetroot.1*
%{_x11mandir}/man1/xsm.1*
%{_x11mandir}/man1/xstdcmap.1*
%{_x11mandir}/man1/xterm.1*
%{_x11mandir}/man1/xtrap.1*
%{_x11mandir}/man1/xtrapchar.1*
%{_x11mandir}/man1/xtrapin.1*
%{_x11mandir}/man1/xtrapinfo.1*
%{_x11mandir}/man1/xtrapout.1*
%{_x11mandir}/man1/xtrapproto.1*
%{_x11mandir}/man1/xtrapreset.1*
%{_x11mandir}/man1/xtrapstats.1*
%{_x11mandir}/man1/xvidtune.1*
%{_x11mandir}/man1/xwd.1*
%{_x11mandir}/man1/xwud.1*
%ifnarch s390 s390x
%{_x11mandir}/man4/*
%{_x11mandir}/man5/*
%endif
%{_x11mandir}/man7/*

### XFree86-tools ####################################################
%files tools
%defattr(-,root,root)
%{_x11bindir}/beforelight
%{_x11bindir}/glxinfo
%{_x11bindir}/glxgears
%{_x11bindir}/ico
%{_x11bindir}/listres
%{_x11bindir}/mkhtmlindex
%{_x11bindir}/oclock
%{_x11bindir}/showfont
%{_x11bindir}/ucs2any.pl
%{_x11bindir}/viewres
%{_x11bindir}/x11perf
%{_x11bindir}/x11perfcomp
%{_x11bindir}/xbiff
%{_x11bindir}/xcalc
%{_x11bindir}/xclipboard
%{_x11bindir}/xclock
%{_x11bindir}/xditview
%{_x11bindir}/xedit
%{_x11bindir}/xev
%{_x11bindir}/xeyes
%{_x11bindir}/xfd
%{_x11bindir}/xfontsel
%{_x11bindir}/xgc
# XIE is obsolete %{_x11bindir}/xieperf
# xload has no need to be SUID root
%attr(755,root,root) %{_x11bindir}/xload
%{_x11bindir}/xmag
%{_x11bindir}/xman
%{_x11bindir}/xmessage
%{_x11bindir}/xvinfo
%{_x11bindir}/xwininfo
%{_x11bindir}/xlogo
%{_x11bindir}/xkill
%dir %{_x11libdir}/X11/xedit
%dir %{_x11libdir}/X11/xedit/lisp
%{_x11libdir}/X11/xedit/lisp/fun.lsp
%{_x11libdir}/X11/xman.help
%{_x11mandir}/man1/beforelight.1*
%{_x11mandir}/man1/glxinfo.1*
%{_x11mandir}/man1/glxgears.1*
%{_x11mandir}/man1/ico.1*
%{_x11mandir}/man1/listres.1*
%{_x11mandir}/man1/showfont.1*
%{_x11mandir}/man1/viewres.1*
%{_x11mandir}/man1/x11perf.1*
%{_x11mandir}/man1/x11perfcomp.1*
%{_x11mandir}/man1/xbiff.1*
%{_x11mandir}/man1/xcalc.1*
%{_x11mandir}/man1/xclipboard.1*
%{_x11mandir}/man1/xclock.1*
%{_x11mandir}/man1/xditview.1*
%{_x11mandir}/man1/xedit.1*
%{_x11mandir}/man1/xev.1*
%{_x11mandir}/man1/xeyes.1*
%{_x11mandir}/man1/xfd.1*
%{_x11mandir}/man1/xfontsel.1*
%{_x11mandir}/man1/xgc.1*
# XIE is obsolete %{_x11mandir}/man1/xieperf.1*
%{_x11mandir}/man1/xload.1*
%{_x11mandir}/man1/xmag.1*
%{_x11mandir}/man1/xman.1*
%{_x11mandir}/man1/xmessage.1*
%{_x11mandir}/man1/xvinfo.1*
%{_x11mandir}/man1/xwininfo.1*

### XFree86-xauth ####################################################
%if %{RHL_80_build}
%files xauth
%defattr(-,root,root)
%{_x11bindir}/xauth
%{_x11bindir}/mkxauth
%{_x11mandir}/man1/xauth.1*
%{_x11mandir}/man1/mkxauth.1*
%endif

%files xfs
%defattr(-,root,root)
%dir /etc/X11/fs
# Changed back to 'noreplace' to fix bug #53103
%config(noreplace) %verify(not md5 size mtime) /etc/X11/fs/config
%config /etc/rc.d/init.d/xfs
%{_x11bindir}/xfsinfo
%{_x11bindir}/fslsfonts
%{_x11bindir}/fstobdf
%{_x11bindir}/xfs
%{_x11libdir}/X11/fs
%{_x11mandir}/man1/xfs.1*
%{_x11mandir}/man1/xfsinfo.1*
%{_x11mandir}/man1/fslsfonts.1*
%{_x11mandir}/man1/fstobdf.1*

# Please do not put files into the font-utils package that are linked to any
# X libraries.  The intent being to not need X installed to get mkfontdir and
# ttmkfdir.
%files font-utils
%defattr(-,root,root)
%{_x11bindir}/mkfontdir
%{_x11mandir}/man1/mkfontdir.1*
%if %{RHL_80_build}
%{_x11bindir}/mkfontscale
%{_x11mandir}/man1/mkfontscale.1*
%endif
%if %{with_ttmkfdir}
/usr/bin/ttmkfdir
%endif

%files twm
%defattr(-,root,root)
%dir /etc/X11/twm
%config /etc/X11/twm/system.twmrc
%{_x11bindir}/twm
%{_x11libdir}/X11/twm
%{_x11mandir}/man1/twm.1*

%files xdm
%defattr(-,root,root)
%dir /etc/X11/xdm
/etc/X11/xdm/authdir
%dir /etc/X11/xdm/pixmaps
/etc/X11/xdm/pixmaps/*
# We ship these in the xinitrc package
#%config /etc/X11/xdm/GiveConsole
#%config /etc/X11/xdm/TakeConsole
#%config /etc/X11/xdm/Xaccess
%config /etc/X11/xdm/Xservers
# We ship these in the xinitrc package
#/etc/X11/xdm/Xsession
#/etc/X11/xdm/Xsetup_0
%config /etc/X11/xdm/Xresources
%config /etc/X11/xdm/Xwilling
# FIXME: chooser is an ELF executable, should not be in /etc really
/etc/X11/xdm/chooser
%config  %attr(0644,root,root) /etc/pam.d/xdm
%{_x11bindir}/xdm
%{_x11libdir}/X11/xdm
%{_x11mandir}/man1/xdm.1*
%dir /var/lib/xdm
%dir %attr(0700,root,root) /var/lib/xdm/authdir


%files devel
%defattr(-,root,root)
# Changed GL include dir, on Mar 17, 2002 for 4.2.0-6.48 release
%dir /usr/include/GL
/usr/include/GL/*
# These three are here for documentation only.  They're picked up below by
# the glob %{_x11libdir}/*.so
#%{_x11libdir}/libGL.so
#%{_x11libdir}/libGLU.so
#%{_x11libdir}/libOSMesa.so
#/usr/include/GL
%{_libdir}/libGL.so
%{_libdir}/libGLU.so
%dir %{_x11dir}/include/DPS
%dir %{_x11dir}/include/X11
%dir %{_x11dir}/include/X11/ICE
# PEX is obsolete %dir %{_x11dir}/include/X11/PEX5
%dir %{_x11dir}/include/X11/PM
%dir %{_x11dir}/include/X11/SM
%dir %{_x11dir}/include/X11/Xaw
%dir %{_x11dir}/include/X11/Xft
%dir %{_x11dir}/include/X11/Xmu
%dir %{_x11dir}/include/X11/bitmaps
%{_x11dir}/include/X11/bitmaps/*
%ifnarch s390 s390x
%dir %{_x11dir}/include/X11/pixmaps
%{_x11dir}/include/X11/pixmaps/*
%endif
%dir %{_x11dir}/include/X11/extensions
%{_x11dir}/include/X11/extensions/*.h
%dir %{_x11dir}/include/X11/fonts
%{_x11dir}/include/X11/fonts/*.h
%dir %{_x11dir}/include/X11/fonts/codeconv
%{_x11dir}/include/X11/fonts/codeconv/*.h
%dir %{_x11libdir}/X11/config
%{_x11bindir}/cxpm
%{_x11bindir}/gccmakedep
%{_x11bindir}/imake
%{_x11bindir}/makedepend
%{_x11bindir}/makeg
%{_x11bindir}/pswrap
%{_x11bindir}/rman
%{_x11bindir}/sxpm
%{_x11bindir}/xmkmf
%ifnarch s390 s390x
%{_x11dir}/include/*.h
%endif
%{_x11dir}/include/DPS/*.h
%{_x11dir}/include/X11/*.h
%{_x11dir}/include/X11/ICE/*.h
# PEX is obsolete %{_x11dir}/include/X11/PEX5/*.h
%{_x11dir}/include/X11/PM/*.h
%{_x11dir}/include/X11/SM/*.h
%{_x11dir}/include/X11/Xaw/*
%if ! %{with_new_fontconfig_Xft}
%{_x11dir}/include/X11/Xft/*
%endif
%{_x11dir}/include/X11/Xmu/*.h
%{_x11libdir}/*.a
%{_x11libdir}/*.so
%{_x11libdir}/X11/config/*
/usr/include/X11
/usr/include/DPS
%{_x11mandir}/man1/cxpm.1*
%{_x11mandir}/man1/imake.1*
%{_x11mandir}/man1/makeg.1*
%{_x11mandir}/man1/pswrap.1*
%{_x11mandir}/man1/rman.1*
%{_x11mandir}/man1/sxpm.1*
%{_x11mandir}/man1/xmkmf.1*
%{_x11mandir}/man3/*

%files libs
%defattr(-,root,root)
# All manpage dirs owned by libs package to guarantee they are owned by some
# installed package because everything pretty much depends on libs being there
%dir %{_x11mandir}
%dir %{_x11mandir}/man1
%dir %{_x11mandir}/man2
%dir %{_x11mandir}/man3
%dir %{_x11mandir}/man4
%dir %{_x11mandir}/man5
%dir %{_x11mandir}/man6
%dir %{_x11mandir}/man7
%dir %{_x11mandir}/man8
%dir %{_x11libdir}/X11
%dir %{_x11libdir}/X11/locale
%{_x11libdir}/X11/locale/*
# The files (XErrorDB, XKeysymDB, rgb.txt) moved from XFree86 to XFree86-libs
# subpackage in 4.2.1-10 while duplicating an enhancement request made to
# XFree86 4.1.0-43 for AS 2.1 - bugzilla bug (#79488)
%{_x11libdir}/X11/XErrorDB
%{_x11libdir}/X11/XKeysymDB
%{_x11libdir}/X11/rgb.txt
# Shared libraries:  %{_x11libdir}/lib*.so.* might be better in the long run
# except for arch specific stuff, but it shouldn't be built in the first place.
%if %{with_DRI}
%{_x11libdir}/libOSMesa.so.*
%endif
%{_x11libdir}/libICE.so.*
# PEX is obsolete %{_x11libdir}/libPEX5.so.*
%{_x11libdir}/libSM.so.*
%{_x11libdir}/libX11.so.*
# XIE is obsolete %{_x11libdir}/libXIE.so.*
%{_x11libdir}/libXTrap.so.*
%{_x11libdir}/libXaw.so.*
%{_x11libdir}/libXext.so.*
%{_x11libdir}/libXfont.so.*
# Make sure proper libXft.so.* files get included
%{_x11libdir}/libXft.so.1
%if ! %{with_new_fontconfig_Xft}
%{_x11libdir}/libXft.so.1.1
%else
%{_x11libdir}/libXft.so.1.2
%endif
%{_x11libdir}/libXi.so.*
%{_x11libdir}/libXmu.so.*
%{_x11libdir}/libXmuu.so.*
%{_x11libdir}/libXp.so.*
%{_x11libdir}/libXpm.so.*
%{_x11libdir}/libXrandr.so.*
%{_x11libdir}/libXrender.so.*
%{_x11libdir}/libXt.so.*
%{_x11libdir}/libXtst.so.*
%{_x11libdir}/libdps.so.*
%{_x11libdir}/libdpstk.so.*
%{_x11libdir}/libpsres.so.*
%ifarch %{ix86} alpha
%{_x11libdir}/libxrx.so.*
%endif
# In RHL 7.3, libGL and libGLU are in XFree86-libs, but in RHL 8.0, they are
# in XFree86-Mesa-libGL and XFree86-Mesa-libGLU
%if %{RHL_73_build}
%{_x11libdir}/libGL.so.*
%{_libdir}/libGL.so.*
%{_x11libdir}/libGLU.so.*
%{_libdir}/libGLU.so.*
%endif

### XFree86-Mesa-libGL ###############################################
%if %{RHL_80_build}
%files Mesa-libGL
%defattr(-,root,root)
%{_x11libdir}/libGL.so.*
%{_libdir}/libGL.so.*
### XFree86-Mesa-libGLU ##############################################
%files Mesa-libGLU
%defattr(-,root,root)
%{_x11libdir}/libGLU.so.*
%{_libdir}/libGLU.so.*
%endif

######################################################################
# FONT SUBPACKAGES
### XFree86-base-fonts ###############################################
%files base-fonts
%defattr(-,root,root)
%dir %{_x11fontdir}
# base 100dpi fonts
%dir %{_x11fontdir}/100dpi
%ghost %verify(not md5 size mtime) %{_x11fontdir}/100dpi/encodings.dir
%config(noreplace) %verify(not md5 size mtime) %{_x11fontdir}/100dpi/fonts.alias
%ghost %verify(not md5 size mtime) %{_x11fontdir}/100dpi/fonts.dir
# base 75dpi fonts
%dir %{_x11fontdir}/75dpi
%ghost %verify(not md5 size mtime) %{_x11fontdir}/75dpi/encodings.dir
%config(noreplace) %verify(not md5 size mtime) %{_x11fontdir}/75dpi/fonts.alias
%ghost %verify(not md5 size mtime) %{_x11fontdir}/75dpi/fonts.dir
# base CID fonts
%dir %{_x11fontdir}/CID
%ghost %verify(not md5 size mtime) %{_x11fontdir}/CID/encodings.dir
%ghost %verify(not md5 size mtime) %{_x11fontdir}/CID/fonts.dir
%ghost %verify(not md5 size mtime) %{_x11fontdir}/CID/fonts.scale
# Encoding files
%dir %{_x11fontdir}/encodings
%{_x11fontdir}/encodings/*
#%dir %{_x11fontdir}/encodings/large
#%{_x11fontdir}/encodings/large/*
# local, and misc do not currently contain fonts, but we want to own the dir
%dir %{_x11fontdir}/local
%ghost %verify(not md5 size mtime) %{_x11fontdir}/local/encodings.dir
%ghost %verify(not md5 size mtime) %{_x11fontdir}/local/fonts.dir
# base misc files
%dir %{_x11fontdir}/misc
%{_x11fontdir}/misc/*.pcf.gz
%ghost %verify(not md5 size mtime) %{_x11fontdir}/misc/encodings.dir
%config(noreplace) %verify(not md5 size mtime) %{_x11fontdir}/misc/fonts.alias
%ghost %verify(not md5 size mtime) %{_x11fontdir}/misc/fonts.dir
# Utility fonts?  Font utilities? Ruh-roh....
%dir %{_x11fontdir}/util
%{_x11fontdir}/util/*
# base Speedo fonts
%dir %{_x11fontdir}/Speedo
%{_x11fontdir}/Speedo/*.spd
%ghost %verify(not md5 size mtime) %{_x11fontdir}/Speedo/encodings.dir
%ghost %verify(not md5 size mtime) %{_x11fontdir}/Speedo/fonts.dir
%verify(not md5 size mtime) %{_x11fontdir}/Speedo/fonts.scale
# base Type1 fonts
%dir %{_x11fontdir}/Type1
%{_x11fontdir}/Type1/*.afm
%{_x11fontdir}/Type1/*.pfa
%{_x11fontdir}/Type1/*.pfb
%ghost %verify(not md5 size mtime) %{_x11fontdir}/Type1/encodings.dir
%ghost %verify(not md5 size mtime) %{_x11fontdir}/Type1/fonts.dir
%verify(not md5 size mtime) %{_x11fontdir}/Type1/fonts.scale
#%ghost %verify(not md5 size mtime) %{_x11fontdir}/Type1/fonts.cache*
### XFree86-truetype-fonts ###########################################
%files truetype-fonts
%defattr(-,root,root)
%dir %{_x11fontdir}/TTF
%{_x11fontdir}/TTF/*.ttf
%ghost %verify(not md5 size mtime) %{_x11fontdir}/TTF/encodings.dir
%ghost %verify(not md5 size mtime) %config(noreplace) %{_x11fontdir}/TTF/fonts.alias
%ghost %verify(not md5 size mtime) %{_x11fontdir}/TTF/fonts.dir
%ghost %verify(not md5 size mtime) %{_x11fontdir}/TTF/fonts.scale
#%ghost %verify(not md5 size mtime) %{_x11fontdir}/TTF/fonts.cache*

%files 75dpi-fonts
%defattr(-,root,root)
%dir %{_x11fontdir}/75dpi
%exclude %{_x11fontdir}/75dpi/*-ISO8859-2.pcf.gz
%exclude %{_x11fontdir}/75dpi/*-ISO8859-9.pcf.gz
%exclude %{_x11fontdir}/75dpi/*-ISO8859-15.pcf.gz
%{_x11fontdir}/75dpi/*.pcf.gz

%files 100dpi-fonts
%defattr(-,root,root)
%dir %{_x11fontdir}/100dpi
%exclude %{_x11fontdir}/100dpi/*-ISO8859-2.pcf.gz
%exclude %{_x11fontdir}/100dpi/*-ISO8859-9.pcf.gz
%exclude %{_x11fontdir}/100dpi/*-ISO8859-15.pcf.gz
%{_x11fontdir}/100dpi/*.pcf.gz

%files ISO8859-2-75dpi-fonts
%defattr(-,root,root)
%{_x11fontdir}/75dpi/*-ISO8859-2.pcf.gz

%files ISO8859-2-100dpi-fonts
%defattr(-,root,root)
%{_x11fontdir}/100dpi/*-ISO8859-2.pcf.gz

%files ISO8859-9-75dpi-fonts
%defattr(-,root,root)
%{_x11fontdir}/75dpi/*-ISO8859-9.pcf.gz

%files ISO8859-9-100dpi-fonts
%defattr(-,root,root)
%{_x11fontdir}/100dpi/*-ISO8859-9.pcf.gz

%files ISO8859-15-75dpi-fonts
%defattr(-,root,root)
%{_x11fontdir}/75dpi/*-ISO8859-15.pcf.gz

%files ISO8859-15-100dpi-fonts
%defattr(-,root,root)
%{_x11fontdir}/100dpi/*-ISO8859-15.pcf.gz

%files cyrillic-fonts
%defattr(-,root,root)
%dir %{_x11fontdir}/cyrillic
%{_x11fontdir}/cyrillic/*.gz
%ghost %verify(not md5 size mtime) %{_x11fontdir}/cyrillic/encodings.dir
%config(noreplace) %verify(not md5 size mtime) %{_x11fontdir}/cyrillic/fonts.alias
%ghost %verify(not md5 size mtime) %{_x11fontdir}/cyrillic/fonts.dir

%ifnarch s390 s390x
%files doc
%defattr(-,root,root)
%doc xc/doc/hardcopy/*
%endif

%files Xnest
%defattr(-,root,root)
%{_x11bindir}/Xnest
%{_x11mandir}/man1/Xnest.1*

%files Xvfb
%defattr(-,root,root)
%{_x11bindir}/Xvfb
%{_x11mandir}/man1/Xvfb.1*

%if %{with_xf86cfg}
%files xf86cfg
%defattr(-,root,root)
%{_x11bindir}/xf86cfg
%{_x11mandir}/man1/xf86cfg.1*
%endif

%clean
[ "$RPM_BUILD_ROOT" != "/" ] && rm -rf $RPM_BUILD_ROOT 

########## CHANGELOG SECTION #########################################

%changelog
* Sun Feb 12 2006 Marc Deslauriers <marcdeslauriers@videotron.ca> 4.2.1-16.73.31.legacy
- Add XFree86-4.1.0-xpm-security-fix-CAN-2005-0605.patch.
- Add XFree86-4.3.0-security-CAN-2005-2495.patch to fix various integer
  overflows.

* Tue Nov 30 2004 Rob Myers <rob.myers@gtri.gatech.edu> 4.2.1-16.73.30.legacy
- apply fix for previous patch

* Tue Nov 30 2004 Rob Myers <rob.myers@gtri.gatech.edu> 4.2.1-16.73.29.legacy
- apply patch for CAN-2004-0914 (FL #2314)

* Sat Oct  2 2004 Dominic Hargreaves <dom@earth.li> 4.2.1-28
- Fix for CAN-2004-0687/8 libXpm stack and integer overflows.

* Tue Sep 28 2004 Dominic Hargreaves <dom@earth.li> 4.2.1-27
- Fixed permissions of a few source files
- Added gcc-c++ BuildRequires

* Fri May 14 2004 John P. Dalbec <jpdalbec@ysu.edu> 4.2.1-26
- Disabled parallel building (not fixable?).

* Wed May 12 2004 John P. Dalbec <jpdalbec@ysu.edu> 4.2.1-25
- Fixed parallel building (reversed order of two lines in Makefile patches).
- Added conditional BuildRequires for Glide3-devel.
- Commented out rpm -q test for Glide3-devel.

* Thu Feb 24 2004 John P. Dalbec <jpdalbec@ysu.edu> 4.2.1-24
- [SECURITY] XFree86-4.2.1-libXfont-security-CAN-2004-0083-CAN-2004-0084-CAN-2004-0106-v2-430-backport.patch
  added containing fixes for libXfont buffer overflow issues CAN-2004-0083,
  CAN-2004-0084, and CAN-2004-0106 (copied from RH 9 SRPM).
- Added missing BuildRequires for libtool
- Converted all BuildPrereq to BuildRequires

* Mon Oct 20 2003 Mike A. Harris <mharris@redhat.com> 4.2.1-23
- Updated comments in patches that were added in 4.2.1-22
- Also rebuilt this release as 4.2.1-13.73.23 for Red Hat Linux 7.3 erratum

* Fri Oct 17 2003 Mike A. Harris <mharris@redhat.com> 4.2.1-13.73.22
- Rebuilt as 4.2.1-13.73.22 for Red Hat Linux 7.3 erratum with RHL_73_build
  enabled

* Wed Oct 15 2003 Mike A. Harris <mharris@redhat.com> 4.2.1-22
- [SECURITY] XFree86-4.2.1-libXfont-security-int-overflow-430-backport.patch
  added containing backported fixes with appropriate modifications for libXfont
  integer signedness issues from xf-4_3-branch in order to fix CAN-2003-0730
  Backport developed from cvsps of patchsets 11532, 11538, 11545, 11643
- Added XFree86-4.2.1-xdm-pam-setcred-security.patch as a minimal fix for the
  xdm pam setcred issue reported against kdm in CAN-2003-0690.  This patch is
  a very minimal backport of the xdm changes made to 4.3.0 containing only the
  small fix for this one issue.

* Sat Jun 28 2003 Mike A. Harris <mharris@redhat.com> 4.2.1-21
- Bump release number to 21 and rebuild due to a temporary buildsystem glitch
  which added '-g' to RPM_OPT_FLAGS which went unnoticed and caused the
  packages to be built with debug info in them.  While the problems were fixed
  later, these packages were generated and tested during the problem time, and
  as such the problem never got noticed prior to being released as huge monga
  XFree86 packages which are slowing down the Internet and causing maple syrop
  prices to soar.  Added code to remove '-g' from RPM_OPT_FLAGS if it exists,
  in order to prevent this problem from ever occuring again. (#98082)
- XFree86 somehow managed to pick up an install time dependancy on pam-devel
  instead of 'pam' sometime along the line, causing pam-devel to be required
  unnecessarily in order to upgrade.  This problem was present in both the
  4.2.1-20 erratum for Red Hat Linux 8.0 and the 4.2.1-13.73.3 erratum for
  Red Hat Linux 7.3 (#98013)

* Thu May  2 2003 Mike A. Harris <mharris@redhat.com> 4.2.1-20
- Bump release to 4.2.1-20 from 4.2.1-13.73.3, so that builds < 20 are
  reserved for RHL 7.3 builds, and 20 and above are for RHL 8.0 builds.

* Thu May  2 2003 Mike A. Harris <mharris@redhat.com> 4.2.1-13.73.3
- Added XFree86-4.2.1-redhat-version-change-detection.patch to detect version
  skew when building, and XFree86-4.2.1-redhat-lock-version.patch to lock
  version when skew is detected.

* Thu May  2 2003 Mike A. Harris <mharris@redhat.com> 4.2.1-13.73.2
- Added Provides/Obsoletes Mesa to XFree86-libs when building for RHL 7.3 as
  glut requires Mesa, and possibly other packages do too.
- Removed BuildPrereq: kudzu-devel, pciutils-devel from both the XFree86 and
  XFree86-libs subpackages, as they were added for glidelink which was a part
  of Glide3 when it was integrated into XFree86 packaging back in 4.1.0 days,
  and is not needed any longer

* Thu May  1 2003 Mike A. Harris <mharris@redhat.com> 4.2.1-13.73.1
- Made __fc-cache macro use fc-cache on RHL 8.0 and xftcache on RHL 7.3
- Changed install section to not delete xftcache stuff on RHL 7.3
- Do not delete xf86cfg on RHL 7.3 builds in install section.

* Thu May  1 2003 Mike A. Harris <mharris@redhat.com> 4.2.1-13.73.0
- Removed and obsoleted the XFree86-xtrap-clients package, and merged it
  into the main XFree86 package, to simplify packaging
- Remove XFree86-4.1.0-ppc-compiler-workaround.patch and the gcc296ppc define
  hack, as we never shipped a ppc product which used XFree86 4.2.x, so no sense
  keeping that mess around
- Created new spec file macro RHL_73_build which should be set to 1 when doing
  a build on RHL 7.3.  Also added RHL_80_build macro which is set to be the
  opposite of whatever RHL_73_build is set to for convenience throughout spec
- Conditionalized xauth subpackage to only build on RHL 8.0, otherwise stuff
  it in XFree86 package
- Conditionalized mkfontscale to only build on RHL 8.0
- Test builds (7.3 - 4.2.1-13.73.0) / (8.0 - 4.2.1-13.80.0)

* Sun Apr 20 2003 Mike A. Harris <mharris@redhat.com> 4.2.1-13
- Update to ttmkfdir 3.0.9 and remove all ttmkfdir patches

* Fri Apr 18 2003 Mike A. Harris <mharris@redhat.com> 4.2.1-12.2
- Added XFree86-4.2.1-xterm-session-management-resource.patch that the xterm
  maintainer fixed in 4.3.0 and requested we add to 4.2.1 also (#88773)
- Remove with_sdk macro and all references
- Remove with_Xresource_extension and restest.c
- Remove unused with_kdrive and with_render_cursor_enhancement macros
- Cleaned up fontlists to use %%exclude similar to 4.3.0 packaging
- Updated savage driver to Tim Roberts 1.1.27t driver
- Removed various dead ia64 patches
- Renamed Build_DRI to with_DRI to sync macro with 4.3.0

* Sat Apr  5 2003 Mike A. Harris <mharris@redhat.com> 4.2.1-12.1
- Added XFree86-4.2.1-redhat-bug-report-address-update.patch to provide
  better more up to date bug report addresses and information in server
  failure error messages

* Sat Apr  5 2003 Mike A. Harris <mharris@redhat.com> 4.2.1-12
- Updated patch0 with XFree86-4.2.1-xf-4_2-branch-20030405.patch to latest
  stable xf-4_2-branch
- Added XFree86-4.2.1-makefile-fastbuild.patch to help speed up builds a bit

* Mon Mar  3 2003 Mike A. Harris <mharris@redhat.com> 4.2.1-11.5
- Added XFree86-4.2.1-xterm-DECUDK-security-fix.patch to fix security issue
  indicated in [CAN-2003-0071]
- Added XFree86-4.2.1-xterm-can-2003-0063.patch to fix [CAN-2003-0063]

* Mon Mar  3 2003 Mike A. Harris <mharris@redhat.com> 4.2.1-11.4
- Backported XFree86-4.2.1-xaa-render-mga-xinerama-issues.patch from 4.3.0
  to fix Render accel generic code which caused artifacting on mga especially
  with xinerama
- Disabled XFree86-4.2.1-mga-xinerama-G450-issue.patch which disables RENDER
  accel on mga, since above patch should resolve that issue

* Fri Feb 21 2003 Mike A. Harris <mharris@redhat.com> 4.2.1-11.3
- Added XFree86-4.2.1-ati-radeon-alan-legacy-vga.patch to allow ancient VGA
  mono monitor which can not be detected automatically to be used by adding
  a new option ForceLegacyCRT to the config file (#69978)

* Wed Feb 12 2003 Mike A. Harris <mharris@redhat.com> 4.2.1-11.2
- Converted the main tarball from bzip2 to gzip -9 because it decompresses
  twice as fast, making test builds faster.  It increases the size of the
  src.rpm by about 10Mb, but who cares for erratum packages.  Speed wins.
- Removed CVSBuild related macros as it is irrelevant in erratum packages
- Removed BuildVoodoo option as it was never implemented and is just clutter
- Remove BuildXterm3d and related stuff since we never shipped it with 8.0
- Updated Savage driver to Tim Roberts 1.1.26t driver, which should fix tonnes
  of problems for most savage users

* Wed Feb 12 2003 Mike A. Harris <mharris@redhat.com> 4.2.1-11.1
- Added XFree86-4.2.99.901-xauth-diskfull.patch from current rawhide, which
  fixes a bug where xauth may write an incomplete .xauth file and delete the
  old one if there is insufficient disk space (Harald Hoyer - #84036)
- Merged the two parallel make patches into one

* Wed Feb  5 2003 Mike A. Harris <mharris@redhat.com> 4.2.1-11
- Added XFree86-4.2.1-ati-r128-missing-symbols.patch to fix bug (#83303)

* Wed Jan 15 2003 Mike A. Harris <mharris@redhat.com> 4.2.1-10.5
- Fix mkfontdir to set permissions properly XFree86-4.2.99.2-mkfontdir-perms.patch

* Sat Dec 21 2002 Mike A. Harris <mharris@redhat.com> 4.2.1-10.4
- Added XFree86-4.2.1-netmouse.patch to fix mouse initialization problem
  reported on XFree86 bug report mailing list

* Sat Dec 21 2002 Mike A. Harris <mharris@redhat.com> 4.2.1-10.3
- Updated redhat-custom-startup patch to 4.2.1 by backporting changes from
  rawhide version (#77930)

* Sat Dec 21 2002 Mike A. Harris <mharris@redhat.com> 4.2.1-10.2
- Added XFree86-4.2.1-lndir-relative-symlink-fix.patch to fix (#75155)

* Fri Dec 20 2002 Mike A. Harris <mharris@redhat.com> 4.2.1-10.1
- Added new __fccache macro for running fc-cache if it exists when installing
  or uninstalling font packages.  Added __fccache to all font packages
  post/postun scripts. (#77542)
- Replaced /usr/X11R6/lib/X11/fonts with _x11fontdir in rpm scripts, etc.

* Wed Dec 18 2002 Mike A. Harris <mharris@redhat.com> 4.2.1-10
- The files (XErrorDB, XKeysymDB, rgb.txt) moved from XFree86 to XFree86-libs
  subpackage in 4.1.0-43 for AS 2.1 enhancement request - bugzilla bug (#79488)

* Sun Dec 15 2002 Mike A. Harris <mharris@redhat.com> 4.2.1-9.6
- Added XFree86-4.2.1-xkb-Xutf8LookupString-fails-in-UTF8-bug78804.patch to
  fix Xutf8LookupString UTF8 failure if X server lacks XKB support (#78804)

* Mon Dec  2 2002 Mike A. Harris <mharris@redhat.com> 4.2.1-9.5
- Added XFree86-4.2.1-mga-xinerama-G450-issue.patch to work around problems
  with Render hardware acceleration on Matrox G400/G450/G550

* Tue Nov 26 2002 Mike A. Harris <mharris@redhat.com> 4.2.1-9.4
- Added XFree86-4.2.1-timestamp-monotonicity.patch to guarantee the X server
  timestamps increase monotonically internally (#63509)

* Sat Nov 23 2002 Mike A. Harris <mharris@redhat.com> 4.2.1-9.3
- Removed XFree86-4.0.3-xaw-asciisink.patch, as a different solution was put
  into upstream sources

* Sun Nov  3 2002 Mike A. Harris <mharris@redhat.com> 4.2.1-9.2
- Added XFree86-4.2.0-bad-mmap-check.patch to fix bug (#71783) on Alpha, but
  possibly other architectures are affected also.
- Updated Cyrix driver to 0.3 driver from Alan

* Fri Oct 18 2002 Mike A. Harris <mharris@redhat.com> 4.2.1-9
- Added XFree86-4.2.1-Xrender-crashfix.patch to fix bug (#76154)

* Tue Oct  8 2002 Mike A. Harris <mharris@redhat.com> 4.2.1-8
- Updated Patch0 to current xf-4_2-branch, picking up a few security fixes
  and bugfixes, in particular for MIT-SHM, xdm
- Removed XFree86-4.0.3-xaw-freed-mem-deref.patch now as it _finally_ is in
  XFree86.org sources.  ;o)
- Removed XFree86-4.2.0-xdm-pam-conv-and-realloc.patch - it is integrated now

* Mon Oct  7 2002 Mike A. Harris <mharris@redhat.com> 4.2.1-7
- Various architectural cleanups for all-arch build

* Wed Sep 18 2002 Mike A. Harris <mharris@redhat.com> 4.2.1-6.2
- Added new input drivers from Alan Cox for "Fujitsu stylistic",
  Palmax PD1000/PD1100 Input driver, Union Reality UR-98 head tracker

* Wed Sep 18 2002 Mike A. Harris <mharris@redhat.com> 4.2.1-6.1
- Added new Cyrix driver 0.2 from Alan Cox, which fixes (#72297)

* Sat Sep 14 2002 Mike A. Harris <mharris@redhat.com> 4.2.1-6
- Updated savage driver to the upstream maintainer Tim Roberts new 1.1.25t
  version which solves various savage driver problems, which are fully
  documented at http://www.probo.com/timr/savage40.html (#71973)

* Wed Sep 11 2002 Mike A. Harris <mharris@redhat.com> 4.2.1-5.1
- Disabled DRI on ppc at streeters request

* Wed Sep 11 2002 Mike A. Harris <mharris@redhat.com> 4.2.1-5
- Added XFree86-4.2.1-lbxproxy-SEGV-fix.patch from Debian to fix a SEGV
  in lbxproxy
- Added XFree86-4.2.1-xshm-header-file-fix.patch from Debian
- Added XFree86-4.2.1-vidmode-manpage-fixes.diff from Debian

* Tue Sep 10 2002 Mike A. Harris <mharris@redhat.com> 4.2.1-4
- Added ati-r128-dri-dga and ati-radeon-dri-dga patches to fix bugs in the
  Radeon and Rage 128 drivers which cause crashes while using VMware with
  DGA when DRI is enabled (#73678)
- Fix up ttmkfdir to look for freetype in _libdir for AMD Hammer

* Sun Sep  8 2002 Mike A. Harris <mharris@redhat.com> 4.2.1-3.3
- Remove scanpci, pcitweak from ppc/ppc64 builds

* Sun Sep  8 2002 Mike A. Harris <mharris@redhat.com> 4.2.1-3.2
- (x86_64) Added Imake define to point Freetype2LibDir to _libdir

* Sat Sep  7 2002 Mike A. Harris <mharris@redhat.com> 4.2.1-3
- Replaced the BuildRequires on Glide3 and Glide3-devel that was
  conditionalized for x86/alpha/ia64 with some new shell script code in the
  prep section to ensure Glide3 is installed on the build system since
  some rpm based software freaks out with conditional BuildRequires, and I
  am a nice guy.

* Sat Sep  7 2002 Mike A. Harris <mharris@redhat.com> 4.2.1-2
- Did a search and replace on specfile to convert all locations of the X11
  font directory to _x11fontdir, /usr/X11R6/bin -> _x11bindir, and similar
  for _x11mandir, etc. throughout the specfile
  
* Sat Sep  7 2002 Mike A. Harris <mharris@redhat.com> 4.2.1-1
- Updated XFree86 to version 4.2.1.  This does not bring us anything new
  since 4.2.1 is merely 4.2.0 stable branch (which our 4.2.0 was already
  tracking all along) plus the latest X security patch, which 4.2.0-72
  contains.  This release is merely a cosmetic update to official 4.2.1 in
  order to quell all of the "Why doesnt Red Hat have 4.2.1" questions that
  are sure to abound.
- Removed patches present in 4.2.1:  XFree86-4.2.0-vesa-xf86SetDpi-fix.patch,
  XFree86-4.0.3-xaw-readtext.patch, XFree86-4.1.0-time-wraparound.patch,
  XFree86-4.2.0-mitshm.patch,  XFree86-4.2.0-xkb-us_intl-missing-commas.patch,
  XFree86-4.2.0-overlay-crash.patch

* Thu Sep  5 2002 Owen Taylor <otaylor@redhat.com> 4.2.0-72
- Fix zh_TW-xcinNEW patch which lost a couple of things in the merge 
  with the XLOCALEDIR patch

* Tue Sep  3 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-71
- Added xlib-security-fix-XLOCALEDIR to fix a security vulnerability in
  Xlib i18n code new to 4.2.0.  4.1.0 and earlier is not susceptible.
- XFree86.org has tagged a new release of XFree86 4.2.1 in CVS for this
  issue.  Red Hat current XFree86 4.2.0 is essentially 4.2.1 except for the
  cosmetic version number difference
- Updated the zh_TW-xcin patch to zh_TW-xcinNEW which handles a code area
  that overlapped with the new security patch
- Updated the _LP64 kludge patch on alpha/ia64 as it also overlapped the
  security patch

* Sun Sep  1 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-70
- Updated custom startup log patch to fix a few glitches
- Added -fPIC to x86_64 compiler flags until better solution is made in future
- Added XFree86-4.2.0-libXrender-bugfix.patch to fix showstopper (#73243)

* Thu Aug 29 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-69.1
- Added Obsoletes: XFree86-compat-libs to list of obsolete packages

* Thu Aug 29 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-69
- Rebuild with a few patches disabled that errored out on me and will be
  fixed in future build

* Thu Aug 29 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-68
- Pruned ia64 driver list based on unknown state of working order for these
  drivers on ia64 to minimalize support issues.  As hardware becomes available
  for testing, and drivers can be verified to be mostly sane/working, they
  can be re-enabled on a driver by driver basis.
- Added XFree86-4.2.0-im-clientmessage-crash.patch to fix CJK application
  crashing showstopper bug (#72236)

* Mon Aug 26 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-67.6
- Actually properly enable the maxxfbmem patch from 4.2.0-67.5 this time
- Fix unresolved symbols in SiS driver reported by Alan Cox

* Sun Aug 25 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-67.5
- Changed buildsys autodetect to use new beehive mechanism (#71055)
- Added kernel version string to X server startup messages for easier debugging
- Fixed SiS hardware cursor (hopefully) with XFree86-4.2.0-sis-cursor.patch
- Fixed SiS maxxfbmem driver comparison inversions

* Thu Aug 22 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-67.1
- Cleaned up 3.3.6 server Obsoletes lines et al. to be more compact

* Thu Aug 22 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-67
- Integrated PPC specfile changes
- Enable DRI on ppc, but not ppc64
- PPC using gcc 2.96 autodetection and compiler flag tweaks, etc.
- Added ppc64, s390x, x86_64 to conditionalized LP64 patch
- PPC - build pcitweak, scanpci on ppc, ppc64 now

* Mon Aug 19 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-66
- Added XFree86-4.2.0-elf-loader-empty-symbol-table.patch to fix gcc 3.2
  related issue in the X ELF loader (#70576)
- Re-enabled the Radeon DDA removal patch now that Null beta is released

* Thu Aug 15 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-65
- Due to a kernel bug breaking SuS compliance in the Alpha kernel, a change
  has been made to the install section so that fonts.dir, encodings.dir files
  are mode 644 before "touch" touches them.
- Modified stripping policy at end of install section to strip all ELF
  executable files in the buildroot instead of just the ones found in 
  /usr/bin and /usr/X11R6/bin.
- Modified shared library stripping policy for all libs found in /usr/X11R6/lib,
  /usr/lib, and now also /usr/X11R6/lib/X11/locale/common.  All .so.* libs are
  now stripped with "strip --strip-unneeded -R .comment" following the current
  RPM default for stripping shared libraries, and under the advice of Uli.
- Note:  XFree86 server modules are not stripped at all currently for safety.
  Once I determine what can be safely stripped, I will add stripping of the
  modules also.

* Wed Aug 14 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-64
- Removed XIE and PEX5 documentation from XFree86-doc subpackage because both
  of these extensions are obsolete and not included anymore.
- Temporarily disabled XFree86-4.2.0-ati-radeon-dda-removal.patch as it is
  untested, and I dont want to destabilize.  Will re-enable for testing soon.

* Tue Aug 13 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-63.1
- Added XFree86-4.2.0-ati-radeon-dda-removal.patch which removes the DDA
  code from the radeon driver which was leftovers from the r128 driver and
  aparently causes 1400x1050 and other modes to cause an FPE on some radeon
  boards in some refresh rates (#63593)
- Explicitly delete unshipped files from RPM_BUILD_ROOT at end of install
  section in order to pass RPMs new unpackaged_files_terminate_build option
- Moved around some file removals to the new DELETE section of specfile

* Mon Aug 12 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-63
- Added XFree86-4.2.0-ati-mach64-dsp-rounding-error.patch to fix a rounding
  error in Mach64 DSP calculation
- Added XFree86-4.2.0-ati-radeon-missing-commas.patch which fixes a missing
  comma issue in a struct in radeon_driver.c
- Bumped spec file release from 60.4 to 63 due to someone elses package
  release number conflicting.

* Thu Aug  8 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-60.4
- Fixed an xdm SEGV bug in verify.c which could be occasionally triggered,
  due to malloc() allocated memory not being zeroed out.  Also fixed a
  bad realloc() call that assumed the reallocated block of memory would be in
  the same location every time - fixes bug (#40729)

* Wed Aug  7 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-60.3
- Added XFree86-4.2.0-sane-deadacc.patch to fix dead diareisis problem reported
  by aoliva in bug (#71014)
* Tue Aug  6 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-60.2
- Disabled the ugly 1980 style ancient UNIX ugly ugly X server startup
  stipple pattern.

* Mon Aug  5 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-60.1
- Added XFree86-4.2.0-locale-alias-utf8-euro.patch to workaround bug in
  fi_FI.UTF-8@euro and pt_PT.UTF-8@euro locales (#67914)
- Added XFree86-4.2.0-i810-vtswitch-sync-fix.patch to fix i810 VTswitch
  lockup problem - BLOCKER bug (#66187,#53231)

* Mon Aug  5 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-60
- Removed /usr/share/fonts/default/TrueType from default xfs config file in
  order to fix BLOCKER bug (#68126,#70178)
- Made X resource extension off by default for official builds, due to
  irrational ABI compatibility concerns.  People wanting to use it can
  easily rebuild X from rpm after setting the define with_Xresource_extension
  to 1.

* Sat Aug  3 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-59.2
- Added restest dumb sample client to use the new Xres extension
- Conditionalized spec file inclusion of Xres and the sample client

* Sat Aug  3 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-59.1
- Bugfix to dixsym.c for the Xres extension from yesterday.

* Fri Aug  2 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-59
- Backported the new X-resource extension from XFree86 head CVS, which allows
  internal X server resource statistics, etc. to be queried by client
  applications.  This can aide in debugging client related pixmap leakage, and
  a variety of other various resource related problems/bugs in both client
  applications, as well as the X server itself.

* Wed Jul 31 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-58.1
- Disabled ParallelBuild on s390 upon request of pknirsch

* Tue Jul 30 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-58
- Added support to the Radeon driver CP engine to perform accelerated color
  expansion and image writes.  The CP engine is used when DRI is enabled.
  XFree86-4.2.0-ati-radeon-cp-colorexpansion-imagewrite-enhancement.patch

* Fri Jul 26 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-57.1
- Removed the following paths from the default xfs config file as we do not
  ship fonts in these directories by default or they dont belong in the default
  config: /usr/X11R6/lib/X11/fonts/CID, /usr/X11R6/lib/X11/fonts/local,
  /usr/X11R6/lib/X11/fonts/latin2/Type1, /usr/share/AbiSuite/fonts (#68126)

* Fri Jul 26 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-57
- Added XFree86-4.2.0-ati-r128-vtswitch-fix-busmaster-enable.patch to fix
  the exact same bug in the r128 driver as was just fixed in the radeon
  driver in 4.2.0-56. (#62442,#65136)

* Fri Jul 26 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-56
- Added XFree86-4.2.0-libICE-remove-stupid-delay.patch to remove stupid 5
  second delays from libICE (#66751)
- Added XFree86-4.2.0-ati-radeon-vtswitch-fix-busmaster-enable.patch to fix
  lockups reported in XFree86 4.2.0 for a long time now by users of ATI Radeon
  cards with certain hardware combinations. (#62171,#65330)

* Wed Jul 24 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-55.2
- Added -f flag to hostname command to attempt to fix Custom build
- Added fix for SysRq / Print Screen:  XFree86-4.2.0-sysreq.patch (#69743)

* Tue Jul 23 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-55.1
- Made all instances of "rm" in spec file "rm -f" in order to force removal
  of the file without prompting.  Reported by a few people that rebuilding X
  caused it to hang while compiling on an "rm" command.  (#69713)
- Added XFree86-4.2.0-manpage-document-nomtrr-option.patch to document
  Option "NoMTRR" in the XF86Config manpage.

* Mon Jul 22 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-55
- Added ati-rage-xl-pci-spec-cleanup patch to fix ATI Rage XL PCI spec
  violations (#69291)  Replaces previous patch for IBM/Dell/others from
  Feb 28, 2002 (#58188)

* Mon Jul 22 2002 Tim Powers <timp@redhat.com> 4.2.0-54
- rebuild using gcc-3.2-0.1

* Sat Jul 20 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-53.1
- Redirect stderr+stdout of hostname command in xon script to prevent stderr
  from being displayed ot user (#67323)
- Corrected incorrect filepath in XftConfig-README-OBSOLETE file (#68632,#69104)

* Thu Jul 18 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-53
- Previous ia64/alpha fix from Jul 08 removed the Xft1 patch,
  and made the ia64/alpha patch apply on all architectures.  Fixed.
- Added XFree86-4.2.0-overlay-crash.patch to fix bug (#68516)
- Added patch for module loader from Bill Nottingham for gcc 3.1 on ia64
- Add patch to enable/disable DMA for Xv on r128 (#64503,#68058,#68668)

* Mon Jul 08 2002 Elliot Lee <sopwith@redhat.com> 4.2.0-52.01
- Fix duplicate application of patch4201 on ia64/alpha
- Remove ExcludeArch: alpha ia64

* Tue Jun 25 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-52
- Reordered the spec install section so that Xft1 .so gets deleted after it
  the code which generates the .so devel symlinks
- Fixed libXft.so.1 to point to libXft.so.1.2 instead of 1.1, and made sure
  the files are explicitly listed in the files section.

* Sun Jun 23 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-51
- Added Obsoletes lines for remaining 3.3.6 servers that were not previously
  obsoleted from the olden days.
- Really made Xft headers excluded this time

* Sun Jun 23 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-50.24
- Assimilated mkxauth into the XFree86-xauth package, and added Obsoletes and
  Provides entries for it.
- Removed Xft headers when new Xft1 is used, as Xft2 now provides the Xft
  headers instead.

* Fri Jun 21 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-50.23
- Replaced libXft with the new Xft1 from XFree86 CVS which is completely
  compatible, however uses fontconfig instead of XftConfig.  This has been
  conditionalized so that it can be disabled for builds for RHL 7.3 et al.
  The new libXft is Xft 1.2 whereas the stock Xft is 1.1.  The new lib should
  be binary compatible and source compatible.
- xftcache conditionalized as well - replaced with fc-cache in fontconfig

* Thu Jun 20 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-50.22
- Backported the Trident driver from CVS, picking up many Trident fixes
  from Alan Hourihane

* Tue Jun 18 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-50.21
- Backported i810/i830 driver from CVS, adding 2D only i845 support
- Removed i830m workaround for Dell c400 laptop as it did not work
- Backported siliconmotion driver from CVS, picking up a few bugfixes
- Conditionalized spec file using backup prefixes on patches

* Mon Jun 17 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-50.20
- Backported i740 driver from CVS - i740-driver-update-cvs-20020617
- Renamed the radeon-mobility-LX patch to radeon-mobility-FireGL-7800 after
  determining the two are one and the same card.
- Added mkfontscale from XFree86 CVS so we can begin moving away from ttmkfdir
  and towards mkfontscale which is going to be better in the long run.
- Conditionalized inclusion of XftConfig file and Xft/Xrender libraries,
  so they can be disabled for builds using fontconfig (which replaces them).
- Added new /etc/X11/XftConfig-README-OBSOLETE file to explain wht it is no
  longer there.

* Mon Jun 17 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-50.19
- Reorganized patch section, moved all video driver patches into an
  alphabetically sorted driver patch section, and renumbered all patches
  to meet the new patch numbering scheme.
- Backported cirrus driver from XFree86 CVS (4.2.99.1)

* Fri Jun 14 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-50.18
- Created XFree86-4.2.0-xman-manconf.patch to fix the xman man config
  file path for once and for all.  Sent upstream so hopefully this will
  get merged into XFree86 4.3.0.
- Conditionalized building xf86cfg, and disabled it by default, as we are
  moving to our new redhat-config-xfree86 tool for X configuration.
- Backported apm driver from XFree86 CVS (4.2.99.1), DPMS support
  enhancements, and a few accel fixes.  apm-driver-update-cvs-20020617
- Backported ark driver from XFree86 CVS (4.2.99.1) ark-driver-update-cvs-20020617
- Backported chips driver from XFree86 CVS (4.2.99.1), with hardware mouse
  cursor and 2D accleration fixes.

* Wed Jun 12 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-50.17
- Added workaround for buggy laptop BIOSs (in particular the Dell
  Latitude C400) which use the Intel i830/i830m chipset, and limit the
  video memory to 1Mb of stolen system memory without making it
  configureable. This workaround addresses bugzilla bug (#65661)
  (Update: subsequently removed as it did not solve the problem.)
- Removed currently unused Glide3Libver macro.

* Tue Jun 11 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-50.16
- Fixed a bug in the VESA driver, where the X server would crash with
  an FPE due to a division by zero in miscreeninit() when the DisplaySize
  option was used in the config file.  Inside xf86SetDpi(), pScrn->virtualX
  and pScrn->virtualY are used only when DisplaySize is given in the config
  file, however these struct members were not initialized properly in the
  vesa driver prior to xf86SetDpi() being called.  Fixes bug (#66009)
- Removed specfile BuildXwrapper conditional as XFree86 4.x does not need or
  use Xwrapper - it only existed for XFree86 3.3.6 in the past.
- Removed specfile Build7x conditional as it was both poorly named, and the
  functionality it provided is no longer needed.

* Mon Jun 10 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-50.15
- Added alpha-ia64-_LP64-fix to workaround issue in xc/lib/X11/XlcDL.c
  preventing X from building on alpha/ia64 with gcc 3.1.
- Added 4 patches from Hewlett Packard for ia64 (XFree86-4.2.0-int10-hplso.diff,
  XFree86-4.2.0-pci-hplso.diff, XFree86-4.2.0-primpci-hplso.diff,
  XFree86-4.2.0-ps2-hplso.diff

* Wed Jun  5 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-50.14
- Added explicit Requires: _x11bindir/xauth to XFree86 main package now
  that xauth is split out.

* Mon Jun  3 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-50.13
- Update BuildPreReq: freetype-devel >= 2.0.6-3

* Thu May 30 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-50.12
- Disable debug mode in cirrus alpine driver - filling logfile (#65704)

* Wed May 29 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-50.11
- Split out xauth into a separate subpackage so things like ssh do not
  require the entire dependancy chain of XFree86 be installed merely
  to use ssh or similar (#38409,62426)
- Added neomagic-Xv-support (#63609)
- Added fix for deadkey-quotedbl in ISO8859-15 (#50282)

* Wed May 29 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-50.10
- Updated parallelmake-libfont Imake patch for more parallelism
- Fixed nasty problem in post script for libGLU, and added postun scripts
  that call ldconfig for the 2 Mesa subpackages
- Added remove-bitmap-scaler patch disabled by default pending testing,
  compatibility, etc.

* Tue May 28 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-50.9
- Added rpm post scripts for XFree86-Mesa-libGL, XFree86-Mesa-libGLU that
  call ldconfig properly
  
* Tue May 28 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-50.8
- Fixed defattr for new XFree86-Mesa-libGL* packages
- Removed Requires: XFree86 dep from Mesa-libGL subpackage

* Mon May 27 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-50.6
- Updated parallel make patch from H.J. Lu!!!
- Split out libGL.so.* and libGLU.so.* into new subpackages XFree86-Mesa-libGL
  and XFree86-Mesa-libGLU as suggested by H.J. Lu (#65152) and other vendors
- Moved _x11dir et al defines to top of spec file to ensure their definition
  precedes their usage.
- Completely removed XFree86.spec support for building using an external
  Mesa instead of the one included with XFree86.

* Fri May 24 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-50.1
- Changed stripping policy and fixed a redundancy in the spec stripping

* Fri May 24 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-50
- Bumped release number to -50 and rebuilt in new build environment

* Fri May 17 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-9.13
- Changed Xnest, Xvfb to be in group "User Interface/X" (#62820)
- Added fix for glint driver for bug (#60895)

* Fri May 17 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-9.12
- Fix for i810 Xv maximum video size (#53329)
- Changed += to =+ on various entries in our default XftConfig as per (#64970)

* Wed May 15 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-9.11
- Changed all chkfontpath calls in specfile post scripts to use :unscaled
  for all bitmap fonts, otherwise scaled bitmap fonts get used, and that
  really really sucks.  Makes Windows users run fast back to Billy.
- Disabled Radeon PCI DRI code, as it has been reported as not working by
  a user despite claims before by others that it works.
- Fixed euro support for pl keymaps as per bug (#64559)
- Added Requires: /lib/cpp to XFree86 package as xrdb requires /lib/cpp at
  runtime and will fail with an error if it is not present.
- Added fix for Rage 128 DRI related bug ati-r128-indirectBuffer from Michal
  Daenzer.

* Tue May  7 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-9.10
- Removed s390 patch 3000, and fixed up file lists for s390/s390x

* Sat May  4 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-9.8
- Replaced /usr/lib throughout specfile with _libdir for compat with
  architectures which have /usr/lib and /usr/lib64.
- Replaced /usr/X11R6 throughout specfile with _x11dir - part of a
  gradual move to implement RPMified variable ProjectRoot support for
  developmental parallel installation.
- Added the following patches backported from XFree86 CVS for AMD x86_64
  AMD-x86_64-elfloader, AMD-x86_64-imake, AMD-x86_64-compiler_h,
  AMD-x86_64-int10, AMD-x86_64-misc-small-fixes, AMD-x86_64-os-support

* Sun Apr 27 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-9.0
- Added AMD x86-64 architecture (Hammer/Opteron) support to the Imake config
  files.
  
* Wed Apr 24 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-8.1.beta
- Changed BuildRequires to pam-devel instead of pam header file.
- Reworked BuildXF86DRI portion of host.def to exclude DRI on PPC for now
- Reworked Glide3 BuildRequires so that the CURRENT Glide3 packages are
  required instead of the mess of conditional code that was there.  People
  who rebuild now require the rawhide Glide3.  Hopefully they read my
  changelog messages.
- Changed xfs postinstall script to conditionalize the login shell at runtime
  instead of at build time to help ensure that packages _built_ on a newer
  release will work on an older release.  Also, /bin/nologin which was added
  in January - does not exist, it is /sbin/nologin.  Fixed, and tested.
- Added utempter to BuildRequires and Requires
- BuildXterm3d macro causes a buildrequires loop, and needs to be set to
  "0" if bootstrapping XFree86 on a new architecture.  Comment added.

* Thu Apr 18 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-8
- Fixed bug in XFree86 post install script, renaming XF86Config-4 config file
  to .rpmsave, and preserving permissions of the file. (#63822)
- Corrected perms on /dev/dri

* Sat Apr 13 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-7
- Updated mitshm patch

* Thu Apr 11 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-6.666
- Added code to XFree86 post install script to remove xie and pex5 module
  load lines from XF86Config-4 upon upgrade/install since XIE and PEX are
  no longer provided nor supported, and X will not start if those lines
  exist in the config file. (#63119)
- Added fix for sessreg being broken with high UIDs due to open() being used
  to open a file larger than 32bit offsets can handle. (#42850,#63116)
- Fixed startx ugliness issue with hostname command (#61278,63117)
- Removed double ghost flag in truetype-fonts package
- Removed config(noreplace) from Speedo fonts.dir (#63357,63735)
- I went outside today, and the snow is almost completely gone!

* Wed Apr 10 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-6.62
- Made specfile remove fonts.dir files generated by XFree86 build, and
  "touch" them instead so they satisfy the ghost flag.  Also for the fonts.alias
  for the TTF directory.
- Removed CID directory from list of dirs to run mkfontdir in and add to
  fontpath, because our XFree86 build is not including fonts in there anymore,
  so it should not add the dir to the fontpath, nor run mkfontdir in it.
- Fixed bug in truetype-fonts subpackage which was adding cyrillic to fontpath
  instead of the TTF directory due to cut and paste error.
- Audited all font subpackage file lists for accuracy, correcting various
  ghost/config/verify flags, adding missing ghosted fonts.alias, etc. files to
  the lists also, so the files are owned by the package if a user creates them.
- Added ISO8859-15 locale aliases to locale.alias for en_US and en_GB (#62844)

* Tue Apr  9 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-6.61
- Added patch to fix various ATI Radeon issues. Will fill in the
  details of what specifically is fixed after testing the fixes.
  VTswitch is one... <more later>

* Mon Apr  8 2002 Mike A. Harris <mharris@redhat.com>
- Changed xf86cfg dep on Xconfigurator to /usr/X11R6/lib/X11/Cards

* Fri Apr  5 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-6.60
- Added fix for Trident 9397 bug (#62119)

* Mon Apr  1 2002 Mike A. Harris <mharris@redhat.com>
- Updated ttmkfdir-freetype2-port-plus-cjk-chocolaty-goodness.patch to
  build properly with gcc 3.x (Bero,Yu Shao)

* Thu Mar 28 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-6.52
- Fixed Matrox G550 cursor on second head mga-g550-cursor patch
- Created new support for Euro currency symbol for gb, hu, hu_US, pl, pl2, tr,
  us_intl keymaps based on http://www.microsoft.com/typography/faq/faq12.htm,
  also closing bugs (#56818, and a few others I need to track down in bugzilla)
- Put fonts.alias back in misc fonts directory, it slipped out somehow.

* Thu Mar 28 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-6.51
 - Flagged encodings.dir, fonts.dir, fonts.scale files properly for the
  misc, Type1, and Speedo directories in base-fonts, and changed the file
  globs to match just the font files in order to fix bug (#59619)
- Fixed similar issues to above in bug (#61940)
- Added XFree86-4.2.0-sparc_pci_domains.patch for sparc support (#62037)
- Fixed duplicate Slovak entries - MF bug (#61709)
- Confirmed ulT1mo fonts work and closed - MF bug (#61694) and (#62036)

* Wed Mar 27 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-6.50
- Added ko, zh_CN, zh_TW entries to XftConfig for bug (#61282)
- Changed antialiasing on small fonts from "any size < 14" to "any size < 11"
- Added gb18030-enc patch from Yu Shao
- ttmkfdir ported to freetype2, plus misc enhancements for CJK

* Sun Mar 17 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-6.48
- Moved GL include files into /usr/include/GL for compliance with defacto
  and possibly official standards due to user complaints.
- Changed host.def to not symlink GL include dir into /usr/include

* Thu Mar 14 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-6.47
- Updated package descriptions to not suck quite so bad, and not be
  so meaninglessly verbose as they have been for a while.  We do not want
  to scare away Harry Homeowner.

* Tue Mar 12 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-6.46
- Cleaned up xfs initscript to use simpler syntax, and fix a few issues

* Sun Mar 10 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-6.45
- Added the /usr/X11R6/lib/X11/fonts/TTF dir to XftConfig (#60901)
- Updated bugfix for (#60906) from Keith Packard
- Built on all arches

* Sun Mar 10 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-6.44
- Fixed up tdfx DRI disable patch for hires on voodoo3/banshee
- Updated Glide3 dependancy, to pick up new Glide3 package with libs directly
  in /usr/lib, instead of in /usr/lib/glide3

* Thu Mar  7 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-6.42
- Added XFree86-4.2.0-mitshm.patch to fix security issue
- Added fix for time wraparound bug (#60906)

* Wed Mar  6 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-6.41
- Resolved some Brazillian and Icelandic keyboard issues (hopefully).

* Mon Mar  4 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-6.40
- Added XFree86-4.2.0-xkb-is.patch to fix bug (#60594)
- Moved all xkb symbol patches to section 800 - 819
- disabled tdfx font corruption patch

* Thu Feb 28 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-6.39
- Added XFree86-4.2.0-ati-mach64-rage-XL.patch to fix problems reported
  on many Dell, IBM servers (#58188)
- Fixed memleak in Xlib with XFree86-4.2.0-xlib-memleak.patch

* Wed Feb 27 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-6.38
- Reorganized various fonts.dir, fonts.alias, encodings.dir files to try and
  fix some of the reported problems that have come up after various
  installations.  All files are believed to be properly flaged with ghost,
  verify and config attributes now.

* Tue Feb 26 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-6.37
- Fixed xfs initscript to use "reload" instead of "restart" for the
  condrestart option.

* Sun Feb 24 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-6.36
- Fixed ghost/config flags on various fonts.dir, fonts.alias, encodings.dir
  files in file list section.
- Fixed bug in truetype-fonts scripts which contained %%_ttmkfdir instead
  of just plain old ttmkfdir

* Sat Feb 23 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-6.35
- Added specfile URL to http://www.xfree86.org
- Rebuilt with new built toolchain in new environment

* Mon Feb 11 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-6.34
- Enabled Radeon PCI pcigart support in radeon_dri.c and radeon_cp.c
- Disabled the ugly black and white pattern that X starts up with by default
  with XFree86-4.2.0-die-ugly-pattern-die-die-die.patch - blue or something
  else will replace it in the future likely.

* Mon Feb 11 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-6.33
- Ghosted encodings.dir files in 100dpi and 75dpi font subpackages
- Modified XftConfig with some suggested changes from Keith Packard for better
  AA font support, by moving stuff around (#59192)
- Added Luxi font aliases, etc. to XftConfig for bug (#59708)
  
* Sat Feb  9 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-6.32
- Created support for ATI Radeon Mobility M7 (LX) and also updated the
  pcitable, and Cards databases, in the hwdata package also.
- Removed the conditional BuildPrereq for pam-devel et al. and replaced it
  with /usr/include/security/pam_modules.h which will automatically do the
  right thing regardless of what distro release is being built for.

* Fri Feb  8 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-6.31
- Drop XFree86-4.0.2-neomagic_swcursor.patch previously included for sony
  laptops using Neomagic 256XL+ (NM2380), and set the option to default to
  on in the Cards database instead.
- Created sis-swcursor option patch
- Created xkb-us_intl-missing-commas to fix bug (#59529)
  
* Thu Feb  7 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-6.30
- Experimental patch to disable DRI on tdfx when an incompatible hires
  video mode is selected that is known to cause unstable behaviour.
- Removed -e arguments from calls to mkfontdir in spec file as they appear
  to be unnecessary now.
- Added XFree86-4.2.0-zh_TW-xcin.patch to fix xcin (Owen Taylor, Leon Ho)

* Wed Feb  6 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-6.24
- First merge with upstream stable branch xf-4_2-branch-patch-2002-02-06
- Misc fixes:  Fix startx script for ksh, temporary workaround for IA-64,
  fix SIGSEGV when printing modes that have no flags, fix an unresolved
  symbol in libGLU.so with gcc 3, revert the composite sync default to off
  in the ati driver.

* Tue Feb  5 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-6.23
- Updated XFree86-4.2.0-gb18030-20020207.patch from Yu Shao <yshao@redhat.com>
- Added i810-dont-force-XvMC-on-DRI-users patch to fix bug in where i810
  users must enable XvMC in addition to DRI in order for DRI to work. (#59318)
- Added patch XFree86-4.2.0-FIRSTINDEX-breaks-ttmkfdir to remove FIRSTINDEX
  entries from large font encoding files as it makes ttmkfdir deep six.

* Tue Feb  5 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-6.21
- Added XFree86-4.2.0-i810-dont-use-empty-for-loops-for-delays.patch which
  removes null for loops from the i810 driver and i810 and i830 kernel DRM
  drivers for Linux and BSD.  The for loops were used as a timing delay, and
  are now replaced with "usleep(1);" instead.
- Added ttmkfdir-CJK-bug-54087-fix and bugzilla-54087-fix-gbk-encoding
  patches to fix bug (#54087)
- Fixed libGLU symlink screwup by changing from absolute to relative symlinks

* Sun Feb  3 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-6.20
- NEW XFree86-truetype-fonts subpackage which includes the new Luxi
  fonts (formerly Lucidux) by Bigelow and Holmes.
- Added /usr/lib/libGLU.so.* and /usr/lib/libGLU.so symlinks to the libGLU
  libraries included in XFree86 in the /usr/X11R6 directories for OpenGL
  standards compliance, and disabled the non-working Imake patch I made
  earlier to do the same.  This is fairly CRITICAL as any OpenGL software
  which uses GLU, will fail to compile without the proper links.
- Removed a bunch of leftover Glide3 specfile mess.
- Removed ancient no longer necessary hardlink between xterm and nxterm

* Sun Feb  3 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-6.15
- Created support for interlaced video modes on 3dfx Voodoo 3/4/5, with
  the enable-interlaced-modes patch.
- Created tdfx-fix-vtswitch-font-corruption patch to try to fix the VGA
  font corruption that occurs on VT switch on Voodoo 3 and other 3dfx cards.
  
* Sun Feb  3 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-6.14
- Added XFree86-4.2.0-tdfx-should-be-2048-not-2046.patch to fix a typo
  I found in the tdfx driver.
- Fixed bug in ttmkfdir Makefile.  In RHL 7.1 & 7.2 freetype 1 headers
  were in /usr/include/freetype however in RHL 7.2 for some god known
  reason they moved to /usr/include/freetype1/freetype.  No problem in
  RHL 7.2 as ttmkfdir used the freetype headers as part of the freetype
  build process rather than the system headers.
    
* Sun Feb  3 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-6
- Fixed base-fonts and font-utils conflicts lines
- Bumped release to 4.2.0-6, and rebuilt
- RHL 7.2 build release tag 4.2.0-0.6.13

* Sat Feb  2 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-5.2
- NEW XFree86-font-utils subpackage created for mkfontdir and ttmkfdir
  to reside in.  This will allow these utils to be available without
  requiring other XFree86 libs or packages being installed.
- Added patch to fix Matrox driver when VT switching to non-standard text
  modes (#59119)
- Created new Red Hat custom modelines patch, merged previous patches into
  it, and added new modelines from bug (#53364)
- RHL 7.2 build release tag 4.2.0-0.6.11
  
* Fri Feb  1 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-5.1
- Created XFree86-4.2.0-xfs-syslog.patch to make syslog log to LOG_DAEMON
  instead of LOG_LOCAL0 - which is supposed to be reserved for local
  system usage only.  Fixes bug (#24873)
- RHL 7.2 build release tag 4.2.0-0.6.10
  
* Thu Jan 31 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-5
- Enabled the now compiling gb18030 support patch
- RHL 7.2 build release tag 4.2.0-0.6.9

* Thu Jan 31 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-4.1
- Added gb18030 support patch to 4.2.0 <yshao@redhat.com>, but disabled it
  as it does not properly compile yet.
- enabled patch to force xfs to chdir to / before fork()
- RHL 7.2 build release tag 4.2.0-0.6.8

* Wed Jan 30 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-4.0
- Added XFree86-4.2.0-xkb-ar.patch for Arabic support (#56897)
- Also built 4.2.0-0.6.7 for RHL 7.2

* Tue Jan 29 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-3.6
- Added missing defattr to files list for XFree86-base-fonts (#59014,59020)
- Moved all /usr/X11R6/lib/modules files/dirs into same section of specfile
  and added dir flags for dirs that were not owned by the package.
- Enhanced the xfs initscript so "restart" shuts down xfs and starts it back
  up again, using the stop/start functions.  "reload" is now what reload and
  restart used to be - "kill -USR1" of xfs.
- Added zh_CN-i18n patch to fix an i18n problem with
  Chinese locales

* Mon Jan 28 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-3.4
- Added chmod kludge to bottom of install section to force locale/common
  *.so.* libraries to have execute perms.
- Also built 4.2.0-0.6.5 for RHL 7.2
- Removed the version from the Glide/Glide-devel build dependancies, so
  X will build if any version of Glide3 is present.
  
* Sun Jan 27 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-3.2
- Added link-glu-to-usrinclude patch for LSB conformance.
- Made xfs post script use /bin/false in 7.x builds and /bin/nologin in
  rawhide builds.  (#53088)
  
* Sat Jan 26 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-3.1
- NEW XFree86-base-fonts subpackage created to hold all of the base fonts
  that were previously contained in the main XFree86 package.  The new
  package contains Conflicts lines to minimize upgrading difficulties.
- Added Prereq: /sbin/chkconfig for XFree86-xfs
- Removed XFree86-4.1.0-ati-r128-PR-fix.patch as it was no longer needed,
  although not harmful in either case.
- Removed various other spurious patches that were no longer being applied,
  but were left in the specfile.
- Removed conditional support for building XIE and PEX as they have been
  deprecated by XFree86.org for quite some time now and are now obsolete

* Fri Jan 25 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-3.0
- Toggled BuildGlide3 flag so that Glide3 does not get built inside XFree86
  specfile by default.  Glide3 has been separated back out to a separate
  RPM package to simplify the XFree86 spec file, and ease maintenance.

* Thu Jan 24 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-2.5
- Fixed bug in xfs initscript fixing a problem with xfs having a CWD under
  /usr, which when located on an NFS mount, causes problems. (#57110)
- Enabled libGLw in build (#41791,#41974)
- Built also 4.2.0-0.6.1 for RHL 7.2
 
* Wed Jan 23 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-2.4
- Updated Wacom USB tablet driver Wacom-USB-driver-a25-update (#52947)
- Added xkb-french-canadian keyboard to xkb list (#52309)
- Fixed Xterm resource bugs (#48783,#49315,#58031,#58713)

* Sun Jan 20 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-2.2
- Disabled the old DisableModuleStringMerging hack in specfile as 4.2.0
  detects wether or not this option is required or not now via Imake tests.
- Conditionalized pam and automake buildprereqs

* Sun Jan 20 2002 Bernhard Rosenkraenzer <bero@redhat.com> 4.2.0-2.1
- Fix build in current tree (Glide is a mess)

* Sat Jan 19 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-2.0
- Bumped release number to -2.0 with no changes from -0.3 package, for
  building into rawhide.  All packages built for RHL 7.x should use release
  numbers less than -2, and preferably less than -1, ie: -0.x.y, so that
  upgrades stand a better chance of working in the future.

* Sat Jan 19 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-0.3
- Updated the "Requires: kernel-drm = 4.2.0" to ensure the user has the
  proper DRM version installed.  Newer rawhide kernels will now provide both
  kernel-drm = 4.2.0, as well as kernel-drm = 4.1.0 since the new DRM is
  supposed to be backward compatible.
  
* Sat Jan 19 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-0.2
- Added missing defattr(-,root,root) to xtrap-clients subpackage

* Sat Jan 19 2002 Mike A. Harris <mharris@redhat.com> 4.2.0-0.1
- XFree86 4.2.0 released - first build

* Fri Jan 18 2002 Mike A. Harris <mharris@redhat.com> 4.1.99.7-0.1
- CVS trunk update to 4.1.99.7
- dropped patches that have been merged upstream

* Sun Jan 06 2002 Mike A. Harris <mharris@redhat.com> 4.1.99.4-0.1
- CVS trunk update

* Wed Dec 26 2001 Mike A. Harris <mharris@redhat.com> 4.1.99.3-0.1
- CVS trunk update

* Thu Dec  6 2001 Mike A. Harris <mharris@redhat.com> 4.1.99.2-0.2.4
- Integrated PPC arch changes from streeter@redhat.com
- Integrated the Chinese gb18030 support patches received from yshao@redhat.com
- Added SiS DRM patch (doesnt affect build as our DRM is in kernel rpm)

* Tue Dec  4 2001 Mike A. Harris <mharris@redhat.com> 4.1.99.2-0.2.3
- Removed eurofonts-X11.tar.bz2, and ulT1mo-beta-1.0.tar.gz from XFree86
  package, moving them to their own separate packages that do not conflict
  with XFree86 namespaces.  (Removed the ISO8859-2-Type1-fonts package)
- Added new shared libs libXTrap, libXrandr.so to file lists
- Added new applications to filelist: xrandr, xedit, luit, and various
  others, and their documentation.
- Added new subpackage XFree86-xtrap-clients to hold the new xtrap client
  utilities
          
* Sun Dec  2 2001 Mike A. Harris <mharris@redhat.com> 4.1.99.2-0.1.7
- Made XFree86 server binary SUID root when not supporting Xwrapper (#56986)

* Wed Nov 28 2001 Mike A. Harris <mharris@redhat.com> 4.1.99.2-0.1.5
- Conditionalized out Xwrapper as its functionality is built directly into
  the X server now.  To build it set BuildXwrapper to 1 in specfile.
  
* Mon Nov 19 2001 Mike A. Harris <mharris@redhat.com> 4.1.99.2-0.1.3
- Fixed that annoying Radeon hardware mouse cursor bug, where any mouse
  pointer that has a hotspot *NOT* on the left side of the pointer, caused
  the mouse to freeze up and jump around on left side of screen.
  XFree86-4.1.0-radeon-hardware-cursor-fix.patch
      
* Mon Nov 12 2001 Mike A. Harris <mharris@redhat.com> 4.1.99.2-0.1.2
- Updated xman patch, to use FreeBSD style man.config (why? I dunno.)

* Tue Nov  6 2001 Mike A. Harris <mharris@redhat.com> 4.1.99.2-0.1.1
- Added new entries to XftConfig for "console" and "fixed" to not antialias,
  which solves problems reported in konsole and other Qt applications.
- Updated CVS source to current.
- Removed patches that are now integrated into new upstream source base:
  XFree86-4.1.0-ati-radeon-dri-buildfix.patch

* Fri Nov  2 2001 Mike A. Harris <mharris@redhat.com> 4.1.99.2-0.0.4
- Fixed problems with WithExternalMesa disabled, in the file lists, etc.
- Made new section for internationalizaton patches (30-39), and moved all
  locale.alias patches to that section.
- Created some new aliases for en_AU, and en_CA and sent patches upstream.
  
* Thu Nov  1 2001 Mike A. Harris <mharris@redhat.com> 4.1.99.2-0.0.2
- Initial fork from 4.1.0 codebase to separate branch for 4.1.99.2 CVS
- Set Build_7x to 0, which now means XIE, PEX and external Mesa are gone,
  and the doctor says I can stop taking my medication now.
- Added preliminary support for building CVS snapshots, which will
  eventually result in nightly builds from CVS or somesuch.
- Removed patches that are integrated into new upstream source base:
  ati-r128-SM, cirrus-foobaroo-fix, allow-module-flags, Xrender-required-libs,
  libXfont-put-eof, twm-coredumpfix, compose-iso8859-2, crash-message-fixup,
  xinerama-extmod-fix
- Updated locale-nn_NO locale-en_BG patch, and sent upstream _again_.
- Updated mkfontdir-perms
- Added patch to remove SuperProbe leftovers.

* Tue Oct 30 2001 Than Ngo <than@redhat.com>
- Added XFree86-4.1.0-cpp-s390x.patch which fixes a man-pages of size 0
  bug on s390 (#54927,#54932)

* Sat Oct 27 2001 Mike A. Harris <mharris@redhat.com> 4.1.0-5
- Disabled VT switch patch from -4 release after feedback of regression
- Updated the Savage driver with Tim Roberts 1.1.20t driver, this should
  fix the reported bugs with Staroffice locking up X, and also video
  memory detection problems: (#31879)
- Added XFree86-4.1.0-keycodes-abnt2.patch to fix abnt2 support bug(#55128)

* Mon Oct  7 2001 Mike A. Harris <mharris@redhat.com> 4.1.0-4
- Added patch to fix VT switch hangs that are hardware independant.  This
  should fix numerous reported VT switch bug reports.
- Fixed up host.def parallel make stuff.. HasParallelMake define is broken,
  and unneeded for now.

* Sat Oct  6 2001 Mike A. Harris <mharris@redhat.com>
- Removed __rmfontpath macro, and its usage, as well as the rpm 4.0.3 dep,
  because a lot of people were getting snagged on it, and it is questionable
  of the benefit of removing the fontpaths anyways, since it does not harm
  anything by leaving the font paths in config files really.
- Changed /lib/libpam reqs to pam-devel instead
- Commented the DisableModuleStringMerging specfile define, and moved to top
  of specfile where it is much more visible, as a lot of people have been
  getting snagged on this.

* Wed Oct  3 2001 Mike A. Harris <mharris@redhat.com> 4.1.0-3.9
- Modified and unified the "make World" buildlines by removing all the
  buildflags, etc. from them, and moving them into proper Imake configuration
  variables.
- Added "-pipe" to default C compiler flags, as it should work on all
  architectures now.
- Various other specfile cleanups.
- Created support for ATI Rage 128 PP (1002:5050) XFree86-4.1.0-ati-r128-PP.patch
  
* Mon Sep 24 2001 Mike A. Harris <mharris@redhat.com> 4.1.0-3.8
- Silenced some Glide3 compiler warnings with Glide3-redhat-cleanup-1.patch.

* Sun Sep 23 2001 Mike A. Harris <mharris@redhat.com> 4.1.0-3.5
- Primary integration of changes in specfile to allow simple conditional
  build of fully debuggable modularized XFree86 packages.  This is done by
  enabling DebuggableBuild RPM macro at top of specfile, adding "dbg" to
  Release tag, and rebuilding.  The resulting RPM packages total in at 127Mb
  of data, as opposed to 55Mb or so regularly.  In order to debug this
  debuggable XFree86, a special patched version of gdb 5.0 is required, which
  is currently a work in progress based on a much older patch for gdb 4.18.

* Mon Sep 17 2001 Mike A. Harris <mharris@redhat.com>
- Changed xfs initscript to use find -cnewer instead of -newer to fix
  bug (#53737)

* Wed Sep  5 2001 Mike A. Harris <mharris@redhat.com> 4.1.0-3 
- Reordered font paths in xfs catalogue to put 75dpi first, etc..
- fixed couple critical specfile bugs that have slipped through til now

* Tue Sep  4 2001 Mike A. Harris <mharris@redhat.com>
- Fixed fs/config bug (MF#53103) as well as doing the same for XftConfig

* Fri Aug 31 2001 Mike A. Harris <mharris@redhat.com> 4.1.0-2
- Fixed a couple SHOULD-FIX bugs - fontpath order (SF#52413),
  metaSendsEscape bug (SF#49315)

* Wed Aug 29 2001 Mike A. Harris <mharris@redhat.com> 4.1.0-1.1
- Added "Requires: kernel-drm = 4.1.0" so that a matching kernel RPM package
  is installed and DRI works properly.  (Brought up by mkj/arjan, and agreed
  upon by me)

* Tue Aug 28 2001 Mike A. Harris <mharris@redhat.com> 4.1.0-1
- Added dont-build-pex-docs patch from Branden Robinson to disable building
  PEX documentation (deprecated and obsolete)
- Fix permissions on XftConfig, and other source files. (MF#52735)
- Bravely bumping version to 4.1.0-1
- Added xinerama-extmod patch for bug (#52842)

* Mon Aug 27 2001 Mike A. Harris <mharris@redhat.com> 4.1.0-0.99.2
- Added Obsoletes: XFree86-ISO8859-2-Type1-fonts < 4.1.0, and provides
  ISO8859-2-Type1-fonts, to fix upgrade from 7.1, and prepare for future
  packaging.
- Removed (noreplace) from fs/config, I *want* it to replace.
  
* Sun Aug 26 2001 Mike A. Harris <mharris@redhat.com> 4.1.0-0.99.1
- Completed font related fixups (hopefully)
- Added specfile buildroot install time removal of fonts.dir files as they
  should never ever be included in the RPM packaging, but generated at
  runtime instead.

* Fri Aug 24 2001 Mike A. Harris <mharris@redhat.com> 4.1.0-0.20.5
- Added XFree86-4.1.0-ati-pciids-cleanup.patch, which includes misc
  cleanups to the PCI tables for ATI hardware.
- Added ati-radeon-dri-buildfix from notting@redhat.com which hopefully
  fixes bug (#51884)

* Tue Aug 21 2001 Mike A. Harris <mharris@redhat.com>
- Completed font screwup overhaul take1.

* Mon Aug 20 2001 Mike A. Harris <mharris@redhat.com> 4.1.0-0.20.1
- Added XFree86-4.1.0-s3virge-mx.patch to fix some corruption issues on
  S3 Virge MX hardware.
- BuildPreReq: rpm >= 4.0.3  (parameterized macro fix)

* Sat Aug 18 2001 Mike A. Harris <mharris@redhat.com>
- Exclude XFree86 doc dir from, and add xdm pixmaps to s390 arch.

* Wed Aug 15 2001 Mike A. Harris <mharris@redhat.com> 4.1.0-0.20.0
- Added xman-soelim-fix to fix bug (#51037).
- Modified cirrus-foobaroo patch to disable debug messages (#51179)
- Backed out an xfs change that breaks serving 3.3.6 servers.  Attempted
  workaround for (#)
- Disable ATI update patch to see if it fixes Radeon DRI bugs.

* Mon Aug 13 2001 Mike A. Harris <mharris@redhat.com> 4.1.0-0.9.13
- Added XFree86-4.1.0-radeon-slowdownthere.patch to fix bug where ATI
  Radeon hangs on faster computers when VT switching.
- Created fix for mkfontdir to force permissions on newly created fonts.dir
  and encodings.dir files to be mode 644, fixes bug (#51636)
- Added fix for iso8859-2 compose file (affects Mozilla)
- Added patch to prevent X error messages from referencing log file if
  it has not yet been opened.
- Created support for ATI Rage 128 SM (Xpert2000), and added rage128-SM patch
  to fix (#34732,#51230,#50231) <mharris@redhat.com>
- Created XFree86-4.1.0-locale-alias-en_GB.patch to fix (#47247,51169)
- Moved video hardware documentation in /usr/X11R6/lib/X11/doc to main
  XFree86 package as that is where the drivers are (#50828)
- Updated XFree86 dependancy on Mesa to -> 3:3.4.2-5

* Thu Aug  9 2001 Mike A. Harris <mharris@redhat.com> 4.1.0-0.9.12
- Synced with XFree86 stable branch to pick up upstream bugfixes
- Added support for Japanese 109 key USB keyboard

* Wed Aug  8 2001 Mike A. Harris <mharris@redhat.com>
- merged new changes into specfile
- added nn_NO, en_GB locale.alias support
- Added support to xfs.init for .ttc font files, and to use case
  insensitive regex when grepping for truetype fonts.  (#41169)

* Sun Aug  4 2001 Bill Nottingham <notting@redhat.com> 4.1.0-0.9.11
- port & apply necessary DRI fixes that fell out

* Thu Aug  2 2001 Mike A. Harris <mharris@redhat.com> 4.1.0-0.9.10
- Added custom Red Hat XftConfig to fix AA font problems (#49937)
- Added RPM_BUILD_ROOT to ia64 libxrx removal.. ;o(

* Tue Jul 31 2001 Mike A. Harris <mharris@redhat.com> 4.1.0-0.9.9
- Enabled "HasLinuxInput YES" to force wacom driver to get built with USB
  support with 2.4 kernel.  Fixes bug (#50453).
  
* Mon Jul 30 2001 Mike A. Harris <mharris@redhat.com>
- Attempted fix for (#50043) -frame option ignored when -id option used
  on xwd  (XFree86-4.1.0-xwd-frame-option.patch)
- Made XF86Config-4 outside ifnarch s390 as Bero claims s390 uses it.

* Thu Jul 26 2001 Mike A. Harris <mharris@redhat.com> 4.1.0-0.9.8
- Added improved X startup messages for debugging purposes
- Updated patch148 from ATI plus 2 minor buildfixes

* Wed Jul 25 2001 Mike A. Harris <mharris@redhat.com> 4.1.0-0.9.7
- Added XFree86-4.1.0-libXfont-put-eof.patch to fix bug (#48830) where
  the 100dpi/75dpi helvBO12.pcf.gz fonts were getting munged.
- Added XFree86-4.1.0-twm-coredumpfix.patch to fix (#49674)
- Added XFree86-4.1.0-cirrus-foobaroo-fix.patch from Egbert Eich to attempt
  to fix the Cirrus Logic problems.
- Fix libxrx problem on ia64 (#49990) by removing libxrx from non-x86/alpha

* Tue Jul 24 2001 Mike A. Harris <mharris@redhat.com> 4.1.0-0.9.4
- Added XF86Config and XF86Config-4 as owned config files (latter ghosted)
- Fixed s390 Buildprereq on gcc by unnegating macro test
- Apply patch 3003 (64bit.patch) to all 64bit arch's.

* Tue Jul 24 2001 Mike A. Harris <mharris@redhat.com> 4.1.0-0.9.3
- Worked around rpm parameterized macro processing bug that caused a problem
  with postun scripts - discovered by rpmlint.
- Reformatted all pre/post/postun/etc. scripts to be more readable and
  maintainable.
- Added patch8 to xterm resources to provide RFE (#48783)

* Mon Jul 23 2001 Mike A. Harris <mharris@redhat.com> 4.1.0-0.9.2
- Added bison, zlib-devel as Buildprereqs - discovered on s390 by
  <Karsten.Hopp@redhat.de>
- Added ati-radeon-ve patch from ATI (patch148)
- Made Prereq's on /usr/sbin/chkfontpath instead of on chkfontpath

* Sun Jul 22 2001 Mike A. Harris <mharris@redhat.com>
- ifnarchd patch1013 for s390

* Wed Jul 18 2001 Mike A. Harris <mharris@redhat.com> 4.1.0-0.9.1
- Created new macro __rmfontpath to be called from font package postun
  scripts to fix bug (#49243)

* Mon Jul 16 2001 Mike A. Harris <mharris@redhat.com>
- Added /usr/X11R6/man/man6, and other non existing manX dirs to XFree86-libs
  package so anything using them ends up having the dir owned by something.
- Removed unneeded shared lib stuff (Xv/Xxf86dga)

* Sun Jul 15 2001 Mike A. Harris <mharris@redhat.com> 4.1.0-0.9.0
- Added BuildPrereq: gcc >= 2.96-93 to guarantee compiler used supports
  the -fno-merge-constants option
- Made External Mesa usage conditionalized via WithExternalMesa so that it is
  easy to rebuild XFree86 with/without using external Mesa, which will be the 
  default at some point in the future.

* Wed Jul 11 2001 Mike A. Harris <mharris@redhat.com>
- Explicitly state mkfontdir path in __mkfontdir macro (#48829)

* Tue Jul 10 2001 Mike A. Harris <mharris@redhat.com>
- Removed SharedLibXdmGreet from host.def, it is the same as default anyway
- Removed tcl and tk as buildprereq's, Bero says they're not needed anymore

* Tue Jul 10 2001 Tim Powers <timp@redhat.com> 4.1.0-0.8.6
- don't require XFree86-compat-libs in XFree86-libs

* Tue Jul 10 2001 Mike A. Harris <mharris@redhat.com> 4.1.0-0.8.5
- Fixed missing requiredlibs on shared libXrender so that prelinking works.
- Built 4.1.0-0.8.4
- Woops, I left shared libXv and libXxf86dga on again by accident.
- Built 4.1.0-0.8.5
  
* Mon Jul  9 2001 Mike A. Harris <mharris@redhat.com> 4.1.0-0.8.1
- Fixed up xdm pre script
- Fixed up missing Latin2 Type1 fonts, they are now in the fonts/Type1 dir
- Removed shared libXv.so and libXxf86dga.so at request of XFree86 team,
  and in conjunction with discussion with Debian X maintainer.

* Mon Jul  9 2001 Mike A. Harris <mharris@redhat.com> 4.1.0-0.7.51
- Fixed ia64 Glide3 build failure.

* Sun Jul  8 2001 Mike A. Harris <mharris@redhat.com> 4.1.0-0.7.50
- Merged with xf-4_1-branch to pick up stable bugfixes, and removed
  XFree86-4.1.0-redhat-glint-missing-symbols.patch, also Banshee
  ramtiming fix picked up from the update. 
  
* Fri Jul  6 2001 Mike A. Harris <mharris@redhat.com> 4.1.0-0.7.12
- Really disabled string merging this time
- Added verify flag to /etc/X11/fs/config
- Disabled shared libraries Xv/xf86dga for standards compliance.  These
  libraries do not have a stable API and should not be shared.  It was
  a Bad Idea(tm) to ship these.

* Wed Jul  4 2001 Mike A. Harris <mharris@redhat.com> 4.1.0-0.7.8
- Disabled string merging in modules using ModuleLdFlags in host.def
- Added WORLDOPTS= to make World to get rid of the "-k" passed to make so
  that failed X builds will fail immediately instead of continuing on.

* Mon Jul  2 2001 Mike A. Harris <mharris@redhat.com> 4.1.0-0.7.6
- Phase 1 - Amalgamated all my local font related changes to get fonts
  working better in the new 4.1.0 release. Straightened out 75dpi/100dpi
  brokenness and split up packages.
- mkfontdir is now called in post(un)install scripts, and fonts.dir files are
  not installed as part of packages anymore because it was a bad broken idea
  to do so because these files should be generated, not provided.
- Added missing \ in main package post script

* Thu Jun 21 2001 Mike A. Harris <mharris@redhat.com> 4.1.0-0.7.5
- Added customer requested custom 1152x864x85Hz modeline

* Sun Jun 17 2001 Mike A. Harris <mharris@redhat.com>
- Reworked all ISO8859-* font subpackages for 4.1.0.  fonts.dir is not
  included in the packages, rather it is generated at post install time.
- Refixed (#31618)

* Sat Jun 16 2001 Mike A. Harris <mharris@redhat.com> 4.1.0-0.6.1
- More s390 cleanups

* Fri Jun 15 2001 Mike A. Harris <mharris@redhat.com> 4.1.0-0.6.0
- Integrated s390 patches sent by Than from Oliver Paukstadt

* Sat Jun  9 2001 Mike A. Harris <mharris@redhat.com> 4.1.0-0.5.6
- Cleaned up unneeded Freetype2 stuff in host.def

* Fri Jun  8 2001 Mike A. Harris <mharris@redhat.com> 4.1.0-0.5.6
- Take-1 at cleaning up some of the font related 'issues' due to the different
  way fonts are generated in 4.1.0.  Still many issues remaining.

* Wed Jun  6 2001 Mike A. Harris <mharris@redhat.com>
- Folding the external Mesa into XFree86 created as many problems as it
  solved.  The DRI CVS trunk has a more permanent solution worth checking out.
- Since the V4L drivers have aparently been included in the main XFree86
  package all this time, I've removed the separate package.

* Mon Jun  4 2001 Mike A. Harris <mharris@redhat.com> 4.1.0-0.1.5
- First stab at assimilating Mesa 3.4.2 package into XFree86 package
- Added missing symbols to glint driver (#42751)

* Mon Jun  4 2001 Mike A. Harris <mharris@redhat.com> 4.1.0-0.0.2
- Rebuilt against Mesa 3.4.2 in new environment

* Sat Jun  2 2001 Mike A. Harris <mharris@redhat.com> 4.1.0-0.0.1
- XFree86 4.1.0 released - built 4.1.0-0.0.1

* Thu May 31 2001 Mike A. Harris <mharris@redhat.com> 4.0.99.901-0.0.6
- Remove GLw manpages since we don't ship libGLw (#41791)
- I finally got XIE and PEX disabled completely for sure this time absolutely
  no question.  No really...  It's gone.

* Wed May 30 2001 Mike A. Harris <mharris@redhat.com> 4.0.99.901-0.0.4
- Updated to 4.0.99.901, removed unneeded patches
- Removed Glide3 Provides/Obsoletes from devel package, and removed the
  Glide3 devel stuff from that package also - only X needs it during build
- Removed BuildGlide3 conditional - Glide3 will always be built from now on
- Added conditionals BuildPEX & BuildXIE.  These have officially been obsoleted
  by XFree86, and are no longer actively supported or used by anything.

* Mon May 28 2001 Mike A. Harris <mharris@redhat.com> 4.0.99.900-0.2.5
- Added "Options" database file, and also the following apps and their
  manpages:  dpsexec, dpsinfo, texteroids, xftcache
- Removed hardcopy doc creation code (groff) from specfile.  The XFree86
  makefiles have been fixed now to do this themselves properly.
- Removed Glide3 headers from XFree86-devel.  Only needed during build, no
  apps should be linking to Glide3.
- Simplified filelist for libs subpackage by using globs instead of hard
  coded library version numbers.
- Removed use-cpp patch, done with imake now.

* Sun May 27 2001 Mike A. Harris <mharris@redhat.com> 4.0.99.900-0.2.2
- Merged bero's changes to my local sources, and changed libXmuu inclusion
  from libXmuu.* to libXmuu.1.0, so that the *.so doesn't get picked up also,
  as it should be in the devel package.

* Mon May 21 2001 Bernhard Rosenkraenzer <bero@redhat.com> 4.0.99.900-0.2.1
- Add missing libXmuu.* files

* Sun May 20 2001 Mike A. Harris <mharris@redhat.com>
- Many fixes from H. J. Lu <hjl@gnu.org> including enhanced parallel make,
  xterm-xaw3d, pex patches, specfile updates, build enhancements and a
  partridge in a pear tree.  ;o)
- Fixed insane off-the-screen indenting levels in xfs.init

* Sat May 19 2001 Mike A. Harris <mharris@redhat.com>
- Updated to 4.0.99.900
- Updated with the latest parallelmake patch from H. J. Lu <hjl@gnu.org>
- Added new specfile option ParallelBuild, so that any parallel build
  stuff can be conditionally defined in the specfile in case the parallel
  make patch breaks in the future.

* Fri May 11 2001 Bernhard Rosenkraenzer <bero@redhat.com>
- Fix build

* Wed May  9 2001 Mike A. Harris <mharris@redhat.com> 4.0.99.3-0
- Updated 4.0.99.x package to 4.0.99.3 release, forward ported all
  relevant changes that have occured in 4.0.3 packaging since March 27th
  until now, and brought the 4.0.3 specfile changelogs into the 4.0.99.3
  spec changelog.  The two releases should be syncronized now.

* Mon May  7 2001 Mike A. Harris <mharris@redhat.com> 4.0.3-14
- Syncronize XFree86 with Mesa 3.4.1-1
- Disable alpha-hack from May 3rd and add new patch from Compaq to replace it

* Fri May  4 2001 Mike A. Harris <mharris@redhat.com> 4.0.3-13
- Updated patch0 to latest XFree86 stable branch for 4.0.3.  Fixes many
  3dfx bugs in tdfx driver.
- Moved locale data from /usr/X11R6/lib/X11/locale in main package to
  XFree86-libs package where it belongs. (#38408)
- Corrected dumb reversal in XFree86CustomVersion Imake define in specfile
    
* Thu May  3 2001 Mike A. Harris <mharris@redhat.com> 4.0.3-12
- Reverted ia64-int10 patch from Alpha.
- Added XFree86-4.0.3-alpha-hack-bypass-int10bug.patch from
  Jay Estabrook for Alpha.

* Wed May  2 2001 Mike A. Harris <mharris@redhat.com> 4.0.3-11
- Removed RPM_BUILD_ROOT from glide section (#38031)
- Enabled XFree86-4.0.2-ia64-int10.patch on alpha as well for testing.

* Wed Apr 25 2001 Mike A. Harris <mharris@redhat.com>
- Added XFree86-4.0.3-compose-kill-ctrl-shift-t.patch to fix (#23473)

* Mon Apr 23 2001 Mike A. Harris <mharris@redhat.com>
- Added rhl-startupmessages patch to aide debugging and troubleshooting
  bug reports.  This should increase the usefulness of user submitted
  XFree86 log files and decrease the turnaround time on requesting info
  and waiting for someone to provide that info.  Patch doesn't do much yet,
  but will be enhanced later.
- Added xset manpage enhancement

* Sat Apr 21 2001 Mike A. Harris <mharris@redhat.com> 4.0.3-10
- ifarch'd XFree86-4.0.2-agpgart-load.patch to only apply on non-alpha

* Sat Apr 14 2001 Mike A. Harris <mharris@redhat.com> 4.0.3-9
- Removed dependancy of main XFree86 package on xfs by moving the XFree86
  server modules "/usr/X11R6/lib/modules/{codeconv,fonts}/*" from the xfs
  subpackage to the main XFree86 package as they never belonged in the xfs
  package in the first place.  This is an ancient packaging error.
- Added patch from Tim Waugh to fix Xaw password entry in vnc.  (#19231)

* Thu Apr 12 2001 Mike A. Harris <mharris@redhat.com>
- Killed ancient non-FHS compliant symlink to /usr/man/X11
- Disabled XFree86-4.0.3-savage-glitch.patch to fix (#34376)

* Mon Apr  9 2001 Mike A. Harris <mharris@redhat.com>
- Made glidelink get called before ldconfig in %%post libs

* Mon Apr  9 2001 Mike A. Harris <mharris@redhat.com> 4.0.3-8
- Simplified the main package %%pre script symlink munge code
- Fixed bug in %%post xfs section - inadvertently added in 4.0.3-6 release
- Disable patch #220 as it is unnecessary - taken care of via Imake ages ago.

* Sun Apr  8 2001 Mike A. Harris <mharris@redhat.com> 4.0.3-7
- Fixed (#32574) by adding a preinstall script on xdm which moves the dir
  /etc/X11/xdm/authdir to /var/lib/xdm/authdir if it exists, and symlinking
  /etc/X11/xdm/authdir to it.  Corrected the filelist for xdm to include
  these changes.
- Fixed alpha build failure with tga driver patch, ifdef with no macro.

* Fri Apr  6 2001 Mike A. Harris <mharris@redhat.com> 4.0.3-6
- Force enabled BuildXinerama and BuildXineramaLibrary in hosts.def
- FHS compliant manpage sections (4x/7x)

* Thu Apr  5 2001 Mike A. Harris <mharris@redhat.com>
- Added new patches submitted by Compaq for various drivers, etc.
  XFree86-4.0.3-compaq-alpha.patch, XFree86-4.0.3-compaq-glint.patch
  XFree86-4.0.3-compaq-radeon.patch, XFree86-4.0.3-compaq-r128.patch
  XFree86-4.0.3-compaq-mga.patch, XFree86-4.0.3-compaq-tga.patch
  (courtesy of Jay Estabrook)

* Thu Mar 29 2001 Mike A. Harris <mharris@redhat.com> 4.0.3-5
- XFree86 4.0.3 defaults to building libfreetype if Xft is being built,
  so freetype is now disabled with Imake defines.
- Removed shared libsXxf86dga and libXv hack I added on Mar 9 and
  did it properly with Imake defines.  Also fixes (#31232)

* Wed Mar 28 2001 Mike A. Harris <mharris@redhat.com> 4.0.3-4
- Added patch XFree86-4.0.3-glide3-libdir.patch so tdfx driver
  can find the Glide3 libs included with X package.
- Minor xfs.init fix
- Added XFree86-4.0.3-mga-hwcursor-fix.patch

* Tue Mar 27 2001 Mike A. Harris <mharris@redhat.com>
- Updated g450 port from 4.0.3 to XFree86-4.0.99.1-mga-g450-dualhead.patch
- Updated Savage driver dropin to version 1.15
- Added patches 405 - 408 from 4.0.3-4 build

* Sun Mar 25 2001 Mike A. Harris <mharris@redhat.com>
- Initial specfile fork of 4.0.99.1 from 4.0.3-3
- Removed unneeded patches:  XFree86-4.0.1-dri-sym.patch,
  XFree86-4.0.2-mga-busmstr.patch, XFree86-4.0.2-r128-busmstr2.patch,
  XFree86-4.0.2-r128-mobility.patch, XFree86-4.0.2-agpgart-load.patch,
  XFree86-4.0.2-r128-drm-do-wait-for-fifo.patch
- Updated patches: XFree86-4.0.99.1-parallelmake.patch,
  XFree86-4.0.99.1-locale-euro.patch, XFree86-4.0.99.1-winkey-alt-meta.patch  

* Fri Mar 23 2001 Mike A. Harris <mharris@redhat.com> 4.0.3-3
- Drumroll...... Final (or is it?) working G450 dualhead update.  ;o)

* Thu Mar 22 2001 Mike A. Harris <mharris@redhat.com>
- Added pam patch for xdm from Nalin <nalin@redhat.com> Patch404

* Wed Mar 21 2001 Mike A. Harris <mharris@redhat.com>
- Fixed uninitialized memory reference in xlib (Patch401)  (#32222)
- Make libs subpackage depend on kudzu-devel, pciutils-devel for 
  Glide3 (#32534)
- Matrox G450 updates

* Mon Mar 19 2001 Mike A. Harris <mharris@redhat.com> 4.0.3-2
- Fixed glitch in %%post xfs section of spec (#32281)
- Set "umask 133" in xfs initscript so that fonts.dir/fonts.alias files 
  created during script execution work also for non-root users that may
  have changed root's umask.
- Updated Mesa dependancy in specfile to 3.4-13

* Sun Mar 18 2001 Mike A. Harris <mharris@redhat.com>
- Removed XFree86-4.0.1-xterm-appdefaults.patch as it was redundant

* Sat Mar 17 2001 Mike A. Harris <mharris@redhat.com> 4.0.3-1
- New XFree86 4.0.3 released and integrated.
- Updated patches for 4.0.3, removed unneeded patches.
- Built 4.0.3-1

* Fri Mar 16 2001 Mike A. Harris <mharris@redhat.com>
- Reverted G450 driver back to dwmw2's driver.
- Built 4.0.2a-2

* Thu Mar 15 2001 Mike A. Harris <mharris@redhat.com> 4.0.2a-1
- Added XFree86-4.0.2-locale.patch from Phil Knirsch <pknirsch@redhat.com>
  which should fix all problems with euro locales, and other locale issues
  including bug id's (26300,21882,28447, others)
- xfs crash errors should all be fixed now by the XFree86 stable branch
  patch.  Bugzilla (#22538)

* Wed Mar 14 2001 Mike A. Harris <mharris@redhat.com> 4.0.2a-1
- New patch XFree86-4.0.2a-mga-g450-dual_6.patch - G450 driver update 
  from Luugi Marsan <lmarsan@matrox.com>
- Added new euro locale stuff from Phil Knirsch <pknirsch@redhat.com>
- Added XFree86-4.0.2-r128-drm-do-wait-for-fifo.patch from Gareth Hughes
  which should fix the r128 errors in (#26999)
  
* Tue Mar 13 2001 Mike A. Harris <mharris@redhat.com>
- Added provides entries for Glide3 in libs and devel subpackages
- Take 2 of XFree86-4.0.2a-im-being-included-and-i-cant-get-up2.patch
- Moved XftConfig file to /etc/X11 and made compatibility symlink.

* Fri Mar  9 2001 Mike A. Harris <mharris@redhat.com>
- Updated main tarball to 4.0.2a (even though it's the same code we had before
  with 4.0.2 + stable branch patch).
- Updated stable branch patch to bring 4.0.2a up to date with xf-4_0_2a-branch
- Nvidia nv driver updated with MANY fixes from XFree86 stable branch
- Added shared libraries: libXv.so, libXxf86dga.so
- Re-enabled Sparc build.  That machine is slow, someone
  needs to put a spark under it to get it going.  ;o)
- Fixed (#13882) with XFree86-4.0.2-winkey-alt-meta.patch
- Fixed (#19308) added X11R6-contrib obsolesence

* Fri Mar  9 2001 Bill Nottingham <notting@redhat.com> 4.0.2-12.1
- fix glide dependencies

* Thu Mar  8 2001 Mike A. Harris <mharris@redhat.com> 4.0.2-12
- Fixed alpha/ia64 build problems
- Built 4.0.2-12

* Tue Mar  6 2001 Mike A. Harris <mharris@redhat.com>
- Created XFree86-4.0.2-r128-mobility.patch to enable external display
  on Rage Mobility laptops, etc.
- Added XFree86-4.0.2-xft-match.patch (from Bero) (#30836)
  
* Mon Mar  5 2001 Mike A. Harris <mharris@redhat.com>
- Added XFree86-4.0.2-alpha-pci-resource.patch (#30417)

* Sat Mar  3 2001 Mike A. Harris <mharris@redhat.com>
- Glide3 is back (was previously removed on Feb 22)
- Removed loaderProcs.h hack, and replaced with a patch.
- Tidied up a tonne of XFree build warnings
- Added XFree86-4.0.2-im-being-included-and-i-cant-get-up.patch stop
  loaderProcs.h from being wrongly included in building Xnest due to
  a compiler bug.

* Fri Mar  2 2001 Mike A. Harris <mharris@redhat.com>
- Added mga and r128 busmaster patches that Todd Nix <todd@xymox.us.dell.com>
  sent me from Kevin E Martin <martin@valinux.com>.

* Wed Feb 28 2001 Mike A. Harris <mharris@redhat.com> 
- Updated xf-4_0_2-branch patch to todays latest stable code
- Removed unneeded patches after update: XFree86-4.0.2-time.patch,
  XFree86-4.0.2-sis-unresolved-memcpy.patch    
- Added XFree86-4.0.2-agpgart-load.patch from Bill Nottingham to force
  load AGPgart kernel module when a DRI module is loaded.
- Fixed "chmod" in xfs.init (#18573)
- Added BuildPreReq ncurses-devel
- Repaired ia64 int10 patch
- Tidied up specfile, particularly the host.def generation section, and 
  incorporated xfree86.def mess into host.def section where it belongs.

* Tue Feb 27 2001 Mike A. Harris <mharris@redhat.com> 4.0.2-11
- Added updated driver for Savage chipset.  Should fix all known issues
  with Savage cards that I'm aware of.
- Removed Prereq of chkfontpath on xfs subpackage and modified xfs initscript
  to only call chkfontpath if it is installed.
  
* Mon Feb 26 2001 Mike A. Harris <mharris@redhat.com> 4.0.2-10
- Added specfile %%pre fix for (#26857) - problem upgrading to
  Wolverine from Red Hat 5.2 due to directory/symlink fu glitch.
- Enabled Utempter for xterm with "UseUtempter" in specfile
- Added neomagic softcursor patch for (Helge Deller <hdeller@redhat.de>)
- Built 4.0.2-10
- Created patch XFree86-4.0.2-sis-unresolved-memcpy.patch to fix
  bugs (#19530,24670)

* Fri Feb 23 2001 Mike A. Harris <mharris@redhat.com>
- Added spec hack to fix bad include of loaderProcs.h in miinitext.c
  I believe this fixes some of the r128 DRI problems.  I can't get
  r128 DRI to crash anymore now anyways.  It isn't mind blowingly 
  fast though.  May have fixed other problems as well.  X seems much
  smoother now, and VT switching is much faster also.

* Thu Feb 22 2001 Mike A. Harris <mharris@redhat.com>
- Added ExcludeArch tag to quell failed sparc builds (unsupported)
- Re-enabled DRI for mga/r128, but they still do not work

* Sat Feb 17 2001 Mike A. Harris <mharris@redhat.com>
- Updated fix for xfs death bug with truetype fonts.
- Added chkfontpath require to xfs subpackage (#19603)
- Added XFree86-4.0.2-banshee-ramtiming.patch to fix (#26351,#18810)
- Added ia64-int10 patch. (Bill Nottingham)

* Thu Feb 15 2001 Mike A. Harris <mharris@redhat.com>
- Fixed xfs.config

* Tue Feb 13 2001 Mike A. Harris <mharris@redhat.com>
- Disabled DRI drivers r128 and mga because they are broken.
- Built XFree-4.0.2-8
- Fixed bad noarch thing
- Built XFree-4.0.2-9

* Mon Feb 12 2001 Mike A. Harris <mharris@redhat.com>
- Merged in separate XFree86-ISO8859-2 font package

* Sun Feb 11 2001 Mike A. Harris <mharris@redhat.com>
- Added 1400x1050 modeline patch for newer laptops
- Misc fixups
- Disabled DRM kernel module building as we don't use these modules
  anyway.
- Updated 4.0.2-branch patch
- Updated XFree86-4.0.2-xfree86.lst.patch

* Thu Feb 08 2001 Mike A. Harris <mharris@redhat.com>
- Internationalized xfs and xdm initscripts

* Wed Feb 07 2001 Mike A. Harris <mharris@redhat.com>
- New fix for Cirrus 5480 (H.J. Lu)
- Matrox g450 patch that _hopefully_ works this time (from dwmw2)

* Tue Feb 06 2001 Mike A. Harris <mharris@redhat.com>
- (#25890,#26131) tdfx dri driver not included.. specfile mixup, fixed.
- (#23896) Added option for building with Glide2 (default=off).  Dunno if
  it works or not as I'm not testing it.  If someone wants to further the
  enhancement at all, I'll accept specfile patches to add any missing bits. ;o)
- (#25131) Fixed xfs.config file glitch (Truetypex typos), and a similar
  bug in specfile hack.
- Updated to recent XFree86 stable bug fixes (Patch #1)
- Fix temp files vulnerabilites in xman on systems with mkstemp()
- Fix temp vulnerabilities in Xaw/MultiSrc.c
- Fix temp file vulnerability in gccmakedep based on report from Alan Cox.
- Fix temp file vulnerability in Imake.rules
- Fix temp file vulnerability in InstallManPageAliases
- Fix Neomagic 2200 screen corruption
- Add an imake control for determining when xload should be installed set-gid

* Thu Jan 25 2001 Mike A. Harris <mharris@redhat.com>
- Added g450 patch from Matrox.  Lets see some dualhead action baby!
- Filtered out M$ Windows CR's from the Matrox patch, hope I got them
  all.  Windows bad, Linux good.  ;o)
- Removed all prior g450 patches as the new one repaces them all
- Many spec file simplifications, and general tidy up job.

* Wed Jan 24 2001 Bill Nottingham <notting@redhat.com>
- fix perms on xload

* Wed Jan 24 2001 Matt Wilson <msw@redhat.com>
- chmod 644 XftConfig before piping to it

* Wed Jan 24 2001 Mike A. Harris <mharris@redhat.com>
- Disable Cirrus 5480 patch as it wont apply cleanly to 4.0.2.
- Removed v4l patch - its in 4.0.2 already
- (#23701) devel dependant on libs instead of main package.
- Added TrueType font dirs to config files for the ttfonts package
- Numerous other tweaks
- XFree86-4.0.2-4 built

* Tue Jan 23 2001 Mike A. Harris <mharris@redhat.com>
- Fixed xfs initscript to only start at boot time if X is installed.
- Put eurofonts package back and fixed it up with suggestions from
  H. J. Lu - as 2 font files are still needed.
- Changed xload %%install time chmod to %%attr instead
- Tidied up %%install section, removing redundancies.
- Added Cirrus Logic 5480 patch from from Egbert Eich (#24177)

* Mon Jan 22 2001 Mike A. Harris <mharris@redhat.com>
- Removed manpage "hack" section from specfile
- Removed eurofont tarball entirely.  It's included in X already under
  different names now.
- Removed mga, ATI, mesa patches from yesterday as they fail the
  build requiring many other missing items.
  
* Sun Jan 21 2001 Mike A. Harris <mharris@redhat.com>
- Added ATI driver patch from XFree CVS - lots of new fixes
- Added mga driver patch from XFree CVS (mainly for G450)
- Added mesa patch from XFree CVS
- Added BuildPrereq: pam-devel  (Bill Crawford <billc@netcomuk.co.uk>)
- Commented out BuildPrereq: pam-devel as it failed me
- Remove eurofont .bdf files after pcf's are created to quell duplicate
  font errors.

* Sat Jan 20 2001 Mike A. Harris <mharris@redhat.com>
- Added Xft update from XFree CVS
- Updated %%clean section
- Changed specfile bunzip references to bzcat
- Fixed all specfile references of "tar x" to "tar xf -"
- Added romanian-keyboard-fix from Cristian Gafton <gafton@redhat.com>

* Thu Jan 18 2001 Mike A. Harris <mharris@redhat.com>
- ATI r128 update from ATI.

* Wed Jan 17 2001 Mike A. Harris <mharris@redhat.com>
- Disabled tdfx builds as they die with missing glide3 libs
  (at least in RHL 7.0 it does)

* Tue Jan 16 2001 Mike A. Harris <mharris@redhat.com>
- Added BuildPrereq: flex >= 2.5.4a
- Added BuildPrereq: freetype-devel >= 2.0.1
- Added BuildPrereq: Glide3-devel >= 20001220 for tdfx

* Mon Jan 15 2001 Mike A. Harris <mharris@redhat.com>
- Updated fhs patch for 4.0.2
- Updated portuguese patch for 4.0.2

* Thu Jan 11 2001 Mike A. Harris <mharris@redhat.com>
- Integrated Matrox G450 driver for testing from Matrox

* Mon Jan 8 2001 Mike A. Harris <mharris@redhat.com>
- Added xfree86.lst patches from Brent Fox and also (#5977)
 
* Sat Jan 6 2001 Mike A. Harris <mharris@redhat.com>
- Misc spec file fixups

* Fri Jan 5 2001 Mike A. Harris <mharris@redhat.com>
- Integrated ATI driver from Michael Smith <msmith@ati.com>

* Wed Jan 3 2001 Mike A. Harris <mharris@redhat.com>
- Built 4.0.2 release 1

* Thu Dec 28 2000 Bernhard Rosenkraenzer <bero@redhat.com>
- Add a couple of missing man pages, noted by Thayne Harbaugh <thayne@plug.org>
- Use system freetype, now that we've updated
- Add missing XftConfig file

* Thu Dec 28 2000 Bill Nottingham <notting@redhat.com>
- don't list the driver modules explicitly; ship them all

* Thu Dec 21 2000 Bill Nottingham <notting@redhat.com>
- integrate tdfx_dri into main XFree86 package

* Tue Dec 19 2000 Bill Nottingham <notting@redhat.com>
- fix typos in xkb symlink/dir munging

* Tue Dec 19 2000 Bernhard Rosenkraenzer <bero@redhat.com>
- Add missing Xft (Xrender) includes in -devel
- Move xkb files back to their old locations, we can't replace directories
  with symlinks
- Add /etc/X11/xkb -> /usr/X11R6/lib/X11/xkb symlink for compatibility
- 4.0.2
- Get rid of twfix patch (it's in 4.0.2)
- Patch 302 must be applied with -p0, not -p1
- Add a %%clean section
- Get rid of /etc/X11/xdm/xdm-config in XFree86-xdm. Since kdm uses it, as well,
  it should be in xinitrc

* Thu Dec 14 2000 Mike A. Harris <mharris@redhat.com>
- Added XFree86-4.0.1-twfix.patch from bhuang@redhat.com to fix
  zh_TW locale.
- Added locale.alias patch from Jakub Jelinek.
- Removed unneeded patches, and tidied spec file a bit (yeah right). ;o)

* Wed Dec 13 2000 Bill Nottingham <notting@redhat.com>
- tweak the -pic patch so it works with the ELF loader (in theory)
- don't try and build the kernel modules

* Sun Dec 10 2000 Bill Nottingham <notting@redhat.com>
- reapply the parallelmake patch
- hm, libX11 and libXmu are now .6.2

* Sat Dec 9 2000 Mike A. Harris <mharris@redhat.com>
- Updated to CVS version xf-4.0.1Z

* Sat Dec  9 2000 Bill Nottingham <notting@redhat.com>
- add back in some patches (FHS, Xwrapper)
- make it build on ia64 (hopefully)

* Fri Dec 8 2000 Mike A. Harris <mharris@redhat.com>
- Added patch XFree86-4.0.1h-xf86Wacom.c-kernelheaderclash.patch to
  fix 4.0.1h build failure.

* Wed Dec 6 2000 Mike A. Harris <mharris@redhat.com>
- Fixed bug (#21303) changed 2 uses of arch "i386" to "%{ix86}"
- Remove dependancy on tar 1.13.18 by calling bunzip2 and piping to tar
- Removed I810Drm.tar.gz entirely as it smashes other dri code (mga,etc)
  and is ancient

* Wed Dec 6 2000 Mike A. Harris <mharris@redhat.com>
- Updated to CVS version xf-4.0.1h which includes many updates and
  integrates many Red Hat patches directly into XFree86 CVS.

* Sat Nov 10 2000 Bernhard Rosenkraenzer <bero@redhat.com>
- Update to current. This should fix, among other things, DRI/DRM stuff on
  Matrox cards and i18n.
- Fix build with tar 1.13.18
- Add XKB patch for Romanian keyboards from Christian Gafton <gafton@redhat.com>
- Fix up Euro sign support

* Wed Oct 25 2000 Bernhard Rosenkraenzer <bero@redhat.com>
- Don't apply the PIC patch on non-ia64 platforms, it breaks X startup on x86.

* Mon Sep 25 2000 Bill Nottingham <notting@redhat.com>
- minor tweaks for ia64/glibc-2.2 build

* Thu Aug 24 2000 Bill Nottingham <notting@redhat.com>
- never mind, it doesn't. Wheee.

* Wed Aug 23 2000 Bill Nottingham <notting@redhat.com>
- oops, the r128 mobility patch breaks regular r128 cards

* Tue Aug 22 2000 Bill Nottingham <notting@redhat.com>
- fix DGA for real
- add support for the r128 Mobility chips

* Tue Aug 15 2000 Bill Nottingham <notting@redhat.com>
- fix xterm app-defaults file (#13584)
- don't build a shared xdm greeter lib

* Mon Aug 14 2000 Bill Nottingham <notting@redhat.com>
- fixes for MGA dri (text corruption)
- spell Portuguese correctly in keymap list (#12343)
- fix some absolute symlinks (#16133)
- fix xman's man config path (#15974)
- fix broken xdm pam code (#15952)
- fix bug in ATI driver (#14344)

* Fri Aug 11 2000 Bill Nottingham <notting@redhat.com>
- revert some of the i810 code; it breaks VC switching

* Sun Aug  6 2000 Bill Nottingham <notting@redhat.com>
- fix DGA so that 4.x-compiled DGA1 apps can run against 3.3.x servers
- fix tempfile handling in makedepend
- use cpp, not gcc -E 

* Fri Aug  4 2000 Bill Nottingham <notting@redhat.com>
- more CVS updates (Neomagic fixes, some i810)
- fix sparc build

* Thu Aug  3 2000 Bill Nottingham <notting@redhat.com>
- do *not* do xfs stop/start in condrestat

* Wed Aug  2 2000 Bill Nottingham <notting@redhat.com>
- update CVS (i810 fixes, others)
- move some more files out of -xdm, into xinitrc package
- remove /usr/share/fonts/default/TrueType from default xfs config (#14683)
- fix weirdness in the i810 driver update

* Wed Aug  2 2000 Matt Wilson <msw@redhat.com>
- hack to work around gcc bug triggered by xwd (patch207)
- modified xfs post script to add in no-listen = tcp per Bill's request

* Tue Jul 25 2000 Elliot Lee <sopwith@redhat.com>
- Some i810/i815 stuff (new I810Drm.tar.gz, updated to xf4.0.1-I810copy.patch only to find out
that it is already included in this source tree).

* Mon Jul 24 2000 Bill Nottingham <notting@redhat.com>
- add patch for xf86 vidmode extension
- add icelandic keymap to list of keymaps

* Sat Jul 22 2000 Bill Nottingham <notting@redhat.com>
- hey, we recognize the geforce2 now. Wonder if it works. :)

* Thu Jul 19 2000 Bill Nottingham <notting@redhat.com>
- oops, I broke the sparc Mach64 patch on sparc

* Wed Jul 18 2000 Bill Nottingham <notting@redhat.com>
- move initscript back
- update CVS
- remove Mesa (use its own separate package for easier updating)
- kill the GL wrapper
- fix linking of dri modules so that symbol resolution with Mesa works right
- add sparc Mach64 patch from DaveM
- fix sparc Mach64 patch so it builds
- add ffb patch from Jakub
- fix xfs user creation

* Fri Jul 14 2000 Elliot Lee <sopwith@redhat.com>
- Fix Mesa library version info
- Set Mesa package version to reflect Mesa version (not the XFree86
  version), and set release to something that will facilitate upgrades
  from older Mesa pkgs while still being informative.
- Only pass -j to toplevel make, which takes care of passing it on down.

* Thu Jul 13 2000 Preston Brown <pbrown@redhat.com>
- fixed xfs condrestart to do a real stop/start.
- fonts.* files in font directories are config(noreplace)

* Thu Jul 13 2000 Elliot Lee <sopwith@redhat.com>
- Update Mesa to 3.2 release.
- Use mmx/sse/x86 stuff for Mesa on 386 and up, not just if building for 686 (since MMX is
available on 586 many times, and since the functionality is runtime-configured).
- Try to integrate newer i810/i815 driver (unfinished)

* Mon Jul 10 2000 Bill Nottingham <notting@redhat.com>
- update CVS while I'm here
- don't use ix86 PCI code on ia64
- fix some int/long bogosity in some of the drivers

* Sat Jul  8 2000 Bill Nottingham <notting@redhat.com>
- update CVS
- build with new compiler to fix Xserver problems on i386
- add parallel make patch from H. J. Lu

* Tue Jul  4 2000 Bill Nottingham <notting@redhat.com>
- oops, open the right software Mesa lib
- build DRI everywhere

* Mon Jul  3 2000 Bill Nottingham <notting@redhat.com>
- fix Mesa install
- add Romanian keymap so keymaps get installed

* Sun Jul  2 2000 Bill Nottingham <notting@redhat.com>
- add console.apps file for xserver (#13325)
- prereq chkfontpath for font packages
- update CVS
- bump version to 4.0.1
- add lemming patch

* Fri Jun 30 2000 Bill Nottingham <notting@redhat.com>
- update CVS, sparc patches now included
- ship pam files
- point X symlink to Xwrapper, not XFree86

* Thu Jun 29 2000 Bill Nottingham <notting@redhat.com>
- fix pamsession, xfsredhat patches
- turn off joystick, it relies on magic symbols defined *nowhere*

* Wed Jun 28 2000 Preston Brown <pbrown@redhat.com>
- merged in a bunch of patches from 3.3.6 that somehow got dropped including:
- xkb changes
- some xfs changes
- xterm app-defaults
- pam session fix for xdm
- define some paths in host.def instead of a wild mess of patches
- kill compat links from /etc/X11/<dirname> to /usr/X11R6/lib/X11/<dirname>

* Wed Jun 28 2000 Bill Nottingham <notting@redhat.com>
- add Mesa wrapper
- put Mesa libs in /usr/lib
- return of Xwrapper
- take setuid off XFree86

* Wed Jun 28 2000 Jakub Jelinek <jakub@redhat.com>
- remove 3 obsolete SPARC patches
- add 2 new ones

* Tue Jun 27 2000 Bill Nottingham <notting@redhat.com>
- put setuid on XFree86 (temporary)
- yank setuid off xload 
- put the xfs %%pre back in
- xfs initscript munging
- fix ia64 patches

* Tue Jun 27 2000 Bernhard Rosenkraenzer <bero@redhat.com>
- Update to current CVS

* Thu Jun 22 2000 Bill Nottingham <notting@redhat.com>
- return of the font %%post/%%postuns
- move some of the xdm stuff to xinitrc
- put libglut in with Mesa

* Sun Jun 18 2000 Matt Wilson <msw@redhat.com>
- build glint module on alpha

* Thu Jun 15 2000 Bernhard Rosenkraenzer <bero@redhat.com>
- Fix up Xaw (Bugs #11404 and #11426)
- more FHS fixes (fix bug #11358 and some related unreported bugs)

* Wed Jun 14 2000 Bernhard Rosenkraenzer <bero@redhat.com>
- split off Mesa and Mesa-devel
- FHSify
- fix build on alpha and ia64

* Wed Jun  7 2000 Bill Nottingham <notting@redhat.com>
- merge in ia64 fixes

* Fri Jun  2 2000 Nalin Dahyabhai <nalin@redhat.com>
- change PAM configuration to use system-auth
- build fix for Sparc

* Tue May 23 2000 Jakub Jelinek <jakub@redhat.com>
- don't define GlxStubLib if DllModules is not defined -
  otherwise things don't compile on i386

* Mon May 22 2000 Jakub Jelinek <jakub@redhat.com>
- support ffb, leo and cg6 on sparc
- only switch to dlopen() loader on selected architectures

* Thu May 11 2000 Bill Nottingham <notting@redhat.com>
- switch to dlopen() loader

* Wed May 10 2000 Bill Nottingham <notting@redhat.com>
- add man pages to -devel

* Sun May  7 2000 Bill Nottingham <notting@redhat.com>
- more directory shuffles

* Fri May  5 2000 Bill Nottingham <notting@redhat.com>
- more random fixes

* Wed May  3 2000 Bill Nottingham <notting@redhat.com>
- various fixes
- fix specfile for ia64
- merge drivers back into XFree86 package

* Sun Apr 23 2000 Bernhard Rosenkraenzer <bero@redhat.com>
- update xf86cfg
- fix up the xf86cfg patch
- various fixes

* Thu Apr 20 2000 Bernhard Rosenkraenzer <bero@redhat.com>
- Fix up x11perfcomp and move it to -tools
- Fix up xfs (missing init script...)
- chkconfig'ize xfs
- move pswrap to -devel

* Sat Apr  8 2000 Bernhard Rosenkraenzer <bero@redhat.com>
- Add xf86cfg (successor to XF86Setup, taken from the XFree86 4.0a tree
  with permission from the patch author)
- Move the directory fixup stuff from %pre to %triggerpostun -- XFree86 < 3.9
  We don't want to fix things twice...

* Wed Apr  5 2000 Bernhard Rosenkraenzer <bero@redhat.com>
- Fix post script breakage
- Disable build root strip policy (drivers can't be stripped)
- strip the stuff we can safely strip manually
- add /usr/include stuff
- add some stuff from Mesa - we don't really want to obsolete Mesa
  without providing GLU and glut.
- move some man pages from XFree86 to XFree86-tools, where they belong.
- move some files to subpackages:
  beforelight, xclipboard, xclock, xfd, xieperf, xmag, xwininfo are now
  in XFree86-tools (rather than XFree86)
  makeg is now in XFree86-devel (rather than XFree86)
- obsolete Mesa, glxMesa* and xpm in -libs
- hope it still compiles

* Tue Apr  4 2000 Jakub Jelinek <jakub@redhat.com>
- Even move sparc tweaks

* Sat Apr  1 2000 Bernhard Rosenkraenzer <bero@redhat.com>
- Make it compile on sparc (Patch from Jakub Jelinek <jakub@redhat.com>,
  some additional fixes from me)
- Autodetect the right version of Tcl/Tk
- remove xinitrc, we get it from the xinitrc package

* Sat Mar 18 2000 Bernhard Rosenkraenzer <bero@redhat.com>
- More fixes
- Fix compilation on alpha
- TODO: Port our 3.3.6 patches

* Wed Mar 15 2000 Bernhard Rosenkraenzer <bero@redhat.com>
- Add the man pages ;)
- Merge some patches from the RPMs at seawood.org
- Various fixes

* Mon Mar 13 2000 Bernhard Rosenkraenzer <bero@redhat.com>
- Initial RPM

